#!/bin/bash

CMD_PATH=$(realpath $0)
SOURCE_DIR=$(dirname ${CMD_PATH})

COMMON_SYMBOLS="
gen_helper_check_exit_request \
unicorn_fill_tlb \
reg_read \
reg_write \
uc_init \
uc_add_inline_hook \
uc_del_inline_hook \
tb_invalidate_phys_range \
use_idiv_instructions \
arm_arch \
tb_target_set_jmp_target \
have_bmi1 \
have_popcnt \
have_avx1 \
have_avx2 \
have_isa \
have_altivec \
have_vsx \
flush_icache_range \
s390_facilities \
tcg_dump_op \
tcg_dump_ops \
tcg_gen_and_i64 \
tcg_gen_discard_i64 \
tcg_gen_ld16s_i64 \
tcg_gen_ld16u_i64 \
tcg_gen_ld32s_i64 \
tcg_gen_ld32u_i64 \
tcg_gen_ld8s_i64 \
tcg_gen_ld8u_i64 \
tcg_gen_ld_i64 \
tcg_gen_mov_i64 \
tcg_gen_movi_i64 \
tcg_gen_mul_i64 \
tcg_gen_or_i64 \
tcg_gen_sar_i64 \
tcg_gen_shl_i64 \
tcg_gen_shr_i64 \
tcg_gen_st_i64 \
tcg_gen_xor_i64 \
cpu_icount_to_ns \
cpu_is_stopped \
cpu_get_ticks \
cpu_get_clock \
cpu_resume \
qemu_init_vcpu \
cpu_stop_current \
resume_all_vcpus \
vm_start \
address_space_dispatch_compact \
flatview_translate \
flatview_copy \
address_space_translate_for_iotlb \
qemu_get_cpu \
cpu_address_space_init \
cpu_get_address_space \
cpu_exec_unrealizefn \
cpu_exec_initfn \
cpu_exec_realizefn \
tb_invalidate_phys_addr \
cpu_watchpoint_insert \
cpu_watchpoint_remove_by_ref \
cpu_watchpoint_remove_all \
cpu_watchpoint_address_matches \
cpu_breakpoint_insert \
cpu_breakpoint_remove \
cpu_breakpoint_remove_by_ref \
cpu_breakpoint_remove_all \
cpu_abort \
cpu_physical_memory_test_and_clear_dirty \
memory_region_section_get_iotlb \
flatview_add_to_dispatch \
qemu_ram_get_host_addr \
qemu_ram_get_offset \
qemu_ram_get_used_length \
qemu_ram_is_shared \
qemu_ram_pagesize \
qemu_ram_alloc_from_ptr \
qemu_ram_alloc \
qemu_ram_free \
qemu_map_ram_ptr \
qemu_ram_block_host_offset \
qemu_ram_block_from_host \
qemu_ram_addr_from_host \
cpu_check_watchpoint \
iotlb_to_section \
address_space_dispatch_new \
address_space_dispatch_free \
address_space_dispatch_clear \
flatview_read_continue \
address_space_read_full \
address_space_write \
address_space_rw \
cpu_physical_memory_rw \
address_space_write_rom \
cpu_flush_icache_range \
cpu_exec_init_all \
address_space_access_valid \
address_space_map \
address_space_unmap \
cpu_physical_memory_map \
cpu_physical_memory_unmap \
cpu_memory_rw_debug \
qemu_target_page_size \
qemu_target_page_bits \
qemu_target_page_bits_min \
target_words_bigendian \
cpu_physical_memory_is_io \
ram_block_discard_range \
ramblock_is_pmem \
page_size_init \
set_preferred_target_page_bits \
finalize_target_page_bits \
cpu_outb \
cpu_outw \
cpu_outl \
cpu_inb \
cpu_inw \
cpu_inl \
memory_map \
memory_map_io \
memory_map_ptr \
memory_cow \
memory_unmap \
memory_moveout \
memory_movein \
memory_free \
flatview_unref \
address_space_get_flatview \
memory_region_transaction_begin \
memory_region_transaction_commit \
memory_region_init \
memory_region_access_valid \
memory_region_dispatch_read \
memory_region_dispatch_write \
memory_region_init_io \
memory_region_init_ram_ptr \
memory_region_size \
memory_region_set_readonly \
memory_region_get_ram_ptr \
memory_region_from_host \
memory_region_get_ram_addr \
memory_region_add_subregion \
memory_region_del_subregion \
memory_region_add_subregion_overlap \
memory_region_find \
memory_region_filter_subregions \
memory_listener_register \
memory_listener_unregister \
address_space_remove_listeners \
address_space_init \
address_space_destroy \
memory_region_init_ram \
memory_mapping_list_add_merge_sorted \
find_memory_mapping \
exec_inline_op \
floatx80_default_nan \
float_raise \
float16_is_quiet_nan \
float16_is_signaling_nan \
float32_is_quiet_nan \
float32_is_signaling_nan \
float64_is_quiet_nan \
float64_is_signaling_nan \
floatx80_is_quiet_nan \
floatx80_is_signaling_nan \
floatx80_silence_nan \
propagateFloatx80NaN \
float128_is_quiet_nan \
float128_is_signaling_nan \
float128_silence_nan \
float16_add \
float16_sub \
float32_add \
float32_sub \
float64_add \
float64_sub \
float16_mul \
float32_mul \
float64_mul \
float16_muladd \
float32_muladd \
float64_muladd \
float16_div \
float32_div \
float64_div \
float16_to_float32 \
float16_to_float64 \
float32_to_float16 \
float32_to_float64 \
float64_to_float16 \
float64_to_float32 \
float16_round_to_int \
float32_round_to_int \
float64_round_to_int \
float16_to_int16_scalbn \
float16_to_int32_scalbn \
float16_to_int64_scalbn \
float32_to_int16_scalbn \
float32_to_int32_scalbn \
float32_to_int64_scalbn \
float64_to_int16_scalbn \
float64_to_int32_scalbn \
float64_to_int64_scalbn \
float16_to_int16 \
float16_to_int32 \
float16_to_int64 \
float32_to_int16 \
float32_to_int32 \
float32_to_int64 \
float64_to_int16 \
float64_to_int32 \
float64_to_int64 \
float16_to_int16_round_to_zero \
float16_to_int32_round_to_zero \
float16_to_int64_round_to_zero \
float32_to_int16_round_to_zero \
float32_to_int32_round_to_zero \
float32_to_int64_round_to_zero \
float64_to_int16_round_to_zero \
float64_to_int32_round_to_zero \
float64_to_int64_round_to_zero \
float16_to_uint16_scalbn \
float16_to_uint32_scalbn \
float16_to_uint64_scalbn \
float32_to_uint16_scalbn \
float32_to_uint32_scalbn \
float32_to_uint64_scalbn \
float64_to_uint16_scalbn \
float64_to_uint32_scalbn \
float64_to_uint64_scalbn \
float16_to_uint16 \
float16_to_uint32 \
float16_to_uint64 \
float32_to_uint16 \
float32_to_uint32 \
float32_to_uint64 \
float64_to_uint16 \
float64_to_uint32 \
float64_to_uint64 \
float16_to_uint16_round_to_zero \
float16_to_uint32_round_to_zero \
float16_to_uint64_round_to_zero \
float32_to_uint16_round_to_zero \
float32_to_uint32_round_to_zero \
float32_to_uint64_round_to_zero \
float64_to_uint16_round_to_zero \
float64_to_uint32_round_to_zero \
float64_to_uint64_round_to_zero \
int64_to_float16_scalbn \
int32_to_float16_scalbn \
int16_to_float16_scalbn \
int64_to_float16 \
int32_to_float16 \
int16_to_float16 \
int64_to_float32_scalbn \
int32_to_float32_scalbn \
int16_to_float32_scalbn \
int64_to_float32 \
int32_to_float32 \
int16_to_float32 \
int64_to_float64_scalbn \
int32_to_float64_scalbn \
int16_to_float64_scalbn \
int64_to_float64 \
int32_to_float64 \
int16_to_float64 \
uint64_to_float16_scalbn \
uint32_to_float16_scalbn \
uint16_to_float16_scalbn \
uint64_to_float16 \
uint32_to_float16 \
uint16_to_float16 \
uint64_to_float32_scalbn \
uint32_to_float32_scalbn \
uint16_to_float32_scalbn \
uint64_to_float32 \
uint32_to_float32 \
uint16_to_float32 \
uint64_to_float64_scalbn \
uint32_to_float64_scalbn \
uint16_to_float64_scalbn \
uint64_to_float64 \
uint32_to_float64 \
uint16_to_float64 \
float16_min \
float16_minnum \
float16_minnummag \
float16_max \
float16_maxnum \
float16_maxnummag \
float32_min \
float32_minnum \
float32_minnummag \
float32_max \
float32_maxnum \
float32_maxnummag \
float64_min \
float64_minnum \
float64_minnummag \
float64_max \
float64_maxnum \
float64_maxnummag \
float16_compare \
float16_compare_quiet \
float32_compare \
float32_compare_quiet \
float64_compare \
float64_compare_quiet \
float16_scalbn \
float32_scalbn \
float64_scalbn \
float16_sqrt \
float32_sqrt \
float64_sqrt \
float16_default_nan \
float32_default_nan \
float64_default_nan \
float128_default_nan \
float16_silence_nan \
float32_silence_nan \
float64_silence_nan \
float16_squash_input_denormal \
float32_squash_input_denormal \
float64_squash_input_denormal \
normalizeFloatx80Subnormal \
roundAndPackFloatx80 \
normalizeRoundAndPackFloatx80 \
int32_to_floatx80 \
int32_to_float128 \
int64_to_floatx80 \
int64_to_float128 \
uint64_to_float128 \
float32_to_floatx80 \
float32_to_float128 \
float32_rem \
float32_exp2 \
float32_log2 \
float32_eq \
float32_le \
float32_lt \
float32_unordered \
float32_eq_quiet \
float32_le_quiet \
float32_lt_quiet \
float32_unordered_quiet \
float64_to_floatx80 \
float64_to_float128 \
float64_rem \
float64_log2 \
float64_eq \
float64_le \
float64_lt \
float64_unordered \
float64_eq_quiet \
float64_le_quiet \
float64_lt_quiet \
float64_unordered_quiet \
floatx80_to_int32 \
floatx80_to_int32_round_to_zero \
floatx80_to_int64 \
floatx80_to_int64_round_to_zero \
floatx80_to_float32 \
floatx80_to_float64 \
floatx80_to_float128 \
floatx80_round \
floatx80_round_to_int \
floatx80_add \
floatx80_sub \
floatx80_mul \
floatx80_div \
floatx80_rem \
floatx80_sqrt \
floatx80_eq \
floatx80_le \
floatx80_lt \
floatx80_unordered \
floatx80_eq_quiet \
floatx80_le_quiet \
floatx80_lt_quiet \
floatx80_unordered_quiet \
float128_to_int32 \
float128_to_int32_round_to_zero \
float128_to_int64 \
float128_to_int64_round_to_zero \
float128_to_uint64 \
float128_to_uint64_round_to_zero \
float128_to_uint32_round_to_zero \
float128_to_uint32 \
float128_to_float32 \
float128_to_float64 \
float128_to_floatx80 \
float128_round_to_int \
float128_add \
float128_sub \
float128_mul \
float128_div \
float128_rem \
float128_sqrt \
float128_eq \
float128_le \
float128_lt \
float128_unordered \
float128_eq_quiet \
float128_le_quiet \
float128_lt_quiet \
float128_unordered_quiet \
floatx80_compare \
floatx80_compare_quiet \
float128_compare \
float128_compare_quiet \
floatx80_scalbn \
float128_scalbn \
softfloat_init \
tcg_optimize \
gen_new_label \
tcg_can_emit_vec_op \
tcg_expand_vec_op \
tcg_register_jit \
tcg_tb_insert \
tcg_tb_remove \
tcg_tb_lookup \
tcg_tb_foreach \
tcg_nb_tbs \
tcg_region_reset_all \
tcg_region_init \
tcg_code_size \
tcg_code_capacity \
tcg_tb_phys_invalidate_count \
tcg_malloc_internal \
tcg_pool_reset \
tcg_context_init \
tcg_tb_alloc \
tcg_prologue_init \
tcg_func_start \
tcg_set_frame \
tcg_global_mem_new_internal \
tcg_temp_new_internal \
tcg_temp_new_vec \
tcg_temp_new_vec_matching \
tcg_temp_free_internal \
tcg_const_i32 \
tcg_const_i64 \
tcg_const_local_i32 \
tcg_const_local_i64 \
tcg_op_supported \
tcg_gen_callN \
tcg_op_remove \
tcg_emit_op \
tcg_op_insert_before \
tcg_op_insert_after \
tcg_cpu_exec_time \
tcg_gen_code \
tcg_gen_op1 \
tcg_gen_op2 \
tcg_gen_op3 \
tcg_gen_op4 \
tcg_gen_op5 \
tcg_gen_op6 \
tcg_gen_mb \
tcg_gen_addi_i32 \
tcg_gen_subfi_i32 \
tcg_gen_subi_i32 \
tcg_gen_andi_i32 \
tcg_gen_ori_i32 \
tcg_gen_xori_i32 \
tcg_gen_shli_i32 \
tcg_gen_shri_i32 \
tcg_gen_sari_i32 \
tcg_gen_brcond_i32 \
tcg_gen_brcondi_i32 \
tcg_gen_setcond_i32 \
tcg_gen_setcondi_i32 \
tcg_gen_muli_i32 \
tcg_gen_div_i32 \
tcg_gen_rem_i32 \
tcg_gen_divu_i32 \
tcg_gen_remu_i32 \
tcg_gen_andc_i32 \
tcg_gen_eqv_i32 \
tcg_gen_nand_i32 \
tcg_gen_nor_i32 \
tcg_gen_orc_i32 \
tcg_gen_clz_i32 \
tcg_gen_clzi_i32 \
tcg_gen_ctz_i32 \
tcg_gen_ctzi_i32 \
tcg_gen_clrsb_i32 \
tcg_gen_ctpop_i32 \
tcg_gen_rotl_i32 \
tcg_gen_rotli_i32 \
tcg_gen_rotr_i32 \
tcg_gen_rotri_i32 \
tcg_gen_deposit_i32 \
tcg_gen_deposit_z_i32 \
tcg_gen_extract_i32 \
tcg_gen_sextract_i32 \
tcg_gen_extract2_i32 \
tcg_gen_movcond_i32 \
tcg_gen_add2_i32 \
tcg_gen_sub2_i32 \
tcg_gen_mulu2_i32 \
tcg_gen_muls2_i32 \
tcg_gen_mulsu2_i32 \
tcg_gen_ext8s_i32 \
tcg_gen_ext16s_i32 \
tcg_gen_ext8u_i32 \
tcg_gen_ext16u_i32 \
tcg_gen_bswap16_i32 \
tcg_gen_bswap32_i32 \
tcg_gen_smin_i32 \
tcg_gen_umin_i32 \
tcg_gen_smax_i32 \
tcg_gen_umax_i32 \
tcg_gen_abs_i32 \
tcg_gen_addi_i64 \
tcg_gen_subfi_i64 \
tcg_gen_subi_i64 \
tcg_gen_andi_i64 \
tcg_gen_ori_i64 \
tcg_gen_xori_i64 \
tcg_gen_shli_i64 \
tcg_gen_shri_i64 \
tcg_gen_sari_i64 \
tcg_gen_brcond_i64 \
tcg_gen_brcondi_i64 \
tcg_gen_setcond_i64 \
tcg_gen_setcondi_i64 \
tcg_gen_muli_i64 \
tcg_gen_div_i64 \
tcg_gen_rem_i64 \
tcg_gen_divu_i64 \
tcg_gen_remu_i64 \
tcg_gen_ext8s_i64 \
tcg_gen_ext16s_i64 \
tcg_gen_ext32s_i64 \
tcg_gen_ext8u_i64 \
tcg_gen_ext16u_i64 \
tcg_gen_ext32u_i64 \
tcg_gen_bswap16_i64 \
tcg_gen_bswap32_i64 \
tcg_gen_bswap64_i64 \
tcg_gen_not_i64 \
tcg_gen_andc_i64 \
tcg_gen_eqv_i64 \
tcg_gen_nand_i64 \
tcg_gen_nor_i64 \
tcg_gen_orc_i64 \
tcg_gen_clz_i64 \
tcg_gen_clzi_i64 \
tcg_gen_ctz_i64 \
tcg_gen_ctzi_i64 \
tcg_gen_clrsb_i64 \
tcg_gen_ctpop_i64 \
tcg_gen_rotl_i64 \
tcg_gen_rotli_i64 \
tcg_gen_rotr_i64 \
tcg_gen_rotri_i64 \
tcg_gen_deposit_i64 \
tcg_gen_deposit_z_i64 \
tcg_gen_extract_i64 \
tcg_gen_sextract_i64 \
tcg_gen_extract2_i64 \
tcg_gen_movcond_i64 \
tcg_gen_add2_i64 \
tcg_gen_sub2_i64 \
tcg_gen_mulu2_i64 \
tcg_gen_muls2_i64 \
tcg_gen_mulsu2_i64 \
tcg_gen_smin_i64 \
tcg_gen_umin_i64 \
tcg_gen_smax_i64 \
tcg_gen_umax_i64 \
tcg_gen_abs_i64 \
tcg_gen_extrl_i64_i32 \
tcg_gen_extrh_i64_i32 \
tcg_gen_extu_i32_i64 \
tcg_gen_ext_i32_i64 \
tcg_gen_concat_i32_i64 \
tcg_gen_extr_i64_i32 \
tcg_gen_extr32_i64 \
tcg_gen_exit_tb \
tcg_gen_goto_tb \
tcg_gen_lookup_and_goto_ptr \
check_exit_request \
tcg_gen_qemu_ld_i32 \
tcg_gen_qemu_st_i32 \
tcg_gen_qemu_ld_i64 \
tcg_gen_qemu_st_i64 \
tcg_gen_atomic_cmpxchg_i32 \
tcg_gen_atomic_cmpxchg_i64 \
tcg_gen_atomic_fetch_add_i32 \
tcg_gen_atomic_fetch_add_i64 \
tcg_gen_atomic_fetch_and_i32 \
tcg_gen_atomic_fetch_and_i64 \
tcg_gen_atomic_fetch_or_i32 \
tcg_gen_atomic_fetch_or_i64 \
tcg_gen_atomic_fetch_xor_i32 \
tcg_gen_atomic_fetch_xor_i64 \
tcg_gen_atomic_fetch_smin_i32 \
tcg_gen_atomic_fetch_smin_i64 \
tcg_gen_atomic_fetch_umin_i32 \
tcg_gen_atomic_fetch_umin_i64 \
tcg_gen_atomic_fetch_smax_i32 \
tcg_gen_atomic_fetch_smax_i64 \
tcg_gen_atomic_fetch_umax_i32 \
tcg_gen_atomic_fetch_umax_i64 \
tcg_gen_atomic_add_fetch_i32 \
tcg_gen_atomic_add_fetch_i64 \
tcg_gen_atomic_and_fetch_i32 \
tcg_gen_atomic_and_fetch_i64 \
tcg_gen_atomic_or_fetch_i32 \
tcg_gen_atomic_or_fetch_i64 \
tcg_gen_atomic_xor_fetch_i32 \
tcg_gen_atomic_xor_fetch_i64 \
tcg_gen_atomic_smin_fetch_i32 \
tcg_gen_atomic_smin_fetch_i64 \
tcg_gen_atomic_umin_fetch_i32 \
tcg_gen_atomic_umin_fetch_i64 \
tcg_gen_atomic_smax_fetch_i32 \
tcg_gen_atomic_smax_fetch_i64 \
tcg_gen_atomic_umax_fetch_i32 \
tcg_gen_atomic_umax_fetch_i64 \
tcg_gen_atomic_xchg_i32 \
tcg_gen_atomic_xchg_i64 \
simd_desc \
tcg_gen_gvec_2_ool \
tcg_gen_gvec_2i_ool \
tcg_gen_gvec_3_ool \
tcg_gen_gvec_4_ool \
tcg_gen_gvec_5_ool \
tcg_gen_gvec_2_ptr \
tcg_gen_gvec_3_ptr \
tcg_gen_gvec_4_ptr \
tcg_gen_gvec_5_ptr \
tcg_gen_gvec_2 \
tcg_gen_gvec_2i \
tcg_gen_gvec_2s \
tcg_gen_gvec_3 \
tcg_gen_gvec_3i \
tcg_gen_gvec_4 \
tcg_gen_gvec_mov \
tcg_gen_gvec_dup_i32 \
tcg_gen_gvec_dup_i64 \
tcg_gen_gvec_dup_mem \
tcg_gen_gvec_dup64i \
tcg_gen_gvec_dup32i \
tcg_gen_gvec_dup16i \
tcg_gen_gvec_dup8i \
tcg_gen_gvec_not \
tcg_gen_vec_add8_i64 \
tcg_gen_vec_add16_i64 \
tcg_gen_vec_add32_i64 \
tcg_gen_gvec_add \
tcg_gen_gvec_adds \
tcg_gen_gvec_addi \
tcg_gen_gvec_subs \
tcg_gen_vec_sub8_i64 \
tcg_gen_vec_sub16_i64 \
tcg_gen_vec_sub32_i64 \
tcg_gen_gvec_sub \
tcg_gen_gvec_mul \
tcg_gen_gvec_muls \
tcg_gen_gvec_muli \
tcg_gen_gvec_ssadd \
tcg_gen_gvec_sssub \
tcg_gen_gvec_usadd \
tcg_gen_gvec_ussub \
tcg_gen_gvec_smin \
tcg_gen_gvec_umin \
tcg_gen_gvec_smax \
tcg_gen_gvec_umax \
tcg_gen_vec_neg8_i64 \
tcg_gen_vec_neg16_i64 \
tcg_gen_vec_neg32_i64 \
tcg_gen_gvec_neg \
tcg_gen_gvec_abs \
tcg_gen_gvec_and \
tcg_gen_gvec_or \
tcg_gen_gvec_xor \
tcg_gen_gvec_andc \
tcg_gen_gvec_orc \
tcg_gen_gvec_nand \
tcg_gen_gvec_nor \
tcg_gen_gvec_eqv \
tcg_gen_gvec_ands \
tcg_gen_gvec_andi \
tcg_gen_gvec_xors \
tcg_gen_gvec_xori \
tcg_gen_gvec_ors \
tcg_gen_gvec_ori \
tcg_gen_vec_shl8i_i64 \
tcg_gen_vec_shl16i_i64 \
tcg_gen_gvec_shli \
tcg_gen_vec_shr8i_i64 \
tcg_gen_vec_shr16i_i64 \
tcg_gen_gvec_shri \
tcg_gen_vec_sar8i_i64 \
tcg_gen_vec_sar16i_i64 \
tcg_gen_gvec_sari \
tcg_gen_gvec_shls \
tcg_gen_gvec_shrs \
tcg_gen_gvec_sars \
tcg_gen_gvec_shlv \
tcg_gen_gvec_shrv \
tcg_gen_gvec_sarv \
tcg_gen_gvec_cmp \
tcg_gen_gvec_bitsel \
tcg_can_emit_vecop_list \
vec_gen_2 \
vec_gen_3 \
vec_gen_4 \
tcg_gen_mov_vec \
tcg_const_zeros_vec \
tcg_const_ones_vec \
tcg_const_zeros_vec_matching \
tcg_const_ones_vec_matching \
tcg_gen_dup64i_vec \
tcg_gen_dup32i_vec \
tcg_gen_dup16i_vec \
tcg_gen_dup8i_vec \
tcg_gen_dupi_vec \
tcg_gen_dup_i64_vec \
tcg_gen_dup_i32_vec \
tcg_gen_dup_mem_vec \
tcg_gen_ld_vec \
tcg_gen_st_vec \
tcg_gen_stl_vec \
tcg_gen_and_vec \
tcg_gen_or_vec \
tcg_gen_xor_vec \
tcg_gen_andc_vec \
tcg_gen_orc_vec \
tcg_gen_nand_vec \
tcg_gen_nor_vec \
tcg_gen_eqv_vec \
tcg_gen_not_vec \
tcg_gen_neg_vec \
tcg_gen_abs_vec \
tcg_gen_shli_vec \
tcg_gen_shri_vec \
tcg_gen_sari_vec \
tcg_gen_cmp_vec \
tcg_gen_add_vec \
tcg_gen_sub_vec \
tcg_gen_mul_vec \
tcg_gen_ssadd_vec \
tcg_gen_usadd_vec \
tcg_gen_sssub_vec \
tcg_gen_ussub_vec \
tcg_gen_smin_vec \
tcg_gen_umin_vec \
tcg_gen_smax_vec \
tcg_gen_umax_vec \
tcg_gen_shlv_vec \
tcg_gen_shrv_vec \
tcg_gen_sarv_vec \
tcg_gen_shls_vec \
tcg_gen_shrs_vec \
tcg_gen_sars_vec \
tcg_gen_bitsel_vec \
tcg_gen_cmpsel_vec \
tb_htable_lookup \
tb_set_jmp_target \
cpu_exec \
cpu_loop_exit_noexc \
cpu_reloading_memory_map \
cpu_loop_exit \
cpu_loop_exit_restore \
cpu_loop_exit_atomic \
tlb_init \
tlb_flush_by_mmuidx \
tlb_flush \
tlb_flush_by_mmuidx_all_cpus \
tlb_flush_all_cpus \
tlb_flush_by_mmuidx_all_cpus_synced \
tlb_flush_all_cpus_synced \
tlb_flush_page_by_mmuidx \
tlb_flush_page \
tlb_flush_page_by_mmuidx_all_cpus \
tlb_flush_page_all_cpus \
tlb_flush_page_by_mmuidx_all_cpus_synced \
tlb_flush_page_all_cpus_synced \
tlb_protect_code \
tlb_unprotect_code \
tlb_reset_dirty \
tlb_set_dirty \
tlb_set_page_with_attrs \
tlb_set_page \
get_page_addr_code_hostp \
get_page_addr_code \
probe_access \
tlb_vaddr_to_host \
tlb_vaddr_to_paddr \
helper_ret_ldub_mmu \
helper_le_lduw_mmu \
helper_be_lduw_mmu \
helper_le_ldul_mmu \
helper_be_ldul_mmu \
helper_le_ldq_mmu \
helper_be_ldq_mmu \
helper_ret_ldsb_mmu \
helper_le_ldsw_mmu \
helper_be_ldsw_mmu \
helper_le_ldsl_mmu \
helper_be_ldsl_mmu \
cpu_ldub_mmuidx_ra \
cpu_ldsb_mmuidx_ra \
cpu_lduw_mmuidx_ra \
cpu_ldsw_mmuidx_ra \
cpu_ldl_mmuidx_ra \
cpu_ldq_mmuidx_ra \
cpu_ldub_data_ra \
cpu_ldsb_data_ra \
cpu_lduw_data_ra \
cpu_ldsw_data_ra \
cpu_ldl_data_ra \
cpu_ldq_data_ra \
cpu_ldub_data \
cpu_ldsb_data \
cpu_lduw_data \
cpu_ldsw_data \
cpu_ldl_data \
cpu_ldq_data \
helper_ret_stb_mmu \
helper_le_stw_mmu \
helper_be_stw_mmu \
helper_le_stl_mmu \
helper_be_stl_mmu \
helper_le_stq_mmu \
helper_be_stq_mmu \
cpu_stb_mmuidx_ra \
cpu_stw_mmuidx_ra \
cpu_stl_mmuidx_ra \
cpu_stq_mmuidx_ra \
cpu_stb_data_ra \
cpu_stw_data_ra \
cpu_stl_data_ra \
cpu_stq_data_ra \
cpu_stb_data \
cpu_stw_data \
cpu_stl_data \
cpu_stq_data \
helper_atomic_cmpxchgb_mmu \
helper_atomic_xchgb_mmu \
helper_atomic_fetch_addb_mmu \
helper_atomic_fetch_andb_mmu \
helper_atomic_fetch_orb_mmu \
helper_atomic_fetch_xorb_mmu \
helper_atomic_add_fetchb_mmu \
helper_atomic_and_fetchb_mmu \
helper_atomic_or_fetchb_mmu \
helper_atomic_xor_fetchb_mmu \
helper_atomic_fetch_sminb_mmu \
helper_atomic_fetch_uminb_mmu \
helper_atomic_fetch_smaxb_mmu \
helper_atomic_fetch_umaxb_mmu \
helper_atomic_smin_fetchb_mmu \
helper_atomic_umin_fetchb_mmu \
helper_atomic_smax_fetchb_mmu \
helper_atomic_umax_fetchb_mmu \
helper_atomic_cmpxchgw_le_mmu \
helper_atomic_xchgw_le_mmu \
helper_atomic_fetch_addw_le_mmu \
helper_atomic_fetch_andw_le_mmu \
helper_atomic_fetch_orw_le_mmu \
helper_atomic_fetch_xorw_le_mmu \
helper_atomic_add_fetchw_le_mmu \
helper_atomic_and_fetchw_le_mmu \
helper_atomic_or_fetchw_le_mmu \
helper_atomic_xor_fetchw_le_mmu \
helper_atomic_fetch_sminw_le_mmu \
helper_atomic_fetch_uminw_le_mmu \
helper_atomic_fetch_smaxw_le_mmu \
helper_atomic_fetch_umaxw_le_mmu \
helper_atomic_smin_fetchw_le_mmu \
helper_atomic_umin_fetchw_le_mmu \
helper_atomic_smax_fetchw_le_mmu \
helper_atomic_umax_fetchw_le_mmu \
helper_atomic_cmpxchgw_be_mmu \
helper_atomic_xchgw_be_mmu \
helper_atomic_fetch_andw_be_mmu \
helper_atomic_fetch_orw_be_mmu \
helper_atomic_fetch_xorw_be_mmu \
helper_atomic_and_fetchw_be_mmu \
helper_atomic_or_fetchw_be_mmu \
helper_atomic_xor_fetchw_be_mmu \
helper_atomic_fetch_sminw_be_mmu \
helper_atomic_fetch_uminw_be_mmu \
helper_atomic_fetch_smaxw_be_mmu \
helper_atomic_fetch_umaxw_be_mmu \
helper_atomic_smin_fetchw_be_mmu \
helper_atomic_umin_fetchw_be_mmu \
helper_atomic_smax_fetchw_be_mmu \
helper_atomic_umax_fetchw_be_mmu \
helper_atomic_fetch_addw_be_mmu \
helper_atomic_add_fetchw_be_mmu \
helper_atomic_cmpxchgl_le_mmu \
helper_atomic_xchgl_le_mmu \
helper_atomic_fetch_addl_le_mmu \
helper_atomic_fetch_andl_le_mmu \
helper_atomic_fetch_orl_le_mmu \
helper_atomic_fetch_xorl_le_mmu \
helper_atomic_add_fetchl_le_mmu \
helper_atomic_and_fetchl_le_mmu \
helper_atomic_or_fetchl_le_mmu \
helper_atomic_xor_fetchl_le_mmu \
helper_atomic_fetch_sminl_le_mmu \
helper_atomic_fetch_uminl_le_mmu \
helper_atomic_fetch_smaxl_le_mmu \
helper_atomic_fetch_umaxl_le_mmu \
helper_atomic_smin_fetchl_le_mmu \
helper_atomic_umin_fetchl_le_mmu \
helper_atomic_smax_fetchl_le_mmu \
helper_atomic_umax_fetchl_le_mmu \
helper_atomic_cmpxchgl_be_mmu \
helper_atomic_xchgl_be_mmu \
helper_atomic_fetch_andl_be_mmu \
helper_atomic_fetch_orl_be_mmu \
helper_atomic_fetch_xorl_be_mmu \
helper_atomic_and_fetchl_be_mmu \
helper_atomic_or_fetchl_be_mmu \
helper_atomic_xor_fetchl_be_mmu \
helper_atomic_fetch_sminl_be_mmu \
helper_atomic_fetch_uminl_be_mmu \
helper_atomic_fetch_smaxl_be_mmu \
helper_atomic_fetch_umaxl_be_mmu \
helper_atomic_smin_fetchl_be_mmu \
helper_atomic_umin_fetchl_be_mmu \
helper_atomic_smax_fetchl_be_mmu \
helper_atomic_umax_fetchl_be_mmu \
helper_atomic_fetch_addl_be_mmu \
helper_atomic_add_fetchl_be_mmu \
helper_atomic_cmpxchgq_le_mmu \
helper_atomic_xchgq_le_mmu \
helper_atomic_fetch_addq_le_mmu \
helper_atomic_fetch_andq_le_mmu \
helper_atomic_fetch_orq_le_mmu \
helper_atomic_fetch_xorq_le_mmu \
helper_atomic_add_fetchq_le_mmu \
helper_atomic_and_fetchq_le_mmu \
helper_atomic_or_fetchq_le_mmu \
helper_atomic_xor_fetchq_le_mmu \
helper_atomic_fetch_sminq_le_mmu \
helper_atomic_fetch_uminq_le_mmu \
helper_atomic_fetch_smaxq_le_mmu \
helper_atomic_fetch_umaxq_le_mmu \
helper_atomic_smin_fetchq_le_mmu \
helper_atomic_umin_fetchq_le_mmu \
helper_atomic_smax_fetchq_le_mmu \
helper_atomic_umax_fetchq_le_mmu \
helper_atomic_cmpxchgq_be_mmu \
helper_atomic_xchgq_be_mmu \
helper_atomic_fetch_andq_be_mmu \
helper_atomic_fetch_orq_be_mmu \
helper_atomic_fetch_xorq_be_mmu \
helper_atomic_and_fetchq_be_mmu \
helper_atomic_or_fetchq_be_mmu \
helper_atomic_xor_fetchq_be_mmu \
helper_atomic_fetch_sminq_be_mmu \
helper_atomic_fetch_uminq_be_mmu \
helper_atomic_fetch_smaxq_be_mmu \
helper_atomic_fetch_umaxq_be_mmu \
helper_atomic_smin_fetchq_be_mmu \
helper_atomic_umin_fetchq_be_mmu \
helper_atomic_smax_fetchq_be_mmu \
helper_atomic_umax_fetchq_be_mmu \
helper_atomic_fetch_addq_be_mmu \
helper_atomic_add_fetchq_be_mmu \
helper_atomic_cmpxchgb \
helper_atomic_xchgb \
helper_atomic_fetch_addb \
helper_atomic_fetch_andb \
helper_atomic_fetch_orb \
helper_atomic_fetch_xorb \
helper_atomic_add_fetchb \
helper_atomic_and_fetchb \
helper_atomic_or_fetchb \
helper_atomic_xor_fetchb \
helper_atomic_fetch_sminb \
helper_atomic_fetch_uminb \
helper_atomic_fetch_smaxb \
helper_atomic_fetch_umaxb \
helper_atomic_smin_fetchb \
helper_atomic_umin_fetchb \
helper_atomic_smax_fetchb \
helper_atomic_umax_fetchb \
helper_atomic_cmpxchgw_le \
helper_atomic_xchgw_le \
helper_atomic_fetch_addw_le \
helper_atomic_fetch_andw_le \
helper_atomic_fetch_orw_le \
helper_atomic_fetch_xorw_le \
helper_atomic_add_fetchw_le \
helper_atomic_and_fetchw_le \
helper_atomic_or_fetchw_le \
helper_atomic_xor_fetchw_le \
helper_atomic_fetch_sminw_le \
helper_atomic_fetch_uminw_le \
helper_atomic_fetch_smaxw_le \
helper_atomic_fetch_umaxw_le \
helper_atomic_smin_fetchw_le \
helper_atomic_umin_fetchw_le \
helper_atomic_smax_fetchw_le \
helper_atomic_umax_fetchw_le \
helper_atomic_cmpxchgw_be \
helper_atomic_xchgw_be \
helper_atomic_fetch_andw_be \
helper_atomic_fetch_orw_be \
helper_atomic_fetch_xorw_be \
helper_atomic_and_fetchw_be \
helper_atomic_or_fetchw_be \
helper_atomic_xor_fetchw_be \
helper_atomic_fetch_sminw_be \
helper_atomic_fetch_uminw_be \
helper_atomic_fetch_smaxw_be \
helper_atomic_fetch_umaxw_be \
helper_atomic_smin_fetchw_be \
helper_atomic_umin_fetchw_be \
helper_atomic_smax_fetchw_be \
helper_atomic_umax_fetchw_be \
helper_atomic_fetch_addw_be \
helper_atomic_add_fetchw_be \
helper_atomic_cmpxchgl_le \
helper_atomic_xchgl_le \
helper_atomic_fetch_addl_le \
helper_atomic_fetch_andl_le \
helper_atomic_fetch_orl_le \
helper_atomic_fetch_xorl_le \
helper_atomic_add_fetchl_le \
helper_atomic_and_fetchl_le \
helper_atomic_or_fetchl_le \
helper_atomic_xor_fetchl_le \
helper_atomic_fetch_sminl_le \
helper_atomic_fetch_uminl_le \
helper_atomic_fetch_smaxl_le \
helper_atomic_fetch_umaxl_le \
helper_atomic_smin_fetchl_le \
helper_atomic_umin_fetchl_le \
helper_atomic_smax_fetchl_le \
helper_atomic_umax_fetchl_le \
helper_atomic_cmpxchgl_be \
helper_atomic_xchgl_be \
helper_atomic_fetch_andl_be \
helper_atomic_fetch_orl_be \
helper_atomic_fetch_xorl_be \
helper_atomic_and_fetchl_be \
helper_atomic_or_fetchl_be \
helper_atomic_xor_fetchl_be \
helper_atomic_fetch_sminl_be \
helper_atomic_fetch_uminl_be \
helper_atomic_fetch_smaxl_be \
helper_atomic_fetch_umaxl_be \
helper_atomic_smin_fetchl_be \
helper_atomic_umin_fetchl_be \
helper_atomic_smax_fetchl_be \
helper_atomic_umax_fetchl_be \
helper_atomic_fetch_addl_be \
helper_atomic_add_fetchl_be \
helper_atomic_cmpxchgq_le \
helper_atomic_xchgq_le \
helper_atomic_fetch_addq_le \
helper_atomic_fetch_andq_le \
helper_atomic_fetch_orq_le \
helper_atomic_fetch_xorq_le \
helper_atomic_add_fetchq_le \
helper_atomic_and_fetchq_le \
helper_atomic_or_fetchq_le \
helper_atomic_xor_fetchq_le \
helper_atomic_fetch_sminq_le \
helper_atomic_fetch_uminq_le \
helper_atomic_fetch_smaxq_le \
helper_atomic_fetch_umaxq_le \
helper_atomic_smin_fetchq_le \
helper_atomic_umin_fetchq_le \
helper_atomic_smax_fetchq_le \
helper_atomic_umax_fetchq_le \
helper_atomic_cmpxchgq_be \
helper_atomic_xchgq_be \
helper_atomic_fetch_andq_be \
helper_atomic_fetch_orq_be \
helper_atomic_fetch_xorq_be \
helper_atomic_and_fetchq_be \
helper_atomic_or_fetchq_be \
helper_atomic_xor_fetchq_be \
helper_atomic_fetch_sminq_be \
helper_atomic_fetch_uminq_be \
helper_atomic_fetch_smaxq_be \
helper_atomic_fetch_umaxq_be \
helper_atomic_smin_fetchq_be \
helper_atomic_umin_fetchq_be \
helper_atomic_smax_fetchq_be \
helper_atomic_umax_fetchq_be \
helper_atomic_fetch_addq_be \
helper_atomic_add_fetchq_be \
cpu_ldub_code \
cpu_lduw_code \
cpu_ldl_code \
cpu_ldq_code \
helper_div_i32 \
helper_rem_i32 \
helper_divu_i32 \
helper_remu_i32 \
helper_shl_i64 \
helper_shr_i64 \
helper_sar_i64 \
helper_div_i64 \
helper_rem_i64 \
helper_divu_i64 \
helper_remu_i64 \
helper_muluh_i64 \
helper_mulsh_i64 \
helper_clz_i32 \
helper_ctz_i32 \
helper_clz_i64 \
helper_ctz_i64 \
helper_clrsb_i32 \
helper_clrsb_i64 \
helper_ctpop_i32 \
helper_ctpop_i64 \
helper_lookup_tb_ptr \
helper_exit_atomic \
helper_gvec_add8 \
helper_gvec_add16 \
helper_gvec_add32 \
helper_gvec_add64 \
helper_gvec_adds8 \
helper_gvec_adds16 \
helper_gvec_adds32 \
helper_gvec_adds64 \
helper_gvec_sub8 \
helper_gvec_sub16 \
helper_gvec_sub32 \
helper_gvec_sub64 \
helper_gvec_subs8 \
helper_gvec_subs16 \
helper_gvec_subs32 \
helper_gvec_subs64 \
helper_gvec_mul8 \
helper_gvec_mul16 \
helper_gvec_mul32 \
helper_gvec_mul64 \
helper_gvec_muls8 \
helper_gvec_muls16 \
helper_gvec_muls32 \
helper_gvec_muls64 \
helper_gvec_neg8 \
helper_gvec_neg16 \
helper_gvec_neg32 \
helper_gvec_neg64 \
helper_gvec_abs8 \
helper_gvec_abs16 \
helper_gvec_abs32 \
helper_gvec_abs64 \
helper_gvec_mov \
helper_gvec_dup64 \
helper_gvec_dup32 \
helper_gvec_dup16 \
helper_gvec_dup8 \
helper_gvec_not \
helper_gvec_and \
helper_gvec_or \
helper_gvec_xor \
helper_gvec_andc \
helper_gvec_orc \
helper_gvec_nand \
helper_gvec_nor \
helper_gvec_eqv \
helper_gvec_ands \
helper_gvec_xors \
helper_gvec_ors \
helper_gvec_shl8i \
helper_gvec_shl16i \
helper_gvec_shl32i \
helper_gvec_shl64i \
helper_gvec_shr8i \
helper_gvec_shr16i \
helper_gvec_shr32i \
helper_gvec_shr64i \
helper_gvec_sar8i \
helper_gvec_sar16i \
helper_gvec_sar32i \
helper_gvec_sar64i \
helper_gvec_shl8v \
helper_gvec_shl16v \
helper_gvec_shl32v \
helper_gvec_shl64v \
helper_gvec_shr8v \
helper_gvec_shr16v \
helper_gvec_shr32v \
helper_gvec_shr64v \
helper_gvec_sar8v \
helper_gvec_sar16v \
helper_gvec_sar32v \
helper_gvec_sar64v \
helper_gvec_eq8 \
helper_gvec_ne8 \
helper_gvec_lt8 \
helper_gvec_le8 \
helper_gvec_ltu8 \
helper_gvec_leu8 \
helper_gvec_eq16 \
helper_gvec_ne16 \
helper_gvec_lt16 \
helper_gvec_le16 \
helper_gvec_ltu16 \
helper_gvec_leu16 \
helper_gvec_eq32 \
helper_gvec_ne32 \
helper_gvec_lt32 \
helper_gvec_le32 \
helper_gvec_ltu32 \
helper_gvec_leu32 \
helper_gvec_eq64 \
helper_gvec_ne64 \
helper_gvec_lt64 \
helper_gvec_le64 \
helper_gvec_ltu64 \
helper_gvec_leu64 \
helper_gvec_ssadd8 \
helper_gvec_ssadd16 \
helper_gvec_ssadd32 \
helper_gvec_ssadd64 \
helper_gvec_sssub8 \
helper_gvec_sssub16 \
helper_gvec_sssub32 \
helper_gvec_sssub64 \
helper_gvec_usadd8 \
helper_gvec_usadd16 \
helper_gvec_usadd32 \
helper_gvec_usadd64 \
helper_gvec_ussub8 \
helper_gvec_ussub16 \
helper_gvec_ussub32 \
helper_gvec_ussub64 \
helper_gvec_smin8 \
helper_gvec_smin16 \
helper_gvec_smin32 \
helper_gvec_smin64 \
helper_gvec_smax8 \
helper_gvec_smax16 \
helper_gvec_smax32 \
helper_gvec_smax64 \
helper_gvec_umin8 \
helper_gvec_umin16 \
helper_gvec_umin32 \
helper_gvec_umin64 \
helper_gvec_umax8 \
helper_gvec_umax16 \
helper_gvec_umax32 \
helper_gvec_umax64 \
helper_gvec_bitsel \
cpu_restore_state \
page_collection_lock \
page_collection_unlock \
free_code_gen_buffer \
tcg_exec_init \
tb_cleanup \
tb_flush \
tb_phys_invalidate \
tb_gen_code \
tb_exec_lock \
tb_exec_unlock \
tb_invalidate_phys_page_range \
tb_invalidate_phys_range \
tb_invalidate_phys_page_fast \
tb_check_watchpoint \
cpu_io_recompile \
tb_flush_jmp_cache \
tcg_flush_softmmu_tlb \
translator_loop_temp_check \
translator_loop \
helper_atomic_cmpxchgo_le_mmu \
helper_atomic_cmpxchgo_be_mmu \
helper_atomic_ldo_le_mmu \
helper_atomic_ldo_be_mmu \
helper_atomic_sto_le_mmu \
helper_atomic_sto_be_mmu \
unassigned_mem_ops \
floatx80_infinity \
dup_const_func \
gen_helper_raise_exception \
gen_helper_raise_interrupt \
gen_helper_vfp_get_fpscr \
gen_helper_vfp_set_fpscr \
gen_helper_cpsr_read \
gen_helper_cpsr_write \
tlb_reset_dirty_by_vaddr \
helper_stqcx_le_parallel \
helper_stqcx_be_parallel \
"

x86_64_SYMBOLS="
cpu_get_tsc \
x86_cpu_get_memory_mapping \
cpu_x86_update_dr7 \
breakpoint_handler \
helper_single_step \
helper_rechecking_single_step \
helper_set_dr \
helper_get_dr \
helper_bpt_io \
helper_cc_compute_all \
cpu_cc_compute_all \
helper_cc_compute_c \
helper_write_eflags \
helper_read_eflags \
helper_clts \
helper_reset_rf \
helper_cli \
helper_sti \
helper_clac \
helper_stac \
get_register_name_32 \
host_cpuid \
host_vendor_fms \
x86_cpu_set_default_version \
cpu_clear_apic_feature \
cpu_x86_cpuid \
x86_cpu_pending_interrupt \
x86_update_hflags \
cpu_x86_init \
helper_raise_interrupt \
helper_raise_exception \
raise_interrupt \
raise_exception_err \
raise_exception_err_ra \
raise_exception \
raise_exception_ra \
x86_cpu_tlb_fill \
cpu_set_ignne \
helper_flds_FT0 \
helper_fldl_FT0 \
helper_fildl_FT0 \
helper_flds_ST0 \
helper_fldl_ST0 \
helper_fildl_ST0 \
helper_fildll_ST0 \
helper_fsts_ST0 \
helper_fstl_ST0 \
helper_fist_ST0 \
helper_fistl_ST0 \
helper_fistll_ST0 \
helper_fistt_ST0 \
helper_fisttl_ST0 \
helper_fisttll_ST0 \
helper_fldt_ST0 \
helper_fstt_ST0 \
helper_fpush \
helper_fpop \
helper_fdecstp \
helper_fincstp \
helper_ffree_STN \
helper_fmov_ST0_FT0 \
helper_fmov_FT0_STN \
helper_fmov_ST0_STN \
helper_fmov_STN_ST0 \
helper_fxchg_ST0_STN \
helper_fcom_ST0_FT0 \
helper_fucom_ST0_FT0 \
helper_fcomi_ST0_FT0 \
helper_fucomi_ST0_FT0 \
helper_fadd_ST0_FT0 \
helper_fmul_ST0_FT0 \
helper_fsub_ST0_FT0 \
helper_fsubr_ST0_FT0 \
helper_fdiv_ST0_FT0 \
helper_fdivr_ST0_FT0 \
helper_fadd_STN_ST0 \
helper_fmul_STN_ST0 \
helper_fsub_STN_ST0 \
helper_fsubr_STN_ST0 \
helper_fdiv_STN_ST0 \
helper_fdivr_STN_ST0 \
helper_fchs_ST0 \
helper_fabs_ST0 \
helper_fld1_ST0 \
helper_fldl2t_ST0 \
helper_fldl2e_ST0 \
helper_fldpi_ST0 \
helper_fldlg2_ST0 \
helper_fldln2_ST0 \
helper_fldz_ST0 \
helper_fldz_FT0 \
helper_fnstsw \
helper_fnstcw \
update_fp_status \
helper_fldcw \
helper_fclex \
helper_fwait \
helper_fninit \
helper_fbld_ST0 \
helper_fbst_ST0 \
helper_f2xm1 \
helper_fyl2x \
helper_fptan \
helper_fpatan \
helper_fxtract \
helper_fprem1 \
helper_fprem \
helper_fyl2xp1 \
helper_fsqrt \
helper_fsincos \
helper_frndint \
helper_fscale \
helper_fsin \
helper_fcos \
helper_fxam_ST0 \
helper_fstenv \
helper_fldenv \
helper_fsave \
helper_frstor \
helper_fxsave \
helper_xsave \
helper_xsaveopt \
helper_fxrstor \
helper_xrstor \
helper_xgetbv \
helper_xsetbv \
update_mxcsr_status \
helper_ldmxcsr \
helper_enter_mmx \
helper_emms \
helper_movq \
helper_psrlw_mmx \
helper_psraw_mmx \
helper_psllw_mmx \
helper_psrld_mmx \
helper_psrad_mmx \
helper_pslld_mmx \
helper_psrlq_mmx \
helper_psllq_mmx \
helper_paddb_mmx \
helper_paddw_mmx \
helper_paddl_mmx \
helper_paddq_mmx \
helper_psubb_mmx \
helper_psubw_mmx \
helper_psubl_mmx \
helper_psubq_mmx \
helper_paddusb_mmx \
helper_paddsb_mmx \
helper_psubusb_mmx \
helper_psubsb_mmx \
helper_paddusw_mmx \
helper_paddsw_mmx \
helper_psubusw_mmx \
helper_psubsw_mmx \
helper_pminub_mmx \
helper_pmaxub_mmx \
helper_pminsw_mmx \
helper_pmaxsw_mmx \
helper_pand_mmx \
helper_pandn_mmx \
helper_por_mmx \
helper_pxor_mmx \
helper_pcmpgtb_mmx \
helper_pcmpgtw_mmx \
helper_pcmpgtl_mmx \
helper_pcmpeqb_mmx \
helper_pcmpeqw_mmx \
helper_pcmpeql_mmx \
helper_pmullw_mmx \
helper_pmulhrw_mmx \
helper_pmulhuw_mmx \
helper_pmulhw_mmx \
helper_pavgb_mmx \
helper_pavgw_mmx \
helper_pmuludq_mmx \
helper_pmaddwd_mmx \
helper_psadbw_mmx \
helper_maskmov_mmx \
helper_movl_mm_T0_mmx \
helper_movq_mm_T0_mmx \
helper_pshufw_mmx \
helper_pmovmskb_mmx \
helper_packsswb_mmx \
helper_packuswb_mmx \
helper_packssdw_mmx \
helper_punpcklbw_mmx \
helper_punpcklwd_mmx \
helper_punpckldq_mmx \
helper_punpckhbw_mmx \
helper_punpckhwd_mmx \
helper_punpckhdq_mmx \
helper_pi2fd \
helper_pi2fw \
helper_pf2id \
helper_pf2iw \
helper_pfacc \
helper_pfadd \
helper_pfcmpeq \
helper_pfcmpge \
helper_pfcmpgt \
helper_pfmax \
helper_pfmin \
helper_pfmul \
helper_pfnacc \
helper_pfpnacc \
helper_pfrcp \
helper_pfrsqrt \
helper_pfsub \
helper_pfsubr \
helper_pswapd \
helper_pshufb_mmx \
helper_phaddw_mmx \
helper_phaddd_mmx \
helper_phaddsw_mmx \
helper_pmaddubsw_mmx \
helper_phsubw_mmx \
helper_phsubd_mmx \
helper_phsubsw_mmx \
helper_pabsb_mmx \
helper_pabsw_mmx \
helper_pabsd_mmx \
helper_pmulhrsw_mmx \
helper_psignb_mmx \
helper_psignw_mmx \
helper_psignd_mmx \
helper_palignr_mmx \
helper_psrlw_xmm \
helper_psraw_xmm \
helper_psllw_xmm \
helper_psrld_xmm \
helper_psrad_xmm \
helper_pslld_xmm \
helper_psrlq_xmm \
helper_psllq_xmm \
helper_psrldq_xmm \
helper_pslldq_xmm \
helper_paddb_xmm \
helper_paddw_xmm \
helper_paddl_xmm \
helper_paddq_xmm \
helper_psubb_xmm \
helper_psubw_xmm \
helper_psubl_xmm \
helper_psubq_xmm \
helper_paddusb_xmm \
helper_paddsb_xmm \
helper_psubusb_xmm \
helper_psubsb_xmm \
helper_paddusw_xmm \
helper_paddsw_xmm \
helper_psubusw_xmm \
helper_psubsw_xmm \
helper_pminub_xmm \
helper_pmaxub_xmm \
helper_pminsw_xmm \
helper_pmaxsw_xmm \
helper_pand_xmm \
helper_pandn_xmm \
helper_por_xmm \
helper_pxor_xmm \
helper_pcmpgtb_xmm \
helper_pcmpgtw_xmm \
helper_pcmpgtl_xmm \
helper_pcmpeqb_xmm \
helper_pcmpeqw_xmm \
helper_pcmpeql_xmm \
helper_pmullw_xmm \
helper_pmulhuw_xmm \
helper_pmulhw_xmm \
helper_pavgb_xmm \
helper_pavgw_xmm \
helper_pmuludq_xmm \
helper_pmaddwd_xmm \
helper_psadbw_xmm \
helper_maskmov_xmm \
helper_movl_mm_T0_xmm \
helper_movq_mm_T0_xmm \
helper_shufps \
helper_shufpd \
helper_pshufd_xmm \
helper_pshuflw_xmm \
helper_pshufhw_xmm \
helper_addps \
helper_addss \
helper_addpd \
helper_addsd \
helper_subps \
helper_subss \
helper_subpd \
helper_subsd \
helper_mulps \
helper_mulss \
helper_mulpd \
helper_mulsd \
helper_divps \
helper_divss \
helper_divpd \
helper_divsd \
helper_minps \
helper_minss \
helper_minpd \
helper_minsd \
helper_maxps \
helper_maxss \
helper_maxpd \
helper_maxsd \
helper_sqrtps \
helper_sqrtss \
helper_sqrtpd \
helper_sqrtsd \
helper_cvtps2pd \
helper_cvtpd2ps \
helper_cvtss2sd \
helper_cvtsd2ss \
helper_cvtdq2ps \
helper_cvtdq2pd \
helper_cvtpi2ps \
helper_cvtpi2pd \
helper_cvtsi2ss \
helper_cvtsi2sd \
helper_cvtsq2ss \
helper_cvtsq2sd \
helper_cvtps2dq \
helper_cvtpd2dq \
helper_cvtps2pi \
helper_cvtpd2pi \
helper_cvtss2si \
helper_cvtsd2si \
helper_cvtss2sq \
helper_cvtsd2sq \
helper_cvttps2dq \
helper_cvttpd2dq \
helper_cvttps2pi \
helper_cvttpd2pi \
helper_cvttss2si \
helper_cvttsd2si \
helper_cvttss2sq \
helper_cvttsd2sq \
helper_rsqrtps \
helper_rsqrtss \
helper_rcpps \
helper_rcpss \
helper_extrq_r \
helper_extrq_i \
helper_insertq_r \
helper_insertq_i \
helper_haddps \
helper_haddpd \
helper_hsubps \
helper_hsubpd \
helper_addsubps \
helper_addsubpd \
helper_cmpeqps \
helper_cmpeqss \
helper_cmpeqpd \
helper_cmpeqsd \
helper_cmpltps \
helper_cmpltss \
helper_cmpltpd \
helper_cmpltsd \
helper_cmpleps \
helper_cmpless \
helper_cmplepd \
helper_cmplesd \
helper_cmpunordps \
helper_cmpunordss \
helper_cmpunordpd \
helper_cmpunordsd \
helper_cmpneqps \
helper_cmpneqss \
helper_cmpneqpd \
helper_cmpneqsd \
helper_cmpnltps \
helper_cmpnltss \
helper_cmpnltpd \
helper_cmpnltsd \
helper_cmpnleps \
helper_cmpnless \
helper_cmpnlepd \
helper_cmpnlesd \
helper_cmpordps \
helper_cmpordss \
helper_cmpordpd \
helper_cmpordsd \
helper_ucomiss \
helper_comiss \
helper_ucomisd \
helper_comisd \
helper_movmskps \
helper_movmskpd \
helper_pmovmskb_xmm \
helper_packsswb_xmm \
helper_packuswb_xmm \
helper_packssdw_xmm \
helper_punpcklbw_xmm \
helper_punpcklwd_xmm \
helper_punpckldq_xmm \
helper_punpcklqdq_xmm \
helper_punpckhbw_xmm \
helper_punpckhwd_xmm \
helper_punpckhdq_xmm \
helper_punpckhqdq_xmm \
helper_pshufb_xmm \
helper_phaddw_xmm \
helper_phaddd_xmm \
helper_phaddsw_xmm \
helper_pmaddubsw_xmm \
helper_phsubw_xmm \
helper_phsubd_xmm \
helper_phsubsw_xmm \
helper_pabsb_xmm \
helper_pabsw_xmm \
helper_pabsd_xmm \
helper_pmulhrsw_xmm \
helper_psignb_xmm \
helper_psignw_xmm \
helper_psignd_xmm \
helper_palignr_xmm \
helper_pblendvb_xmm \
helper_blendvps_xmm \
helper_blendvpd_xmm \
helper_ptest_xmm \
helper_pmovsxbw_xmm \
helper_pmovsxbd_xmm \
helper_pmovsxbq_xmm \
helper_pmovsxwd_xmm \
helper_pmovsxwq_xmm \
helper_pmovsxdq_xmm \
helper_pmovzxbw_xmm \
helper_pmovzxbd_xmm \
helper_pmovzxbq_xmm \
helper_pmovzxwd_xmm \
helper_pmovzxwq_xmm \
helper_pmovzxdq_xmm \
helper_pmuldq_xmm \
helper_pcmpeqq_xmm \
helper_packusdw_xmm \
helper_pminsb_xmm \
helper_pminsd_xmm \
helper_pminuw_xmm \
helper_pminud_xmm \
helper_pmaxsb_xmm \
helper_pmaxsd_xmm \
helper_pmaxuw_xmm \
helper_pmaxud_xmm \
helper_pmulld_xmm \
helper_phminposuw_xmm \
helper_roundps_xmm \
helper_roundpd_xmm \
helper_roundss_xmm \
helper_roundsd_xmm \
helper_blendps_xmm \
helper_blendpd_xmm \
helper_pblendw_xmm \
helper_dpps_xmm \
helper_dppd_xmm \
helper_mpsadbw_xmm \
helper_pcmpgtq_xmm \
helper_pcmpestri_xmm \
helper_pcmpestrm_xmm \
helper_pcmpistri_xmm \
helper_pcmpistrm_xmm \
helper_crc32 \
helper_pclmulqdq_xmm \
helper_aesdec_xmm \
helper_aesdeclast_xmm \
helper_aesenc_xmm \
helper_aesenclast_xmm \
helper_aesimc_xmm \
helper_aeskeygenassist_xmm \
cpu_sync_bndcs_hflags \
cpu_x86_support_mca_broadcast \
x86_cpu_set_a20 \
cpu_x86_update_cr0 \
cpu_x86_update_cr3 \
cpu_x86_update_cr4 \
x86_cpu_get_phys_page_attrs_debug \
cpu_x86_get_descr_debug \
do_cpu_init \
do_cpu_sipi \
x86_cpu_exec_enter \
x86_cpu_exec_exit \
x86_ldub_phys \
x86_lduw_phys \
x86_ldl_phys \
x86_ldq_phys \
x86_stb_phys \
x86_stl_phys_notdirty \
x86_stw_phys \
x86_stl_phys \
x86_stq_phys \
helper_divb_AL \
helper_idivb_AL \
helper_divw_AX \
helper_idivw_AX \
helper_divl_EAX \
helper_idivl_EAX \
helper_aam \
helper_aad \
helper_aaa \
helper_aas \
helper_daa \
helper_das \
helper_divq_EAX \
helper_idivq_EAX \
helper_pdep \
helper_pext \
helper_rclb \
helper_rcrb \
helper_rclw \
helper_rcrw \
helper_rcll \
helper_rcrl \
helper_rclq \
helper_rcrq \
helper_cr4_testbit \
helper_rdrand \
helper_cmpxchg8b_unlocked \
helper_cmpxchg8b \
helper_cmpxchg16b_unlocked \
helper_cmpxchg16b \
helper_boundw \
helper_boundl \
helper_outb \
helper_inb \
helper_outw \
helper_inw \
helper_outl \
helper_inl \
helper_into \
helper_cpuid \
helper_read_crN \
helper_write_crN \
helper_lmsw \
helper_invlpg \
helper_rdtsc \
helper_rdtscp \
helper_rdpmc \
helper_wrmsr \
helper_rdmsr \
helper_hlt \
helper_monitor \
helper_mwait \
helper_pause \
helper_debug \
helper_rdpkru \
helper_wrpkru \
helper_bndck \
helper_bndldx64 \
helper_bndldx32 \
helper_bndstx64 \
helper_bndstx32 \
helper_bnd_jmp \
helper_syscall \
helper_sysret \
x86_cpu_do_interrupt \
do_interrupt_x86_hardirq \
x86_cpu_exec_interrupt \
helper_lldt \
helper_ltr \
uc_check_cpu_x86_load_seg \
helper_load_seg \
helper_ljmp_protected \
helper_lcall_real \
helper_lcall_protected \
helper_iret_real \
helper_iret_protected \
helper_lret_protected \
helper_sysenter \
helper_sysexit \
helper_lsl \
helper_lar \
helper_verr \
helper_verw \
cpu_x86_load_seg \
helper_check_iob \
helper_check_iow \
helper_check_iol \
do_smm_enter \
helper_rsm \
helper_vmrun \
helper_vmmcall \
helper_vmload \
helper_vmsave \
helper_stgi \
helper_clgi \
helper_skinit \
helper_invlpga \
cpu_svm_check_intercept_param \
helper_svm_check_intercept_param \
helper_svm_check_io \
cpu_vmexit \
do_vmexit \
tcg_x86_init \
gen_intermediate_code \
restore_state_to_opc \
x86_cpu_xsave_all_areas \
x86_cpu_xrstor_all_areas \
cpu_get_fp80 \
cpu_set_fp80 \
"

arm_SYMBOLS="
arm_cpu_exec_interrupt \
arm_cpu_update_virq \
arm_cpu_update_vfiq \
arm_cpu_initfn \
gt_cntfrq_period_ns \
arm_cpu_post_init \
arm_cpu_realizefn \
a15_l2ctlr_read \
arm_cpu_class_init \
cpu_arm_init \
helper_crypto_aese \
helper_crypto_aesmc \
helper_crypto_sha1_3reg \
helper_crypto_sha1h \
helper_crypto_sha1su1 \
helper_crypto_sha256h \
helper_crypto_sha256h2 \
helper_crypto_sha256su0 \
helper_crypto_sha256su1 \
helper_crypto_sha512h \
helper_crypto_sha512h2 \
helper_crypto_sha512su0 \
helper_crypto_sha512su1 \
helper_crypto_sm3partw1 \
helper_crypto_sm3partw2 \
helper_crypto_sm3tt \
helper_crypto_sm4e \
helper_crypto_sm4ekey \
helper_check_breakpoints \
arm_debug_check_watchpoint \
arm_debug_excp_handler \
arm_adjust_watchpoint_address \
read_raw_cp_reg \
pmu_init \
pmu_op_start \
pmu_op_finish \
pmu_pre_el_change \
pmu_post_el_change \
arm_pmu_timer_cb \
arm_gt_ptimer_cb \
arm_gt_vtimer_cb \
arm_gt_htimer_cb \
arm_gt_stimer_cb \
arm_gt_hvtimer_cb \
arm_hcr_el2_eff \
sve_exception_el \
sve_zcr_len_for_el \
hw_watchpoint_update \
hw_watchpoint_update_all \
hw_breakpoint_update \
hw_breakpoint_update_all \
register_cp_regs_for_features \
define_one_arm_cp_reg_with_opaque \
define_arm_cp_regs_with_opaque \
modify_arm_cp_regs \
get_arm_cp_reginfo \
arm_cp_write_ignore \
arm_cp_read_zero \
arm_cp_reset_ignore \
cpsr_read \
cpsr_write \
helper_sxtb16 \
helper_uxtb16 \
helper_sdiv \
helper_udiv \
helper_rbit \
arm_phys_excp_target_el \
aarch64_sync_32_to_64 \
aarch64_sync_64_to_32 \
arm_cpu_do_interrupt \
arm_sctlr \
arm_s1_regime_using_lpae_format \
aa64_va_parameters \
v8m_security_lookup \
pmsav8_mpu_lookup \
get_phys_addr \
arm_cpu_get_phys_page_attrs_debug \
helper_qadd16 \
helper_qadd8 \
helper_qsub16 \
helper_qsub8 \
helper_qsubaddx \
helper_qaddsubx \
helper_uqadd16 \
helper_uqadd8 \
helper_uqsub16 \
helper_uqsub8 \
helper_uqsubaddx \
helper_uqaddsubx \
helper_sadd16 \
helper_sadd8 \
helper_ssub16 \
helper_ssub8 \
helper_ssubaddx \
helper_saddsubx \
helper_uadd16 \
helper_uadd8 \
helper_usub16 \
helper_usub8 \
helper_usubaddx \
helper_uaddsubx \
helper_shadd16 \
helper_shadd8 \
helper_shsub16 \
helper_shsub8 \
helper_shsubaddx \
helper_shaddsubx \
helper_uhadd16 \
helper_uhadd8 \
helper_uhsub16 \
helper_uhsub8 \
helper_uhsubaddx \
helper_uhaddsubx \
helper_usad8 \
helper_sel_flags \
helper_crc32 \
helper_crc32c \
fp_exception_el \
arm_mmu_idx_to_el \
arm_mmu_idx_el \
arm_mmu_idx \
arm_stage1_mmu_idx \
arm_rebuild_hflags \
helper_rebuild_hflags_m32_newel \
helper_rebuild_hflags_m32 \
helper_rebuild_hflags_a32_newel \
helper_rebuild_hflags_a32 \
helper_rebuild_hflags_a64 \
cpu_get_tb_cpu_state \
helper_iwmmxt_maddsq \
helper_iwmmxt_madduq \
helper_iwmmxt_sadb \
helper_iwmmxt_sadw \
helper_iwmmxt_mulslw \
helper_iwmmxt_mulshw \
helper_iwmmxt_mululw \
helper_iwmmxt_muluhw \
helper_iwmmxt_macsw \
helper_iwmmxt_macuw \
helper_iwmmxt_unpacklb \
helper_iwmmxt_unpacklw \
helper_iwmmxt_unpackll \
helper_iwmmxt_unpacklub \
helper_iwmmxt_unpackluw \
helper_iwmmxt_unpacklul \
helper_iwmmxt_unpacklsb \
helper_iwmmxt_unpacklsw \
helper_iwmmxt_unpacklsl \
helper_iwmmxt_unpackhb \
helper_iwmmxt_unpackhw \
helper_iwmmxt_unpackhl \
helper_iwmmxt_unpackhub \
helper_iwmmxt_unpackhuw \
helper_iwmmxt_unpackhul \
helper_iwmmxt_unpackhsb \
helper_iwmmxt_unpackhsw \
helper_iwmmxt_unpackhsl \
helper_iwmmxt_cmpeqb \
helper_iwmmxt_cmpeqw \
helper_iwmmxt_cmpeql \
helper_iwmmxt_cmpgtsb \
helper_iwmmxt_cmpgtsw \
helper_iwmmxt_cmpgtsl \
helper_iwmmxt_cmpgtub \
helper_iwmmxt_cmpgtuw \
helper_iwmmxt_cmpgtul \
helper_iwmmxt_minsb \
helper_iwmmxt_minsw \
helper_iwmmxt_minsl \
helper_iwmmxt_minub \
helper_iwmmxt_minuw \
helper_iwmmxt_minul \
helper_iwmmxt_maxsb \
helper_iwmmxt_maxsw \
helper_iwmmxt_maxsl \
helper_iwmmxt_maxub \
helper_iwmmxt_maxuw \
helper_iwmmxt_maxul \
helper_iwmmxt_subnb \
helper_iwmmxt_subnw \
helper_iwmmxt_subnl \
helper_iwmmxt_addnb \
helper_iwmmxt_addnw \
helper_iwmmxt_addnl \
helper_iwmmxt_subub \
helper_iwmmxt_subuw \
helper_iwmmxt_subul \
helper_iwmmxt_addub \
helper_iwmmxt_adduw \
helper_iwmmxt_addul \
helper_iwmmxt_subsb \
helper_iwmmxt_subsw \
helper_iwmmxt_subsl \
helper_iwmmxt_addsb \
helper_iwmmxt_addsw \
helper_iwmmxt_addsl \
helper_iwmmxt_avgb0 \
helper_iwmmxt_avgb1 \
helper_iwmmxt_avgw0 \
helper_iwmmxt_avgw1 \
helper_iwmmxt_align \
helper_iwmmxt_insr \
helper_iwmmxt_setpsr_nz \
helper_iwmmxt_bcstb \
helper_iwmmxt_bcstw \
helper_iwmmxt_bcstl \
helper_iwmmxt_addcb \
helper_iwmmxt_addcw \
helper_iwmmxt_addcl \
helper_iwmmxt_msbb \
helper_iwmmxt_msbw \
helper_iwmmxt_msbl \
helper_iwmmxt_srlw \
helper_iwmmxt_srll \
helper_iwmmxt_srlq \
helper_iwmmxt_sllw \
helper_iwmmxt_slll \
helper_iwmmxt_sllq \
helper_iwmmxt_sraw \
helper_iwmmxt_sral \
helper_iwmmxt_sraq \
helper_iwmmxt_rorw \
helper_iwmmxt_rorl \
helper_iwmmxt_rorq \
helper_iwmmxt_shufh \
helper_iwmmxt_packuw \
helper_iwmmxt_packul \
helper_iwmmxt_packuq \
helper_iwmmxt_packsw \
helper_iwmmxt_packsl \
helper_iwmmxt_packsq \
helper_iwmmxt_muladdsl \
helper_iwmmxt_muladdsw \
helper_iwmmxt_muladdswl \
armv7m_nvic_set_pending \
helper_v7m_preserve_fp_state \
write_v7m_exception \
helper_v7m_bxns \
helper_v7m_blxns \
armv7m_nvic_neg_prio_requested \
helper_v7m_vlstm \
helper_v7m_vlldm \
arm_v7m_cpu_do_interrupt \
helper_v7m_mrs \
helper_v7m_msr \
helper_v7m_tt \
arm_v7m_mmu_idx_all \
arm_v7m_mmu_idx_for_secstate_and_priv \
arm_v7m_mmu_idx_for_secstate \
helper_neon_qadd_u8 \
helper_neon_qadd_u16 \
helper_neon_qadd_u32 \
helper_neon_qadd_u64 \
helper_neon_qadd_s8 \
helper_neon_qadd_s16 \
helper_neon_qadd_s32 \
helper_neon_qadd_s64 \
helper_neon_uqadd_s8 \
helper_neon_uqadd_s16 \
helper_neon_uqadd_s32 \
helper_neon_uqadd_s64 \
helper_neon_sqadd_u8 \
helper_neon_sqadd_u16 \
helper_neon_sqadd_u32 \
helper_neon_sqadd_u64 \
helper_neon_qsub_u8 \
helper_neon_qsub_u16 \
helper_neon_qsub_u32 \
helper_neon_qsub_u64 \
helper_neon_qsub_s8 \
helper_neon_qsub_s16 \
helper_neon_qsub_s32 \
helper_neon_qsub_s64 \
helper_neon_hadd_s8 \
helper_neon_hadd_u8 \
helper_neon_hadd_s16 \
helper_neon_hadd_u16 \
helper_neon_hadd_s32 \
helper_neon_hadd_u32 \
helper_neon_rhadd_s8 \
helper_neon_rhadd_u8 \
helper_neon_rhadd_s16 \
helper_neon_rhadd_u16 \
helper_neon_rhadd_s32 \
helper_neon_rhadd_u32 \
helper_neon_hsub_s8 \
helper_neon_hsub_u8 \
helper_neon_hsub_s16 \
helper_neon_hsub_u16 \
helper_neon_hsub_s32 \
helper_neon_hsub_u32 \
helper_neon_cgt_s8 \
helper_neon_cgt_u8 \
helper_neon_cgt_s16 \
helper_neon_cgt_u16 \
helper_neon_cgt_s32 \
helper_neon_cgt_u32 \
helper_neon_cge_s8 \
helper_neon_cge_u8 \
helper_neon_cge_s16 \
helper_neon_cge_u16 \
helper_neon_cge_s32 \
helper_neon_cge_u32 \
helper_neon_pmin_s8 \
helper_neon_pmin_u8 \
helper_neon_pmin_s16 \
helper_neon_pmin_u16 \
helper_neon_pmax_s8 \
helper_neon_pmax_u8 \
helper_neon_pmax_s16 \
helper_neon_pmax_u16 \
helper_neon_abd_s8 \
helper_neon_abd_u8 \
helper_neon_abd_s16 \
helper_neon_abd_u16 \
helper_neon_abd_s32 \
helper_neon_abd_u32 \
helper_neon_shl_u16 \
helper_neon_shl_s16 \
helper_neon_rshl_s8 \
helper_neon_rshl_s16 \
helper_neon_rshl_s32 \
helper_neon_rshl_s64 \
helper_neon_rshl_u8 \
helper_neon_rshl_u16 \
helper_neon_rshl_u32 \
helper_neon_rshl_u64 \
helper_neon_qshl_u8 \
helper_neon_qshl_u16 \
helper_neon_qshl_u32 \
helper_neon_qshl_u64 \
helper_neon_qshl_s8 \
helper_neon_qshl_s16 \
helper_neon_qshl_s32 \
helper_neon_qshl_s64 \
helper_neon_qshlu_s8 \
helper_neon_qshlu_s16 \
helper_neon_qshlu_s32 \
helper_neon_qshlu_s64 \
helper_neon_qrshl_u8 \
helper_neon_qrshl_u16 \
helper_neon_qrshl_u32 \
helper_neon_qrshl_u64 \
helper_neon_qrshl_s8 \
helper_neon_qrshl_s16 \
helper_neon_qrshl_s32 \
helper_neon_qrshl_s64 \
helper_neon_add_u8 \
helper_neon_add_u16 \
helper_neon_padd_u8 \
helper_neon_padd_u16 \
helper_neon_sub_u8 \
helper_neon_sub_u16 \
helper_neon_mul_u8 \
helper_neon_mul_u16 \
helper_neon_tst_u8 \
helper_neon_tst_u16 \
helper_neon_tst_u32 \
helper_neon_ceq_u8 \
helper_neon_ceq_u16 \
helper_neon_ceq_u32 \
helper_neon_clz_u8 \
helper_neon_clz_u16 \
helper_neon_cls_s8 \
helper_neon_cls_s16 \
helper_neon_cls_s32 \
helper_neon_cnt_u8 \
helper_neon_rbit_u8 \
helper_neon_qdmulh_s16 \
helper_neon_qrdmulh_s16 \
helper_neon_qdmulh_s32 \
helper_neon_qrdmulh_s32 \
helper_neon_narrow_u8 \
helper_neon_narrow_u16 \
helper_neon_narrow_high_u8 \
helper_neon_narrow_high_u16 \
helper_neon_narrow_round_high_u8 \
helper_neon_narrow_round_high_u16 \
helper_neon_unarrow_sat8 \
helper_neon_narrow_sat_u8 \
helper_neon_narrow_sat_s8 \
helper_neon_unarrow_sat16 \
helper_neon_narrow_sat_u16 \
helper_neon_narrow_sat_s16 \
helper_neon_unarrow_sat32 \
helper_neon_narrow_sat_u32 \
helper_neon_narrow_sat_s32 \
helper_neon_widen_u8 \
helper_neon_widen_s8 \
helper_neon_widen_u16 \
helper_neon_widen_s16 \
helper_neon_addl_u16 \
helper_neon_addl_u32 \
helper_neon_paddl_u16 \
helper_neon_paddl_u32 \
helper_neon_subl_u16 \
helper_neon_subl_u32 \
helper_neon_addl_saturate_s32 \
helper_neon_addl_saturate_s64 \
helper_neon_abdl_u16 \
helper_neon_abdl_s16 \
helper_neon_abdl_u32 \
helper_neon_abdl_s32 \
helper_neon_abdl_u64 \
helper_neon_abdl_s64 \
helper_neon_mull_u8 \
helper_neon_mull_s8 \
helper_neon_mull_u16 \
helper_neon_mull_s16 \
helper_neon_negl_u16 \
helper_neon_negl_u32 \
helper_neon_qabs_s8 \
helper_neon_qneg_s8 \
helper_neon_qabs_s16 \
helper_neon_qneg_s16 \
helper_neon_qabs_s32 \
helper_neon_qneg_s32 \
helper_neon_qabs_s64 \
helper_neon_qneg_s64 \
helper_neon_abd_f32 \
helper_neon_ceq_f32 \
helper_neon_cge_f32 \
helper_neon_cgt_f32 \
helper_neon_acge_f32 \
helper_neon_acgt_f32 \
helper_neon_acge_f64 \
helper_neon_acgt_f64 \
helper_neon_qunzip8 \
helper_neon_qunzip16 \
helper_neon_qunzip32 \
helper_neon_unzip8 \
helper_neon_unzip16 \
helper_neon_qzip8 \
helper_neon_qzip16 \
helper_neon_qzip32 \
helper_neon_zip8 \
helper_neon_zip16 \
raise_exception \
raise_exception_ra \
helper_neon_tbl \
helper_v8m_stackcheck \
helper_add_setq \
helper_add_saturate \
helper_sub_saturate \
helper_add_usaturate \
helper_sub_usaturate \
helper_ssat \
helper_ssat16 \
helper_usat \
helper_usat16 \
helper_setend \
helper_wfi \
helper_wfe \
helper_yield \
helper_exception_internal \
helper_exception_with_syndrome \
helper_exception_bkpt_insn \
helper_cpsr_read \
helper_cpsr_write \
helper_cpsr_write_eret \
helper_get_user_reg \
helper_set_user_reg \
helper_set_r13_banked \
helper_get_r13_banked \
helper_msr_banked \
helper_mrs_banked \
helper_access_check_cp_reg \
helper_set_cp_reg \
helper_get_cp_reg \
helper_set_cp_reg64 \
helper_get_cp_reg64 \
helper_pre_hvc \
helper_pre_smc \
helper_shl_cc \
helper_shr_cc \
helper_sar_cc \
helper_ror_cc \
arm_is_psci_call \
arm_handle_psci_call \
arm_cpu_do_unaligned_access \
arm_cpu_do_transaction_failed \
arm_cpu_tlb_fill \
arm_translate_init \
arm_test_cc \
arm_free_cc \
arm_jump_cc \
arm_gen_test_cc \
vfp_expand_imm \
gen_cmtst_i64 \
gen_ushl_i32 \
gen_ushl_i64 \
gen_sshl_i32 \
gen_sshl_i64 \
gen_intermediate_code \
restore_state_to_opc \
helper_neon_qrdmlah_s16 \
helper_gvec_qrdmlah_s16 \
helper_neon_qrdmlsh_s16 \
helper_gvec_qrdmlsh_s16 \
helper_neon_qrdmlah_s32 \
helper_gvec_qrdmlah_s32 \
helper_neon_qrdmlsh_s32 \
helper_gvec_qrdmlsh_s32 \
helper_gvec_sdot_b \
helper_gvec_udot_b \
helper_gvec_sdot_h \
helper_gvec_udot_h \
helper_gvec_sdot_idx_b \
helper_gvec_udot_idx_b \
helper_gvec_sdot_idx_h \
helper_gvec_udot_idx_h \
helper_gvec_fcaddh \
helper_gvec_fcadds \
helper_gvec_fcaddd \
helper_gvec_fcmlah \
helper_gvec_fcmlah_idx \
helper_gvec_fcmlas \
helper_gvec_fcmlas_idx \
helper_gvec_fcmlad \
helper_gvec_frecpe_h \
helper_gvec_frecpe_s \
helper_gvec_frecpe_d \
helper_gvec_frsqrte_h \
helper_gvec_frsqrte_s \
helper_gvec_frsqrte_d \
helper_gvec_fadd_h \
helper_gvec_fadd_s \
helper_gvec_fadd_d \
helper_gvec_fsub_h \
helper_gvec_fsub_s \
helper_gvec_fsub_d \
helper_gvec_fmul_h \
helper_gvec_fmul_s \
helper_gvec_fmul_d \
helper_gvec_ftsmul_h \
helper_gvec_ftsmul_s \
helper_gvec_ftsmul_d \
helper_gvec_fmul_idx_h \
helper_gvec_fmul_idx_s \
helper_gvec_fmul_idx_d \
helper_gvec_fmla_idx_h \
helper_gvec_fmla_idx_s \
helper_gvec_fmla_idx_d \
helper_gvec_uqadd_b \
helper_gvec_uqadd_h \
helper_gvec_uqadd_s \
helper_gvec_sqadd_b \
helper_gvec_sqadd_h \
helper_gvec_sqadd_s \
helper_gvec_uqsub_b \
helper_gvec_uqsub_h \
helper_gvec_uqsub_s \
helper_gvec_sqsub_b \
helper_gvec_sqsub_h \
helper_gvec_sqsub_s \
helper_gvec_uqadd_d \
helper_gvec_uqsub_d \
helper_gvec_sqadd_d \
helper_gvec_sqsub_d \
helper_gvec_fmlal_a32 \
helper_gvec_fmlal_a64 \
helper_gvec_fmlal_idx_a32 \
helper_gvec_fmlal_idx_a64 \
helper_gvec_sshl_b \
helper_gvec_sshl_h \
helper_gvec_ushl_b \
helper_gvec_ushl_h \
helper_gvec_pmul_b \
helper_gvec_pmull_q \
helper_neon_pmull_h \
helper_vfp_get_fpscr \
vfp_get_fpscr \
helper_vfp_set_fpscr \
vfp_set_fpscr \
helper_vfp_adds \
helper_vfp_addd \
helper_vfp_subs \
helper_vfp_subd \
helper_vfp_muls \
helper_vfp_muld \
helper_vfp_divs \
helper_vfp_divd \
helper_vfp_mins \
helper_vfp_mind \
helper_vfp_maxs \
helper_vfp_maxd \
helper_vfp_minnums \
helper_vfp_minnumd \
helper_vfp_maxnums \
helper_vfp_maxnumd \
helper_vfp_negs \
helper_vfp_negd \
helper_vfp_abss \
helper_vfp_absd \
helper_vfp_sqrts \
helper_vfp_sqrtd \
helper_vfp_cmps \
helper_vfp_cmpes \
helper_vfp_cmpd \
helper_vfp_cmped \
helper_vfp_sitoh \
helper_vfp_tosih \
helper_vfp_tosizh \
helper_vfp_sitos \
helper_vfp_tosis \
helper_vfp_tosizs \
helper_vfp_sitod \
helper_vfp_tosid \
helper_vfp_tosizd \
helper_vfp_uitoh \
helper_vfp_touih \
helper_vfp_touizh \
helper_vfp_uitos \
helper_vfp_touis \
helper_vfp_touizs \
helper_vfp_uitod \
helper_vfp_touid \
helper_vfp_touizd \
helper_vfp_fcvtds \
helper_vfp_fcvtsd \
helper_vfp_shtod \
helper_vfp_toshd_round_to_zero \
helper_vfp_toshd \
helper_vfp_sltod \
helper_vfp_tosld_round_to_zero \
helper_vfp_tosld \
helper_vfp_sqtod \
helper_vfp_tosqd \
helper_vfp_uhtod \
helper_vfp_touhd_round_to_zero \
helper_vfp_touhd \
helper_vfp_ultod \
helper_vfp_tould_round_to_zero \
helper_vfp_tould \
helper_vfp_uqtod \
helper_vfp_touqd \
helper_vfp_shtos \
helper_vfp_toshs_round_to_zero \
helper_vfp_toshs \
helper_vfp_sltos \
helper_vfp_tosls_round_to_zero \
helper_vfp_tosls \
helper_vfp_sqtos \
helper_vfp_tosqs \
helper_vfp_uhtos \
helper_vfp_touhs_round_to_zero \
helper_vfp_touhs \
helper_vfp_ultos \
helper_vfp_touls_round_to_zero \
helper_vfp_touls \
helper_vfp_uqtos \
helper_vfp_touqs \
helper_vfp_sltoh \
helper_vfp_ultoh \
helper_vfp_sqtoh \
helper_vfp_uqtoh \
helper_vfp_toshh \
helper_vfp_touhh \
helper_vfp_toslh \
helper_vfp_toulh \
helper_vfp_tosqh \
helper_vfp_touqh \
helper_set_rmode \
helper_set_neon_rmode \
helper_vfp_fcvt_f16_to_f32 \
helper_vfp_fcvt_f32_to_f16 \
helper_vfp_fcvt_f16_to_f64 \
helper_vfp_fcvt_f64_to_f16 \
helper_recps_f32 \
helper_rsqrts_f32 \
helper_recpe_f16 \
helper_recpe_f32 \
helper_recpe_f64 \
helper_rsqrte_f16 \
helper_rsqrte_f32 \
helper_rsqrte_f64 \
helper_recpe_u32 \
helper_rsqrte_u32 \
helper_vfp_muladds \
helper_vfp_muladdd \
helper_rints_exact \
helper_rintd_exact \
helper_rints \
helper_rintd \
arm_rmode_to_sf \
helper_fjcvtzs \
helper_vjcvt \
helper_frint32_s \
helper_frint64_s \
helper_frint32_d \
helper_frint64_d \
helper_check_hcr_el2_trap \
mla_op \
mls_op \
sshl_op \
ushl_op \
uqsub_op \
sqsub_op \
uqadd_op \
sqadd_op \
sli_op \
cmtst_op \
sri_op \
usra_op \
ssra_op \
"

aarch64_SYMBOLS="
cpu_aarch64_init \
arm_cpu_exec_interrupt \
arm_cpu_update_virq \
arm_cpu_update_vfiq \
arm_cpu_initfn \
gt_cntfrq_period_ns \
arm_cpu_post_init \
arm_cpu_realizefn \
arm_cpu_class_init \
cpu_arm_init \
helper_crypto_aese \
helper_crypto_aesmc \
helper_crypto_sha1_3reg \
helper_crypto_sha1h \
helper_crypto_sha1su1 \
helper_crypto_sha256h \
helper_crypto_sha256h2 \
helper_crypto_sha256su0 \
helper_crypto_sha256su1 \
helper_crypto_sha512h \
helper_crypto_sha512h2 \
helper_crypto_sha512su0 \
helper_crypto_sha512su1 \
helper_crypto_sm3partw1 \
helper_crypto_sm3partw2 \
helper_crypto_sm3tt \
helper_crypto_sm4e \
helper_crypto_sm4ekey \
helper_check_breakpoints \
arm_debug_check_watchpoint \
arm_debug_excp_handler \
arm_adjust_watchpoint_address \
helper_udiv64 \
helper_sdiv64 \
helper_rbit64 \
helper_msr_i_spsel \
helper_msr_i_daifset \
helper_msr_i_daifclear \
helper_vfp_cmph_a64 \
helper_vfp_cmpeh_a64 \
helper_vfp_cmps_a64 \
helper_vfp_cmpes_a64 \
helper_vfp_cmpd_a64 \
helper_vfp_cmped_a64 \
helper_vfp_mulxs \
helper_vfp_mulxd \
helper_simd_tbl \
helper_neon_ceq_f64 \
helper_neon_cge_f64 \
helper_neon_cgt_f64 \
helper_recpsf_f16 \
helper_recpsf_f32 \
helper_recpsf_f64 \
helper_rsqrtsf_f16 \
helper_rsqrtsf_f32 \
helper_rsqrtsf_f64 \
helper_neon_addlp_s8 \
helper_neon_addlp_u8 \
helper_neon_addlp_s16 \
helper_neon_addlp_u16 \
helper_frecpx_f16 \
helper_frecpx_f32 \
helper_frecpx_f64 \
helper_fcvtx_f64_to_f32 \
helper_crc32_64 \
helper_crc32c_64 \
helper_paired_cmpxchg64_le \
helper_paired_cmpxchg64_le_parallel \
helper_paired_cmpxchg64_be \
helper_paired_cmpxchg64_be_parallel \
helper_casp_le_parallel \
helper_casp_be_parallel \
helper_advsimd_addh \
helper_advsimd_subh \
helper_advsimd_mulh \
helper_advsimd_divh \
helper_advsimd_minh \
helper_advsimd_maxh \
helper_advsimd_minnumh \
helper_advsimd_maxnumh \
helper_advsimd_add2h \
helper_advsimd_sub2h \
helper_advsimd_mul2h \
helper_advsimd_div2h \
helper_advsimd_min2h \
helper_advsimd_max2h \
helper_advsimd_minnum2h \
helper_advsimd_maxnum2h \
helper_advsimd_mulxh \
helper_advsimd_mulx2h \
helper_advsimd_muladdh \
helper_advsimd_muladd2h \
helper_advsimd_ceq_f16 \
helper_advsimd_cge_f16 \
helper_advsimd_cgt_f16 \
helper_advsimd_acge_f16 \
helper_advsimd_acgt_f16 \
helper_advsimd_rinth_exact \
helper_advsimd_rinth \
helper_advsimd_f16tosinth \
helper_advsimd_f16touinth \
helper_exception_return \
helper_sqrt_f16 \
helper_dc_zva \
read_raw_cp_reg \
pmu_init \
pmu_op_start \
pmu_op_finish \
pmu_pre_el_change \
pmu_post_el_change \
arm_pmu_timer_cb \
arm_gt_ptimer_cb \
arm_gt_vtimer_cb \
arm_gt_htimer_cb \
arm_gt_stimer_cb \
arm_gt_hvtimer_cb \
arm_hcr_el2_eff \
sve_exception_el \
sve_zcr_len_for_el \
hw_watchpoint_update \
hw_watchpoint_update_all \
hw_breakpoint_update \
hw_breakpoint_update_all \
register_cp_regs_for_features \
define_one_arm_cp_reg_with_opaque \
define_arm_cp_regs_with_opaque \
modify_arm_cp_regs \
get_arm_cp_reginfo \
arm_cp_write_ignore \
arm_cp_read_zero \
arm_cp_reset_ignore \
cpsr_read \
cpsr_write \
helper_sxtb16 \
helper_uxtb16 \
helper_sdiv \
helper_udiv \
helper_rbit \
arm_phys_excp_target_el \
aarch64_sync_32_to_64 \
aarch64_sync_64_to_32 \
arm_cpu_do_interrupt \
arm_sctlr \
arm_s1_regime_using_lpae_format \
aa64_va_parameters \
v8m_security_lookup \
pmsav8_mpu_lookup \
get_phys_addr \
arm_cpu_get_phys_page_attrs_debug \
helper_qadd16 \
helper_qadd8 \
helper_qsub16 \
helper_qsub8 \
helper_qsubaddx \
helper_qaddsubx \
helper_uqadd16 \
helper_uqadd8 \
helper_uqsub16 \
helper_uqsub8 \
helper_uqsubaddx \
helper_uqaddsubx \
helper_sadd16 \
helper_sadd8 \
helper_ssub16 \
helper_ssub8 \
helper_ssubaddx \
helper_saddsubx \
helper_uadd16 \
helper_uadd8 \
helper_usub16 \
helper_usub8 \
helper_usubaddx \
helper_uaddsubx \
helper_shadd16 \
helper_shadd8 \
helper_shsub16 \
helper_shsub8 \
helper_shsubaddx \
helper_shaddsubx \
helper_uhadd16 \
helper_uhadd8 \
helper_uhsub16 \
helper_uhsub8 \
helper_uhsubaddx \
helper_uhaddsubx \
helper_usad8 \
helper_sel_flags \
helper_crc32 \
helper_crc32c \
fp_exception_el \
arm_mmu_idx_to_el \
arm_mmu_idx_el \
arm_mmu_idx \
arm_stage1_mmu_idx \
arm_rebuild_hflags \
helper_rebuild_hflags_m32_newel \
helper_rebuild_hflags_m32 \
helper_rebuild_hflags_a32_newel \
helper_rebuild_hflags_a32 \
helper_rebuild_hflags_a64 \
cpu_get_tb_cpu_state \
aarch64_sve_narrow_vq \
aarch64_sve_change_el \
helper_iwmmxt_maddsq \
helper_iwmmxt_madduq \
helper_iwmmxt_sadb \
helper_iwmmxt_sadw \
helper_iwmmxt_mulslw \
helper_iwmmxt_mulshw \
helper_iwmmxt_mululw \
helper_iwmmxt_muluhw \
helper_iwmmxt_macsw \
helper_iwmmxt_macuw \
helper_iwmmxt_unpacklb \
helper_iwmmxt_unpacklw \
helper_iwmmxt_unpackll \
helper_iwmmxt_unpacklub \
helper_iwmmxt_unpackluw \
helper_iwmmxt_unpacklul \
helper_iwmmxt_unpacklsb \
helper_iwmmxt_unpacklsw \
helper_iwmmxt_unpacklsl \
helper_iwmmxt_unpackhb \
helper_iwmmxt_unpackhw \
helper_iwmmxt_unpackhl \
helper_iwmmxt_unpackhub \
helper_iwmmxt_unpackhuw \
helper_iwmmxt_unpackhul \
helper_iwmmxt_unpackhsb \
helper_iwmmxt_unpackhsw \
helper_iwmmxt_unpackhsl \
helper_iwmmxt_cmpeqb \
helper_iwmmxt_cmpeqw \
helper_iwmmxt_cmpeql \
helper_iwmmxt_cmpgtsb \
helper_iwmmxt_cmpgtsw \
helper_iwmmxt_cmpgtsl \
helper_iwmmxt_cmpgtub \
helper_iwmmxt_cmpgtuw \
helper_iwmmxt_cmpgtul \
helper_iwmmxt_minsb \
helper_iwmmxt_minsw \
helper_iwmmxt_minsl \
helper_iwmmxt_minub \
helper_iwmmxt_minuw \
helper_iwmmxt_minul \
helper_iwmmxt_maxsb \
helper_iwmmxt_maxsw \
helper_iwmmxt_maxsl \
helper_iwmmxt_maxub \
helper_iwmmxt_maxuw \
helper_iwmmxt_maxul \
helper_iwmmxt_subnb \
helper_iwmmxt_subnw \
helper_iwmmxt_subnl \
helper_iwmmxt_addnb \
helper_iwmmxt_addnw \
helper_iwmmxt_addnl \
helper_iwmmxt_subub \
helper_iwmmxt_subuw \
helper_iwmmxt_subul \
helper_iwmmxt_addub \
helper_iwmmxt_adduw \
helper_iwmmxt_addul \
helper_iwmmxt_subsb \
helper_iwmmxt_subsw \
helper_iwmmxt_subsl \
helper_iwmmxt_addsb \
helper_iwmmxt_addsw \
helper_iwmmxt_addsl \
helper_iwmmxt_avgb0 \
helper_iwmmxt_avgb1 \
helper_iwmmxt_avgw0 \
helper_iwmmxt_avgw1 \
helper_iwmmxt_align \
helper_iwmmxt_insr \
helper_iwmmxt_setpsr_nz \
helper_iwmmxt_bcstb \
helper_iwmmxt_bcstw \
helper_iwmmxt_bcstl \
helper_iwmmxt_addcb \
helper_iwmmxt_addcw \
helper_iwmmxt_addcl \
helper_iwmmxt_msbb \
helper_iwmmxt_msbw \
helper_iwmmxt_msbl \
helper_iwmmxt_srlw \
helper_iwmmxt_srll \
helper_iwmmxt_srlq \
helper_iwmmxt_sllw \
helper_iwmmxt_slll \
helper_iwmmxt_sllq \
helper_iwmmxt_sraw \
helper_iwmmxt_sral \
helper_iwmmxt_sraq \
helper_iwmmxt_rorw \
helper_iwmmxt_rorl \
helper_iwmmxt_rorq \
helper_iwmmxt_shufh \
helper_iwmmxt_packuw \
helper_iwmmxt_packul \
helper_iwmmxt_packuq \
helper_iwmmxt_packsw \
helper_iwmmxt_packsl \
helper_iwmmxt_packsq \
helper_iwmmxt_muladdsl \
helper_iwmmxt_muladdsw \
helper_iwmmxt_muladdswl \
armv7m_nvic_set_pending \
helper_v7m_preserve_fp_state \
write_v7m_exception \
helper_v7m_bxns \
helper_v7m_blxns \
armv7m_nvic_neg_prio_requested \
helper_v7m_vlstm \
helper_v7m_vlldm \
arm_v7m_cpu_do_interrupt \
helper_v7m_mrs \
helper_v7m_msr \
helper_v7m_tt \
arm_v7m_mmu_idx_all \
arm_v7m_mmu_idx_for_secstate_and_priv \
arm_v7m_mmu_idx_for_secstate \
helper_neon_qadd_u8 \
helper_neon_qadd_u16 \
helper_neon_qadd_u32 \
helper_neon_qadd_u64 \
helper_neon_qadd_s8 \
helper_neon_qadd_s16 \
helper_neon_qadd_s32 \
helper_neon_qadd_s64 \
helper_neon_uqadd_s8 \
helper_neon_uqadd_s16 \
helper_neon_uqadd_s32 \
helper_neon_uqadd_s64 \
helper_neon_sqadd_u8 \
helper_neon_sqadd_u16 \
helper_neon_sqadd_u32 \
helper_neon_sqadd_u64 \
helper_neon_qsub_u8 \
helper_neon_qsub_u16 \
helper_neon_qsub_u32 \
helper_neon_qsub_u64 \
helper_neon_qsub_s8 \
helper_neon_qsub_s16 \
helper_neon_qsub_s32 \
helper_neon_qsub_s64 \
helper_neon_hadd_s8 \
helper_neon_hadd_u8 \
helper_neon_hadd_s16 \
helper_neon_hadd_u16 \
helper_neon_hadd_s32 \
helper_neon_hadd_u32 \
helper_neon_rhadd_s8 \
helper_neon_rhadd_u8 \
helper_neon_rhadd_s16 \
helper_neon_rhadd_u16 \
helper_neon_rhadd_s32 \
helper_neon_rhadd_u32 \
helper_neon_hsub_s8 \
helper_neon_hsub_u8 \
helper_neon_hsub_s16 \
helper_neon_hsub_u16 \
helper_neon_hsub_s32 \
helper_neon_hsub_u32 \
helper_neon_cgt_s8 \
helper_neon_cgt_u8 \
helper_neon_cgt_s16 \
helper_neon_cgt_u16 \
helper_neon_cgt_s32 \
helper_neon_cgt_u32 \
helper_neon_cge_s8 \
helper_neon_cge_u8 \
helper_neon_cge_s16 \
helper_neon_cge_u16 \
helper_neon_cge_s32 \
helper_neon_cge_u32 \
helper_neon_pmin_s8 \
helper_neon_pmin_u8 \
helper_neon_pmin_s16 \
helper_neon_pmin_u16 \
helper_neon_pmax_s8 \
helper_neon_pmax_u8 \
helper_neon_pmax_s16 \
helper_neon_pmax_u16 \
helper_neon_abd_s8 \
helper_neon_abd_u8 \
helper_neon_abd_s16 \
helper_neon_abd_u16 \
helper_neon_abd_s32 \
helper_neon_abd_u32 \
helper_neon_shl_u16 \
helper_neon_shl_s16 \
helper_neon_rshl_s8 \
helper_neon_rshl_s16 \
helper_neon_rshl_s32 \
helper_neon_rshl_s64 \
helper_neon_rshl_u8 \
helper_neon_rshl_u16 \
helper_neon_rshl_u32 \
helper_neon_rshl_u64 \
helper_neon_qshl_u8 \
helper_neon_qshl_u16 \
helper_neon_qshl_u32 \
helper_neon_qshl_u64 \
helper_neon_qshl_s8 \
helper_neon_qshl_s16 \
helper_neon_qshl_s32 \
helper_neon_qshl_s64 \
helper_neon_qshlu_s8 \
helper_neon_qshlu_s16 \
helper_neon_qshlu_s32 \
helper_neon_qshlu_s64 \
helper_neon_qrshl_u8 \
helper_neon_qrshl_u16 \
helper_neon_qrshl_u32 \
helper_neon_qrshl_u64 \
helper_neon_qrshl_s8 \
helper_neon_qrshl_s16 \
helper_neon_qrshl_s32 \
helper_neon_qrshl_s64 \
helper_neon_add_u8 \
helper_neon_add_u16 \
helper_neon_padd_u8 \
helper_neon_padd_u16 \
helper_neon_sub_u8 \
helper_neon_sub_u16 \
helper_neon_mul_u8 \
helper_neon_mul_u16 \
helper_neon_tst_u8 \
helper_neon_tst_u16 \
helper_neon_tst_u32 \
helper_neon_ceq_u8 \
helper_neon_ceq_u16 \
helper_neon_ceq_u32 \
helper_neon_clz_u8 \
helper_neon_clz_u16 \
helper_neon_cls_s8 \
helper_neon_cls_s16 \
helper_neon_cls_s32 \
helper_neon_cnt_u8 \
helper_neon_rbit_u8 \
helper_neon_qdmulh_s16 \
helper_neon_qrdmulh_s16 \
helper_neon_qdmulh_s32 \
helper_neon_qrdmulh_s32 \
helper_neon_narrow_u8 \
helper_neon_narrow_u16 \
helper_neon_narrow_high_u8 \
helper_neon_narrow_high_u16 \
helper_neon_narrow_round_high_u8 \
helper_neon_narrow_round_high_u16 \
helper_neon_unarrow_sat8 \
helper_neon_narrow_sat_u8 \
helper_neon_narrow_sat_s8 \
helper_neon_unarrow_sat16 \
helper_neon_narrow_sat_u16 \
helper_neon_narrow_sat_s16 \
helper_neon_unarrow_sat32 \
helper_neon_narrow_sat_u32 \
helper_neon_narrow_sat_s32 \
helper_neon_widen_u8 \
helper_neon_widen_s8 \
helper_neon_widen_u16 \
helper_neon_widen_s16 \
helper_neon_addl_u16 \
helper_neon_addl_u32 \
helper_neon_paddl_u16 \
helper_neon_paddl_u32 \
helper_neon_subl_u16 \
helper_neon_subl_u32 \
helper_neon_addl_saturate_s32 \
helper_neon_addl_saturate_s64 \
helper_neon_abdl_u16 \
helper_neon_abdl_s16 \
helper_neon_abdl_u32 \
helper_neon_abdl_s32 \
helper_neon_abdl_u64 \
helper_neon_abdl_s64 \
helper_neon_mull_u8 \
helper_neon_mull_s8 \
helper_neon_mull_u16 \
helper_neon_mull_s16 \
helper_neon_negl_u16 \
helper_neon_negl_u32 \
helper_neon_qabs_s8 \
helper_neon_qneg_s8 \
helper_neon_qabs_s16 \
helper_neon_qneg_s16 \
helper_neon_qabs_s32 \
helper_neon_qneg_s32 \
helper_neon_qabs_s64 \
helper_neon_qneg_s64 \
helper_neon_abd_f32 \
helper_neon_ceq_f32 \
helper_neon_cge_f32 \
helper_neon_cgt_f32 \
helper_neon_acge_f32 \
helper_neon_acgt_f32 \
helper_neon_acge_f64 \
helper_neon_acgt_f64 \
helper_neon_qunzip8 \
helper_neon_qunzip16 \
helper_neon_qunzip32 \
helper_neon_unzip8 \
helper_neon_unzip16 \
helper_neon_qzip8 \
helper_neon_qzip16 \
helper_neon_qzip32 \
helper_neon_zip8 \
helper_neon_zip16 \
raise_exception \
raise_exception_ra \
helper_neon_tbl \
helper_v8m_stackcheck \
helper_add_setq \
helper_add_saturate \
helper_sub_saturate \
helper_add_usaturate \
helper_sub_usaturate \
helper_ssat \
helper_ssat16 \
helper_usat \
helper_usat16 \
helper_setend \
helper_wfi \
helper_wfe \
helper_yield \
helper_exception_internal \
helper_exception_with_syndrome \
helper_exception_bkpt_insn \
helper_cpsr_read \
helper_cpsr_write \
helper_cpsr_write_eret \
helper_get_user_reg \
helper_set_user_reg \
helper_set_r13_banked \
helper_get_r13_banked \
helper_msr_banked \
helper_mrs_banked \
helper_access_check_cp_reg \
helper_set_cp_reg \
helper_get_cp_reg \
helper_set_cp_reg64 \
helper_get_cp_reg64 \
helper_pre_hvc \
helper_pre_smc \
helper_shl_cc \
helper_shr_cc \
helper_sar_cc \
helper_ror_cc \
helper_pacia \
helper_pacib \
helper_pacda \
helper_pacdb \
helper_pacga \
helper_autia \
helper_autib \
helper_autda \
helper_autdb \
helper_xpaci \
helper_xpacd \
arm_is_psci_call \
arm_handle_psci_call \
helper_sve_predtest1 \
helper_sve_predtest \
helper_sve_and_pppp \
helper_sve_bic_pppp \
helper_sve_eor_pppp \
helper_sve_sel_pppp \
helper_sve_orr_pppp \
helper_sve_orn_pppp \
helper_sve_nor_pppp \
helper_sve_nand_pppp \
helper_sve_and_zpzz_b \
helper_sve_and_zpzz_h \
helper_sve_and_zpzz_s \
helper_sve_and_zpzz_d \
helper_sve_orr_zpzz_b \
helper_sve_orr_zpzz_h \
helper_sve_orr_zpzz_s \
helper_sve_orr_zpzz_d \
helper_sve_eor_zpzz_b \
helper_sve_eor_zpzz_h \
helper_sve_eor_zpzz_s \
helper_sve_eor_zpzz_d \
helper_sve_bic_zpzz_b \
helper_sve_bic_zpzz_h \
helper_sve_bic_zpzz_s \
helper_sve_bic_zpzz_d \
helper_sve_add_zpzz_b \
helper_sve_add_zpzz_h \
helper_sve_add_zpzz_s \
helper_sve_add_zpzz_d \
helper_sve_sub_zpzz_b \
helper_sve_sub_zpzz_h \
helper_sve_sub_zpzz_s \
helper_sve_sub_zpzz_d \
helper_sve_smax_zpzz_b \
helper_sve_smax_zpzz_h \
helper_sve_smax_zpzz_s \
helper_sve_smax_zpzz_d \
helper_sve_umax_zpzz_b \
helper_sve_umax_zpzz_h \
helper_sve_umax_zpzz_s \
helper_sve_umax_zpzz_d \
helper_sve_smin_zpzz_b \
helper_sve_smin_zpzz_h \
helper_sve_smin_zpzz_s \
helper_sve_smin_zpzz_d \
helper_sve_umin_zpzz_b \
helper_sve_umin_zpzz_h \
helper_sve_umin_zpzz_s \
helper_sve_umin_zpzz_d \
helper_sve_sabd_zpzz_b \
helper_sve_sabd_zpzz_h \
helper_sve_sabd_zpzz_s \
helper_sve_sabd_zpzz_d \
helper_sve_uabd_zpzz_b \
helper_sve_uabd_zpzz_h \
helper_sve_uabd_zpzz_s \
helper_sve_uabd_zpzz_d \
helper_sve_mul_zpzz_b \
helper_sve_mul_zpzz_h \
helper_sve_mul_zpzz_s \
helper_sve_mul_zpzz_d \
helper_sve_smulh_zpzz_b \
helper_sve_smulh_zpzz_h \
helper_sve_smulh_zpzz_s \
helper_sve_smulh_zpzz_d \
helper_sve_umulh_zpzz_b \
helper_sve_umulh_zpzz_h \
helper_sve_umulh_zpzz_s \
helper_sve_umulh_zpzz_d \
helper_sve_sdiv_zpzz_s \
helper_sve_sdiv_zpzz_d \
helper_sve_udiv_zpzz_s \
helper_sve_udiv_zpzz_d \
helper_sve_asr_zpzz_b \
helper_sve_lsr_zpzz_b \
helper_sve_lsl_zpzz_b \
helper_sve_asr_zpzz_h \
helper_sve_lsr_zpzz_h \
helper_sve_lsl_zpzz_h \
helper_sve_asr_zpzz_s \
helper_sve_lsr_zpzz_s \
helper_sve_lsl_zpzz_s \
helper_sve_asr_zpzz_d \
helper_sve_lsr_zpzz_d \
helper_sve_lsl_zpzz_d \
helper_sve_asr_zpzw_b \
helper_sve_lsr_zpzw_b \
helper_sve_lsl_zpzw_b \
helper_sve_asr_zpzw_h \
helper_sve_lsr_zpzw_h \
helper_sve_lsl_zpzw_h \
helper_sve_asr_zpzw_s \
helper_sve_lsr_zpzw_s \
helper_sve_lsl_zpzw_s \
helper_sve_cls_b \
helper_sve_cls_h \
helper_sve_cls_s \
helper_sve_cls_d \
helper_sve_clz_b \
helper_sve_clz_h \
helper_sve_clz_s \
helper_sve_clz_d \
helper_sve_cnt_zpz_b \
helper_sve_cnt_zpz_h \
helper_sve_cnt_zpz_s \
helper_sve_cnt_zpz_d \
helper_sve_cnot_b \
helper_sve_cnot_h \
helper_sve_cnot_s \
helper_sve_cnot_d \
helper_sve_fabs_h \
helper_sve_fabs_s \
helper_sve_fabs_d \
helper_sve_fneg_h \
helper_sve_fneg_s \
helper_sve_fneg_d \
helper_sve_not_zpz_b \
helper_sve_not_zpz_h \
helper_sve_not_zpz_s \
helper_sve_not_zpz_d \
helper_sve_sxtb_h \
helper_sve_sxtb_s \
helper_sve_sxth_s \
helper_sve_sxtb_d \
helper_sve_sxth_d \
helper_sve_sxtw_d \
helper_sve_uxtb_h \
helper_sve_uxtb_s \
helper_sve_uxth_s \
helper_sve_uxtb_d \
helper_sve_uxth_d \
helper_sve_uxtw_d \
helper_sve_abs_b \
helper_sve_abs_h \
helper_sve_abs_s \
helper_sve_abs_d \
helper_sve_neg_b \
helper_sve_neg_h \
helper_sve_neg_s \
helper_sve_neg_d \
helper_sve_revb_h \
helper_sve_revb_s \
helper_sve_revb_d \
helper_sve_revh_s \
helper_sve_revh_d \
helper_sve_revw_d \
helper_sve_rbit_b \
helper_sve_rbit_h \
helper_sve_rbit_s \
helper_sve_rbit_d \
helper_sve_asr_zzw_b \
helper_sve_lsr_zzw_b \
helper_sve_lsl_zzw_b \
helper_sve_asr_zzw_h \
helper_sve_lsr_zzw_h \
helper_sve_lsl_zzw_h \
helper_sve_asr_zzw_s \
helper_sve_lsr_zzw_s \
helper_sve_lsl_zzw_s \
helper_sve_orv_b \
helper_sve_orv_h \
helper_sve_orv_s \
helper_sve_orv_d \
helper_sve_eorv_b \
helper_sve_eorv_h \
helper_sve_eorv_s \
helper_sve_eorv_d \
helper_sve_andv_b \
helper_sve_andv_h \
helper_sve_andv_s \
helper_sve_andv_d \
helper_sve_saddv_b \
helper_sve_saddv_h \
helper_sve_saddv_s \
helper_sve_uaddv_b \
helper_sve_uaddv_h \
helper_sve_uaddv_s \
helper_sve_uaddv_d \
helper_sve_smaxv_b \
helper_sve_smaxv_h \
helper_sve_smaxv_s \
helper_sve_smaxv_d \
helper_sve_umaxv_b \
helper_sve_umaxv_h \
helper_sve_umaxv_s \
helper_sve_umaxv_d \
helper_sve_sminv_b \
helper_sve_sminv_h \
helper_sve_sminv_s \
helper_sve_sminv_d \
helper_sve_uminv_b \
helper_sve_uminv_h \
helper_sve_uminv_s \
helper_sve_uminv_d \
helper_sve_subri_b \
helper_sve_subri_h \
helper_sve_subri_s \
helper_sve_subri_d \
helper_sve_smaxi_b \
helper_sve_smaxi_h \
helper_sve_smaxi_s \
helper_sve_smaxi_d \
helper_sve_smini_b \
helper_sve_smini_h \
helper_sve_smini_s \
helper_sve_smini_d \
helper_sve_umaxi_b \
helper_sve_umaxi_h \
helper_sve_umaxi_s \
helper_sve_umaxi_d \
helper_sve_umini_b \
helper_sve_umini_h \
helper_sve_umini_s \
helper_sve_umini_d \
helper_sve_pfirst \
helper_sve_pnext \
helper_sve_clr_b \
helper_sve_clr_h \
helper_sve_clr_s \
helper_sve_clr_d \
helper_sve_movz_b \
helper_sve_movz_h \
helper_sve_movz_s \
helper_sve_movz_d \
helper_sve_asr_zpzi_b \
helper_sve_asr_zpzi_h \
helper_sve_asr_zpzi_s \
helper_sve_asr_zpzi_d \
helper_sve_lsr_zpzi_b \
helper_sve_lsr_zpzi_h \
helper_sve_lsr_zpzi_s \
helper_sve_lsr_zpzi_d \
helper_sve_lsl_zpzi_b \
helper_sve_lsl_zpzi_h \
helper_sve_lsl_zpzi_s \
helper_sve_lsl_zpzi_d \
helper_sve_asrd_b \
helper_sve_asrd_h \
helper_sve_asrd_s \
helper_sve_asrd_d \
helper_sve_mla_b \
helper_sve_mls_b \
helper_sve_mla_h \
helper_sve_mls_h \
helper_sve_mla_s \
helper_sve_mls_s \
helper_sve_mla_d \
helper_sve_mls_d \
helper_sve_index_b \
helper_sve_index_h \
helper_sve_index_s \
helper_sve_index_d \
helper_sve_adr_p32 \
helper_sve_adr_p64 \
helper_sve_adr_s32 \
helper_sve_adr_u32 \
helper_sve_fexpa_h \
helper_sve_fexpa_s \
helper_sve_fexpa_d \
helper_sve_ftssel_h \
helper_sve_ftssel_s \
helper_sve_ftssel_d \
helper_sve_sqaddi_b \
helper_sve_sqaddi_h \
helper_sve_sqaddi_s \
helper_sve_sqaddi_d \
helper_sve_uqaddi_b \
helper_sve_uqaddi_h \
helper_sve_uqaddi_s \
helper_sve_uqaddi_d \
helper_sve_uqsubi_d \
helper_sve_cpy_m_b \
helper_sve_cpy_m_h \
helper_sve_cpy_m_s \
helper_sve_cpy_m_d \
helper_sve_cpy_z_b \
helper_sve_cpy_z_h \
helper_sve_cpy_z_s \
helper_sve_cpy_z_d \
helper_sve_ext \
helper_sve_insr_b \
helper_sve_insr_h \
helper_sve_insr_s \
helper_sve_insr_d \
helper_sve_rev_b \
helper_sve_rev_h \
helper_sve_rev_s \
helper_sve_rev_d \
helper_sve_tbl_b \
helper_sve_tbl_h \
helper_sve_tbl_s \
helper_sve_tbl_d \
helper_sve_sunpk_h \
helper_sve_sunpk_s \
helper_sve_sunpk_d \
helper_sve_uunpk_h \
helper_sve_uunpk_s \
helper_sve_uunpk_d \
helper_sve_zip_p \
helper_sve_uzp_p \
helper_sve_trn_p \
helper_sve_rev_p \
helper_sve_punpk_p \
helper_sve_zip_b \
helper_sve_zip_h \
helper_sve_zip_s \
helper_sve_zip_d \
helper_sve_uzp_b \
helper_sve_uzp_h \
helper_sve_uzp_s \
helper_sve_uzp_d \
helper_sve_trn_b \
helper_sve_trn_h \
helper_sve_trn_s \
helper_sve_trn_d \
helper_sve_compact_s \
helper_sve_compact_d \
helper_sve_last_active_element \
helper_sve_splice \
helper_sve_sel_zpzz_b \
helper_sve_sel_zpzz_h \
helper_sve_sel_zpzz_s \
helper_sve_sel_zpzz_d \
helper_sve_cmpeq_ppzz_b \
helper_sve_cmpeq_ppzz_h \
helper_sve_cmpeq_ppzz_s \
helper_sve_cmpeq_ppzz_d \
helper_sve_cmpne_ppzz_b \
helper_sve_cmpne_ppzz_h \
helper_sve_cmpne_ppzz_s \
helper_sve_cmpne_ppzz_d \
helper_sve_cmpgt_ppzz_b \
helper_sve_cmpgt_ppzz_h \
helper_sve_cmpgt_ppzz_s \
helper_sve_cmpgt_ppzz_d \
helper_sve_cmpge_ppzz_b \
helper_sve_cmpge_ppzz_h \
helper_sve_cmpge_ppzz_s \
helper_sve_cmpge_ppzz_d \
helper_sve_cmphi_ppzz_b \
helper_sve_cmphi_ppzz_h \
helper_sve_cmphi_ppzz_s \
helper_sve_cmphi_ppzz_d \
helper_sve_cmphs_ppzz_b \
helper_sve_cmphs_ppzz_h \
helper_sve_cmphs_ppzz_s \
helper_sve_cmphs_ppzz_d \
helper_sve_cmpeq_ppzw_b \
helper_sve_cmpeq_ppzw_h \
helper_sve_cmpeq_ppzw_s \
helper_sve_cmpne_ppzw_b \
helper_sve_cmpne_ppzw_h \
helper_sve_cmpne_ppzw_s \
helper_sve_cmpgt_ppzw_b \
helper_sve_cmpgt_ppzw_h \
helper_sve_cmpgt_ppzw_s \
helper_sve_cmpge_ppzw_b \
helper_sve_cmpge_ppzw_h \
helper_sve_cmpge_ppzw_s \
helper_sve_cmphi_ppzw_b \
helper_sve_cmphi_ppzw_h \
helper_sve_cmphi_ppzw_s \
helper_sve_cmphs_ppzw_b \
helper_sve_cmphs_ppzw_h \
helper_sve_cmphs_ppzw_s \
helper_sve_cmplt_ppzw_b \
helper_sve_cmplt_ppzw_h \
helper_sve_cmplt_ppzw_s \
helper_sve_cmple_ppzw_b \
helper_sve_cmple_ppzw_h \
helper_sve_cmple_ppzw_s \
helper_sve_cmplo_ppzw_b \
helper_sve_cmplo_ppzw_h \
helper_sve_cmplo_ppzw_s \
helper_sve_cmpls_ppzw_b \
helper_sve_cmpls_ppzw_h \
helper_sve_cmpls_ppzw_s \
helper_sve_cmpeq_ppzi_b \
helper_sve_cmpeq_ppzi_h \
helper_sve_cmpeq_ppzi_s \
helper_sve_cmpeq_ppzi_d \
helper_sve_cmpne_ppzi_b \
helper_sve_cmpne_ppzi_h \
helper_sve_cmpne_ppzi_s \
helper_sve_cmpne_ppzi_d \
helper_sve_cmpgt_ppzi_b \
helper_sve_cmpgt_ppzi_h \
helper_sve_cmpgt_ppzi_s \
helper_sve_cmpgt_ppzi_d \
helper_sve_cmpge_ppzi_b \
helper_sve_cmpge_ppzi_h \
helper_sve_cmpge_ppzi_s \
helper_sve_cmpge_ppzi_d \
helper_sve_cmphi_ppzi_b \
helper_sve_cmphi_ppzi_h \
helper_sve_cmphi_ppzi_s \
helper_sve_cmphi_ppzi_d \
helper_sve_cmphs_ppzi_b \
helper_sve_cmphs_ppzi_h \
helper_sve_cmphs_ppzi_s \
helper_sve_cmphs_ppzi_d \
helper_sve_cmplt_ppzi_b \
helper_sve_cmplt_ppzi_h \
helper_sve_cmplt_ppzi_s \
helper_sve_cmplt_ppzi_d \
helper_sve_cmple_ppzi_b \
helper_sve_cmple_ppzi_h \
helper_sve_cmple_ppzi_s \
helper_sve_cmple_ppzi_d \
helper_sve_cmplo_ppzi_b \
helper_sve_cmplo_ppzi_h \
helper_sve_cmplo_ppzi_s \
helper_sve_cmplo_ppzi_d \
helper_sve_cmpls_ppzi_b \
helper_sve_cmpls_ppzi_h \
helper_sve_cmpls_ppzi_s \
helper_sve_cmpls_ppzi_d \
helper_sve_brkpa \
helper_sve_brkpas \
helper_sve_brkpb \
helper_sve_brkpbs \
helper_sve_brka_z \
helper_sve_brkas_z \
helper_sve_brkb_z \
helper_sve_brkbs_z \
helper_sve_brka_m \
helper_sve_brkas_m \
helper_sve_brkb_m \
helper_sve_brkbs_m \
helper_sve_brkn \
helper_sve_brkns \
helper_sve_cntp \
helper_sve_while \
helper_sve_faddv_h \
helper_sve_faddv_s \
helper_sve_faddv_d \
helper_sve_fminnmv_h \
helper_sve_fminnmv_s \
helper_sve_fminnmv_d \
helper_sve_fmaxnmv_h \
helper_sve_fmaxnmv_s \
helper_sve_fmaxnmv_d \
helper_sve_fminv_h \
helper_sve_fminv_s \
helper_sve_fminv_d \
helper_sve_fmaxv_h \
helper_sve_fmaxv_s \
helper_sve_fmaxv_d \
helper_sve_fadda_h \
helper_sve_fadda_s \
helper_sve_fadda_d \
helper_sve_fadd_h \
helper_sve_fadd_s \
helper_sve_fadd_d \
helper_sve_fsub_h \
helper_sve_fsub_s \
helper_sve_fsub_d \
helper_sve_fmul_h \
helper_sve_fmul_s \
helper_sve_fmul_d \
helper_sve_fdiv_h \
helper_sve_fdiv_s \
helper_sve_fdiv_d \
helper_sve_fmin_h \
helper_sve_fmin_s \
helper_sve_fmin_d \
helper_sve_fmax_h \
helper_sve_fmax_s \
helper_sve_fmax_d \
helper_sve_fminnum_h \
helper_sve_fminnum_s \
helper_sve_fminnum_d \
helper_sve_fmaxnum_h \
helper_sve_fmaxnum_s \
helper_sve_fmaxnum_d \
helper_sve_fabd_h \
helper_sve_fabd_s \
helper_sve_fabd_d \
helper_sve_fscalbn_h \
helper_sve_fscalbn_s \
helper_sve_fscalbn_d \
helper_sve_fmulx_h \
helper_sve_fmulx_s \
helper_sve_fmulx_d \
helper_sve_fadds_h \
helper_sve_fadds_s \
helper_sve_fadds_d \
helper_sve_fsubs_h \
helper_sve_fsubs_s \
helper_sve_fsubs_d \
helper_sve_fmuls_h \
helper_sve_fmuls_s \
helper_sve_fmuls_d \
helper_sve_fsubrs_h \
helper_sve_fsubrs_s \
helper_sve_fsubrs_d \
helper_sve_fmaxnms_h \
helper_sve_fmaxnms_s \
helper_sve_fmaxnms_d \
helper_sve_fminnms_h \
helper_sve_fminnms_s \
helper_sve_fminnms_d \
helper_sve_fmaxs_h \
helper_sve_fmaxs_s \
helper_sve_fmaxs_d \
helper_sve_fmins_h \
helper_sve_fmins_s \
helper_sve_fmins_d \
helper_sve_fcvt_sh \
helper_sve_fcvt_hs \
helper_sve_fcvt_dh \
helper_sve_fcvt_hd \
helper_sve_fcvt_ds \
helper_sve_fcvt_sd \
helper_sve_fcvtzs_hh \
helper_sve_fcvtzs_hs \
helper_sve_fcvtzs_ss \
helper_sve_fcvtzs_hd \
helper_sve_fcvtzs_sd \
helper_sve_fcvtzs_ds \
helper_sve_fcvtzs_dd \
helper_sve_fcvtzu_hh \
helper_sve_fcvtzu_hs \
helper_sve_fcvtzu_ss \
helper_sve_fcvtzu_hd \
helper_sve_fcvtzu_sd \
helper_sve_fcvtzu_ds \
helper_sve_fcvtzu_dd \
helper_sve_frint_h \
helper_sve_frint_s \
helper_sve_frint_d \
helper_sve_frintx_h \
helper_sve_frintx_s \
helper_sve_frintx_d \
helper_sve_frecpx_h \
helper_sve_frecpx_s \
helper_sve_frecpx_d \
helper_sve_fsqrt_h \
helper_sve_fsqrt_s \
helper_sve_fsqrt_d \
helper_sve_scvt_hh \
helper_sve_scvt_sh \
helper_sve_scvt_ss \
helper_sve_scvt_sd \
helper_sve_scvt_dh \
helper_sve_scvt_ds \
helper_sve_scvt_dd \
helper_sve_ucvt_hh \
helper_sve_ucvt_sh \
helper_sve_ucvt_ss \
helper_sve_ucvt_sd \
helper_sve_ucvt_dh \
helper_sve_ucvt_ds \
helper_sve_ucvt_dd \
helper_sve_fmla_zpzzz_h \
helper_sve_fmls_zpzzz_h \
helper_sve_fnmla_zpzzz_h \
helper_sve_fnmls_zpzzz_h \
helper_sve_fmla_zpzzz_s \
helper_sve_fmls_zpzzz_s \
helper_sve_fnmla_zpzzz_s \
helper_sve_fnmls_zpzzz_s \
helper_sve_fmla_zpzzz_d \
helper_sve_fmls_zpzzz_d \
helper_sve_fnmla_zpzzz_d \
helper_sve_fnmls_zpzzz_d \
helper_sve_fcmge_h \
helper_sve_fcmge_s \
helper_sve_fcmge_d \
helper_sve_fcmgt_h \
helper_sve_fcmgt_s \
helper_sve_fcmgt_d \
helper_sve_fcmeq_h \
helper_sve_fcmeq_s \
helper_sve_fcmeq_d \
helper_sve_fcmne_h \
helper_sve_fcmne_s \
helper_sve_fcmne_d \
helper_sve_fcmuo_h \
helper_sve_fcmuo_s \
helper_sve_fcmuo_d \
helper_sve_facge_h \
helper_sve_facge_s \
helper_sve_facge_d \
helper_sve_facgt_h \
helper_sve_facgt_s \
helper_sve_facgt_d \
helper_sve_fcmge0_h \
helper_sve_fcmge0_s \
helper_sve_fcmge0_d \
helper_sve_fcmgt0_h \
helper_sve_fcmgt0_s \
helper_sve_fcmgt0_d \
helper_sve_fcmle0_h \
helper_sve_fcmle0_s \
helper_sve_fcmle0_d \
helper_sve_fcmlt0_h \
helper_sve_fcmlt0_s \
helper_sve_fcmlt0_d \
helper_sve_fcmeq0_h \
helper_sve_fcmeq0_s \
helper_sve_fcmeq0_d \
helper_sve_fcmne0_h \
helper_sve_fcmne0_s \
helper_sve_fcmne0_d \
helper_sve_ftmad_h \
helper_sve_ftmad_s \
helper_sve_ftmad_d \
helper_sve_fcadd_h \
helper_sve_fcadd_s \
helper_sve_fcadd_d \
helper_sve_fcmla_zpzzz_h \
helper_sve_fcmla_zpzzz_s \
helper_sve_fcmla_zpzzz_d \
helper_sve_ld1bb_r \
helper_sve_ld1bhu_r \
helper_sve_ld1bhs_r \
helper_sve_ld1bsu_r \
helper_sve_ld1bss_r \
helper_sve_ld1bdu_r \
helper_sve_ld1bds_r \
helper_sve_ld1hh_le_r \
helper_sve_ld1hh_be_r \
helper_sve_ld1hsu_le_r \
helper_sve_ld1hsu_be_r \
helper_sve_ld1hss_le_r \
helper_sve_ld1hss_be_r \
helper_sve_ld1hdu_le_r \
helper_sve_ld1hdu_be_r \
helper_sve_ld1hds_le_r \
helper_sve_ld1hds_be_r \
helper_sve_ld1ss_le_r \
helper_sve_ld1ss_be_r \
helper_sve_ld1sdu_le_r \
helper_sve_ld1sdu_be_r \
helper_sve_ld1sds_le_r \
helper_sve_ld1sds_be_r \
helper_sve_ld1dd_le_r \
helper_sve_ld1dd_be_r \
helper_sve_ld2bb_r \
helper_sve_ld3bb_r \
helper_sve_ld4bb_r \
helper_sve_ld2hh_le_r \
helper_sve_ld2hh_be_r \
helper_sve_ld3hh_le_r \
helper_sve_ld3hh_be_r \
helper_sve_ld4hh_le_r \
helper_sve_ld4hh_be_r \
helper_sve_ld2ss_le_r \
helper_sve_ld2ss_be_r \
helper_sve_ld3ss_le_r \
helper_sve_ld3ss_be_r \
helper_sve_ld4ss_le_r \
helper_sve_ld4ss_be_r \
helper_sve_ld2dd_le_r \
helper_sve_ld2dd_be_r \
helper_sve_ld3dd_le_r \
helper_sve_ld3dd_be_r \
helper_sve_ld4dd_le_r \
helper_sve_ld4dd_be_r \
helper_sve_ldff1bb_r \
helper_sve_ldnf1bb_r \
helper_sve_ldff1bhu_r \
helper_sve_ldnf1bhu_r \
helper_sve_ldff1bhs_r \
helper_sve_ldnf1bhs_r \
helper_sve_ldff1bsu_r \
helper_sve_ldnf1bsu_r \
helper_sve_ldff1bss_r \
helper_sve_ldnf1bss_r \
helper_sve_ldff1bdu_r \
helper_sve_ldnf1bdu_r \
helper_sve_ldff1bds_r \
helper_sve_ldnf1bds_r \
helper_sve_ldff1hh_le_r \
helper_sve_ldnf1hh_le_r \
helper_sve_ldff1hh_be_r \
helper_sve_ldnf1hh_be_r \
helper_sve_ldff1hsu_le_r \
helper_sve_ldnf1hsu_le_r \
helper_sve_ldff1hsu_be_r \
helper_sve_ldnf1hsu_be_r \
helper_sve_ldff1hss_le_r \
helper_sve_ldnf1hss_le_r \
helper_sve_ldff1hss_be_r \
helper_sve_ldnf1hss_be_r \
helper_sve_ldff1hdu_le_r \
helper_sve_ldnf1hdu_le_r \
helper_sve_ldff1hdu_be_r \
helper_sve_ldnf1hdu_be_r \
helper_sve_ldff1hds_le_r \
helper_sve_ldnf1hds_le_r \
helper_sve_ldff1hds_be_r \
helper_sve_ldnf1hds_be_r \
helper_sve_ldff1ss_le_r \
helper_sve_ldnf1ss_le_r \
helper_sve_ldff1ss_be_r \
helper_sve_ldnf1ss_be_r \
helper_sve_ldff1sdu_le_r \
helper_sve_ldnf1sdu_le_r \
helper_sve_ldff1sdu_be_r \
helper_sve_ldnf1sdu_be_r \
helper_sve_ldff1sds_le_r \
helper_sve_ldnf1sds_le_r \
helper_sve_ldff1sds_be_r \
helper_sve_ldnf1sds_be_r \
helper_sve_ldff1dd_le_r \
helper_sve_ldnf1dd_le_r \
helper_sve_ldff1dd_be_r \
helper_sve_ldnf1dd_be_r \
helper_sve_st1bb_r \
helper_sve_st1bh_r \
helper_sve_st1bs_r \
helper_sve_st1bd_r \
helper_sve_st2bb_r \
helper_sve_st3bb_r \
helper_sve_st4bb_r \
helper_sve_st1hh_le_r \
helper_sve_st1hh_be_r \
helper_sve_st1hs_le_r \
helper_sve_st1hs_be_r \
helper_sve_st1hd_le_r \
helper_sve_st1hd_be_r \
helper_sve_st2hh_le_r \
helper_sve_st2hh_be_r \
helper_sve_st3hh_le_r \
helper_sve_st3hh_be_r \
helper_sve_st4hh_le_r \
helper_sve_st4hh_be_r \
helper_sve_st1ss_le_r \
helper_sve_st1ss_be_r \
helper_sve_st1sd_le_r \
helper_sve_st1sd_be_r \
helper_sve_st2ss_le_r \
helper_sve_st2ss_be_r \
helper_sve_st3ss_le_r \
helper_sve_st3ss_be_r \
helper_sve_st4ss_le_r \
helper_sve_st4ss_be_r \
helper_sve_st1dd_le_r \
helper_sve_st1dd_be_r \
helper_sve_st2dd_le_r \
helper_sve_st2dd_be_r \
helper_sve_st3dd_le_r \
helper_sve_st3dd_be_r \
helper_sve_st4dd_le_r \
helper_sve_st4dd_be_r \
helper_sve_ldbsu_zsu \
helper_sve_ldbsu_zss \
helper_sve_ldbdu_zsu \
helper_sve_ldbdu_zss \
helper_sve_ldbdu_zd \
helper_sve_ldbss_zsu \
helper_sve_ldbss_zss \
helper_sve_ldbds_zsu \
helper_sve_ldbds_zss \
helper_sve_ldbds_zd \
helper_sve_ldhsu_le_zsu \
helper_sve_ldhsu_le_zss \
helper_sve_ldhdu_le_zsu \
helper_sve_ldhdu_le_zss \
helper_sve_ldhdu_le_zd \
helper_sve_ldhsu_be_zsu \
helper_sve_ldhsu_be_zss \
helper_sve_ldhdu_be_zsu \
helper_sve_ldhdu_be_zss \
helper_sve_ldhdu_be_zd \
helper_sve_ldhss_le_zsu \
helper_sve_ldhss_le_zss \
helper_sve_ldhds_le_zsu \
helper_sve_ldhds_le_zss \
helper_sve_ldhds_le_zd \
helper_sve_ldhss_be_zsu \
helper_sve_ldhss_be_zss \
helper_sve_ldhds_be_zsu \
helper_sve_ldhds_be_zss \
helper_sve_ldhds_be_zd \
helper_sve_ldss_le_zsu \
helper_sve_ldss_le_zss \
helper_sve_ldsdu_le_zsu \
helper_sve_ldsdu_le_zss \
helper_sve_ldsdu_le_zd \
helper_sve_ldss_be_zsu \
helper_sve_ldss_be_zss \
helper_sve_ldsdu_be_zsu \
helper_sve_ldsdu_be_zss \
helper_sve_ldsdu_be_zd \
helper_sve_ldsds_le_zsu \
helper_sve_ldsds_le_zss \
helper_sve_ldsds_le_zd \
helper_sve_ldsds_be_zsu \
helper_sve_ldsds_be_zss \
helper_sve_ldsds_be_zd \
helper_sve_lddd_le_zsu \
helper_sve_lddd_le_zss \
helper_sve_lddd_le_zd \
helper_sve_lddd_be_zsu \
helper_sve_lddd_be_zss \
helper_sve_lddd_be_zd \
helper_sve_ldffbsu_zsu \
helper_sve_ldffbsu_zss \
helper_sve_ldffbdu_zsu \
helper_sve_ldffbdu_zss \
helper_sve_ldffbdu_zd \
helper_sve_ldffbss_zsu \
helper_sve_ldffbss_zss \
helper_sve_ldffbds_zsu \
helper_sve_ldffbds_zss \
helper_sve_ldffbds_zd \
helper_sve_ldffhsu_le_zsu \
helper_sve_ldffhsu_le_zss \
helper_sve_ldffhdu_le_zsu \
helper_sve_ldffhdu_le_zss \
helper_sve_ldffhdu_le_zd \
helper_sve_ldffhsu_be_zsu \
helper_sve_ldffhsu_be_zss \
helper_sve_ldffhdu_be_zsu \
helper_sve_ldffhdu_be_zss \
helper_sve_ldffhdu_be_zd \
helper_sve_ldffhss_le_zsu \
helper_sve_ldffhss_le_zss \
helper_sve_ldffhds_le_zsu \
helper_sve_ldffhds_le_zss \
helper_sve_ldffhds_le_zd \
helper_sve_ldffhss_be_zsu \
helper_sve_ldffhss_be_zss \
helper_sve_ldffhds_be_zsu \
helper_sve_ldffhds_be_zss \
helper_sve_ldffhds_be_zd \
helper_sve_ldffss_le_zsu \
helper_sve_ldffss_le_zss \
helper_sve_ldffsdu_le_zsu \
helper_sve_ldffsdu_le_zss \
helper_sve_ldffsdu_le_zd \
helper_sve_ldffss_be_zsu \
helper_sve_ldffss_be_zss \
helper_sve_ldffsdu_be_zsu \
helper_sve_ldffsdu_be_zss \
helper_sve_ldffsdu_be_zd \
helper_sve_ldffsds_le_zsu \
helper_sve_ldffsds_le_zss \
helper_sve_ldffsds_le_zd \
helper_sve_ldffsds_be_zsu \
helper_sve_ldffsds_be_zss \
helper_sve_ldffsds_be_zd \
helper_sve_ldffdd_le_zsu \
helper_sve_ldffdd_le_zss \
helper_sve_ldffdd_le_zd \
helper_sve_ldffdd_be_zsu \
helper_sve_ldffdd_be_zss \
helper_sve_ldffdd_be_zd \
helper_sve_stbs_zsu \
helper_sve_sths_le_zsu \
helper_sve_sths_be_zsu \
helper_sve_stss_le_zsu \
helper_sve_stss_be_zsu \
helper_sve_stbs_zss \
helper_sve_sths_le_zss \
helper_sve_sths_be_zss \
helper_sve_stss_le_zss \
helper_sve_stss_be_zss \
helper_sve_stbd_zsu \
helper_sve_sthd_le_zsu \
helper_sve_sthd_be_zsu \
helper_sve_stsd_le_zsu \
helper_sve_stsd_be_zsu \
helper_sve_stdd_le_zsu \
helper_sve_stdd_be_zsu \
helper_sve_stbd_zss \
helper_sve_sthd_le_zss \
helper_sve_sthd_be_zss \
helper_sve_stsd_le_zss \
helper_sve_stsd_be_zss \
helper_sve_stdd_le_zss \
helper_sve_stdd_be_zss \
helper_sve_stbd_zd \
helper_sve_sthd_le_zd \
helper_sve_sthd_be_zd \
helper_sve_stsd_le_zd \
helper_sve_stsd_be_zd \
helper_sve_stdd_le_zd \
helper_sve_stdd_be_zd \
arm_cpu_do_unaligned_access \
arm_cpu_do_transaction_failed \
arm_cpu_tlb_fill \
a64_translate_init \
gen_a64_set_pc_im \
unallocated_encoding \
new_tmp_a64 \
new_tmp_a64_zero \
cpu_reg \
cpu_reg_sp \
read_cpu_reg \
read_cpu_reg_sp \
write_fp_dreg \
get_fpstatus_ptr \
sve_access_check \
logic_imm_decode_wmask \
arm_translate_init \
arm_test_cc \
arm_free_cc \
arm_jump_cc \
arm_gen_test_cc \
vfp_expand_imm \
gen_cmtst_i64 \
gen_ushl_i32 \
gen_ushl_i64 \
gen_sshl_i32 \
gen_sshl_i64 \
gen_intermediate_code \
restore_state_to_opc \
disas_sve \
helper_neon_qrdmlah_s16 \
helper_gvec_qrdmlah_s16 \
helper_neon_qrdmlsh_s16 \
helper_gvec_qrdmlsh_s16 \
helper_neon_qrdmlah_s32 \
helper_gvec_qrdmlah_s32 \
helper_neon_qrdmlsh_s32 \
helper_gvec_qrdmlsh_s32 \
helper_gvec_sdot_b \
helper_gvec_udot_b \
helper_gvec_sdot_h \
helper_gvec_udot_h \
helper_gvec_sdot_idx_b \
helper_gvec_udot_idx_b \
helper_gvec_sdot_idx_h \
helper_gvec_udot_idx_h \
helper_gvec_fcaddh \
helper_gvec_fcadds \
helper_gvec_fcaddd \
helper_gvec_fcmlah \
helper_gvec_fcmlah_idx \
helper_gvec_fcmlas \
helper_gvec_fcmlas_idx \
helper_gvec_fcmlad \
helper_gvec_frecpe_h \
helper_gvec_frecpe_s \
helper_gvec_frecpe_d \
helper_gvec_frsqrte_h \
helper_gvec_frsqrte_s \
helper_gvec_frsqrte_d \
helper_gvec_fadd_h \
helper_gvec_fadd_s \
helper_gvec_fadd_d \
helper_gvec_fsub_h \
helper_gvec_fsub_s \
helper_gvec_fsub_d \
helper_gvec_fmul_h \
helper_gvec_fmul_s \
helper_gvec_fmul_d \
helper_gvec_ftsmul_h \
helper_gvec_ftsmul_s \
helper_gvec_ftsmul_d \
helper_gvec_recps_h \
helper_gvec_recps_s \
helper_gvec_recps_d \
helper_gvec_rsqrts_h \
helper_gvec_rsqrts_s \
helper_gvec_rsqrts_d \
helper_gvec_fmul_idx_h \
helper_gvec_fmul_idx_s \
helper_gvec_fmul_idx_d \
helper_gvec_fmla_idx_h \
helper_gvec_fmla_idx_s \
helper_gvec_fmla_idx_d \
helper_gvec_uqadd_b \
helper_gvec_uqadd_h \
helper_gvec_uqadd_s \
helper_gvec_sqadd_b \
helper_gvec_sqadd_h \
helper_gvec_sqadd_s \
helper_gvec_uqsub_b \
helper_gvec_uqsub_h \
helper_gvec_uqsub_s \
helper_gvec_sqsub_b \
helper_gvec_sqsub_h \
helper_gvec_sqsub_s \
helper_gvec_uqadd_d \
helper_gvec_uqsub_d \
helper_gvec_sqadd_d \
helper_gvec_sqsub_d \
helper_gvec_fmlal_a32 \
helper_gvec_fmlal_a64 \
helper_gvec_fmlal_idx_a32 \
helper_gvec_fmlal_idx_a64 \
helper_gvec_sshl_b \
helper_gvec_sshl_h \
helper_gvec_ushl_b \
helper_gvec_ushl_h \
helper_gvec_pmul_b \
helper_gvec_pmull_q \
helper_neon_pmull_h \
helper_sve2_pmull_h \
helper_vfp_get_fpscr \
vfp_get_fpscr \
helper_vfp_set_fpscr \
vfp_set_fpscr \
helper_vfp_adds \
helper_vfp_addd \
helper_vfp_subs \
helper_vfp_subd \
helper_vfp_muls \
helper_vfp_muld \
helper_vfp_divs \
helper_vfp_divd \
helper_vfp_mins \
helper_vfp_mind \
helper_vfp_maxs \
helper_vfp_maxd \
helper_vfp_minnums \
helper_vfp_minnumd \
helper_vfp_maxnums \
helper_vfp_maxnumd \
helper_vfp_negs \
helper_vfp_negd \
helper_vfp_abss \
helper_vfp_absd \
helper_vfp_sqrts \
helper_vfp_sqrtd \
helper_vfp_cmps \
helper_vfp_cmpes \
helper_vfp_cmpd \
helper_vfp_cmped \
helper_vfp_sitoh \
helper_vfp_tosih \
helper_vfp_tosizh \
helper_vfp_sitos \
helper_vfp_tosis \
helper_vfp_tosizs \
helper_vfp_sitod \
helper_vfp_tosid \
helper_vfp_tosizd \
helper_vfp_uitoh \
helper_vfp_touih \
helper_vfp_touizh \
helper_vfp_uitos \
helper_vfp_touis \
helper_vfp_touizs \
helper_vfp_uitod \
helper_vfp_touid \
helper_vfp_touizd \
helper_vfp_fcvtds \
helper_vfp_fcvtsd \
helper_vfp_shtod \
helper_vfp_toshd_round_to_zero \
helper_vfp_toshd \
helper_vfp_sltod \
helper_vfp_tosld_round_to_zero \
helper_vfp_tosld \
helper_vfp_sqtod \
helper_vfp_tosqd \
helper_vfp_uhtod \
helper_vfp_touhd_round_to_zero \
helper_vfp_touhd \
helper_vfp_ultod \
helper_vfp_tould_round_to_zero \
helper_vfp_tould \
helper_vfp_uqtod \
helper_vfp_touqd \
helper_vfp_shtos \
helper_vfp_toshs_round_to_zero \
helper_vfp_toshs \
helper_vfp_sltos \
helper_vfp_tosls_round_to_zero \
helper_vfp_tosls \
helper_vfp_sqtos \
helper_vfp_tosqs \
helper_vfp_uhtos \
helper_vfp_touhs_round_to_zero \
helper_vfp_touhs \
helper_vfp_ultos \
helper_vfp_touls_round_to_zero \
helper_vfp_touls \
helper_vfp_uqtos \
helper_vfp_touqs \
helper_vfp_sltoh \
helper_vfp_ultoh \
helper_vfp_sqtoh \
helper_vfp_uqtoh \
helper_vfp_toshh \
helper_vfp_touhh \
helper_vfp_toslh \
helper_vfp_toulh \
helper_vfp_tosqh \
helper_vfp_touqh \
helper_set_rmode \
helper_set_neon_rmode \
helper_vfp_fcvt_f16_to_f32 \
helper_vfp_fcvt_f32_to_f16 \
helper_vfp_fcvt_f16_to_f64 \
helper_vfp_fcvt_f64_to_f16 \
helper_recps_f32 \
helper_rsqrts_f32 \
helper_recpe_f16 \
helper_recpe_f32 \
helper_recpe_f64 \
helper_rsqrte_f16 \
helper_rsqrte_f32 \
helper_rsqrte_f64 \
helper_recpe_u32 \
helper_rsqrte_u32 \
helper_vfp_muladds \
helper_vfp_muladdd \
helper_rints_exact \
helper_rintd_exact \
helper_rints \
helper_rintd \
arm_rmode_to_sf \
helper_fjcvtzs \
helper_vjcvt \
helper_frint32_s \
helper_frint64_s \
helper_frint32_d \
helper_frint64_d \
helper_check_hcr_el2_trap \
mla_op \
mls_op \
sshl_op \
ushl_op \
uqsub_op \
sqsub_op \
uqadd_op \
sqadd_op \
sli_op \
cmtst_op \
sri_op \
usra_op \
ssra_op \
aarch64_translator_ops \
pred_esz_masks \
helper_uc_hooksys64 \
"

riscv32_SYMBOLS="
riscv_cpu_mmu_index \
riscv_cpu_exec_interrupt \
riscv_cpu_fp_enabled \
riscv_cpu_swap_hypervisor_regs \
riscv_cpu_virt_enabled \
riscv_cpu_set_virt_enabled \
riscv_cpu_force_hs_excep_enabled \
riscv_cpu_set_force_hs_excep \
riscv_cpu_claim_interrupts \
riscv_cpu_update_mip \
riscv_cpu_set_rdtime_fn \
riscv_cpu_set_mode \
riscv_cpu_get_phys_page_debug \
riscv_cpu_do_transaction_failed \
riscv_cpu_do_unaligned_access \
riscv_cpu_tlb_fill \
riscv_cpu_do_interrupt \
riscv_get_csr_ops \
riscv_set_csr_ops \
riscv_csrrw \
riscv_csrrw_debug \
riscv_cpu_get_fflags \
riscv_cpu_set_fflags \
helper_set_rounding_mode \
helper_fmadd_s \
helper_fmadd_d \
helper_fmsub_s \
helper_fmsub_d \
helper_fnmsub_s \
helper_fnmsub_d \
helper_fnmadd_s \
helper_fnmadd_d \
helper_fadd_s \
helper_fsub_s \
helper_fmul_s \
helper_fdiv_s \
helper_fmin_s \
helper_fmax_s \
helper_fsqrt_s \
helper_fle_s \
helper_flt_s \
helper_feq_s \
helper_fcvt_w_s \
helper_fcvt_wu_s \
helper_fcvt_s_w \
helper_fcvt_s_wu \
helper_fclass_s \
helper_fadd_d \
helper_fsub_d \
helper_fmul_d \
helper_fdiv_d \
helper_fmin_d \
helper_fmax_d \
helper_fcvt_s_d \
helper_fcvt_d_s \
helper_fsqrt_d \
helper_fle_d \
helper_flt_d \
helper_feq_d \
helper_fcvt_w_d \
helper_fcvt_wu_d \
helper_fcvt_d_w \
helper_fcvt_d_wu \
helper_fclass_d \
riscv_raise_exception \
helper_raise_exception \
helper_uc_riscv_exit \
helper_csrrw \
helper_csrrs \
helper_csrrc \
helper_sret \
helper_mret \
helper_wfi \
helper_tlb_flush \
pmp_hart_has_privs \
pmpcfg_csr_write \
pmpcfg_csr_read \
pmpaddr_csr_write \
pmpaddr_csr_read \
gen_intermediate_code \
riscv_translate_init \
restore_state_to_opc \
cpu_riscv_init \
helper_fcvt_l_s \
helper_fcvt_lu_s \
helper_fcvt_s_l \
helper_fcvt_s_lu \
helper_fcvt_l_d \
helper_fcvt_lu_d \
helper_fcvt_d_l \
helper_fcvt_d_lu \
gen_helper_tlb_flush \
riscv_fpr_regnames \
riscv_int_regnames \
"

riscv64_SYMBOLS=${riscv32_SYMBOLS}

mips_SYMBOLS="
helper_mfc0_mvpcontrol \
helper_mfc0_mvpconf0 \
helper_mfc0_mvpconf1 \
helper_mfc0_random \
helper_mfc0_tcstatus \
helper_mftc0_tcstatus \
helper_mfc0_tcbind \
helper_mftc0_tcbind \
helper_mfc0_tcrestart \
helper_mftc0_tcrestart \
helper_mfc0_tchalt \
helper_mftc0_tchalt \
helper_mfc0_tccontext \
helper_mftc0_tccontext \
helper_mfc0_tcschedule \
helper_mftc0_tcschedule \
helper_mfc0_tcschefback \
helper_mftc0_tcschefback \
helper_mfc0_count \
helper_mfc0_saar \
helper_mfhc0_saar \
helper_mftc0_entryhi \
helper_mftc0_cause \
helper_mftc0_status \
helper_mfc0_lladdr \
helper_mfc0_maar \
helper_mfhc0_maar \
helper_mfc0_watchlo \
helper_mfc0_watchhi \
helper_mfhc0_watchhi \
helper_mfc0_debug \
helper_mftc0_debug \
helper_dmfc0_tcrestart \
helper_dmfc0_tchalt \
helper_dmfc0_tccontext \
helper_dmfc0_tcschedule \
helper_dmfc0_tcschefback \
helper_dmfc0_lladdr \
helper_dmfc0_maar \
helper_dmfc0_watchlo \
helper_dmfc0_watchhi \
helper_dmfc0_saar \
helper_mtc0_index \
helper_mtc0_mvpcontrol \
helper_mtc0_vpecontrol \
helper_mttc0_vpecontrol \
helper_mftc0_vpecontrol \
helper_mftc0_vpeconf0 \
helper_mtc0_vpeconf0 \
helper_mttc0_vpeconf0 \
helper_mtc0_vpeconf1 \
helper_mtc0_yqmask \
helper_mtc0_vpeopt \
helper_mtc0_entrylo0 \
helper_dmtc0_entrylo0 \
helper_mtc0_tcstatus \
helper_mttc0_tcstatus \
helper_mtc0_tcbind \
helper_mttc0_tcbind \
helper_mtc0_tcrestart \
helper_mttc0_tcrestart \
helper_mtc0_tchalt \
helper_mttc0_tchalt \
helper_mtc0_tccontext \
helper_mttc0_tccontext \
helper_mtc0_tcschedule \
helper_mttc0_tcschedule \
helper_mtc0_tcschefback \
helper_mttc0_tcschefback \
helper_mtc0_entrylo1 \
helper_dmtc0_entrylo1 \
helper_mtc0_context \
helper_mtc0_memorymapid \
update_pagemask \
helper_mtc0_pagemask \
helper_mtc0_pagegrain \
helper_mtc0_segctl0 \
helper_mtc0_segctl1 \
helper_mtc0_segctl2 \
helper_mtc0_pwfield \
helper_mtc0_pwsize \
helper_mtc0_wired \
helper_mtc0_pwctl \
helper_mtc0_srsconf0 \
helper_mtc0_srsconf1 \
helper_mtc0_srsconf2 \
helper_mtc0_srsconf3 \
helper_mtc0_srsconf4 \
helper_mtc0_hwrena \
helper_mtc0_count \
helper_mtc0_saari \
helper_mtc0_saar \
helper_mthc0_saar \
helper_mtc0_entryhi \
helper_mttc0_entryhi \
helper_mtc0_compare \
helper_mtc0_status \
helper_mttc0_status \
helper_mtc0_intctl \
helper_mtc0_srsctl \
helper_mtc0_cause \
helper_mttc0_cause \
helper_mftc0_epc \
helper_mftc0_ebase \
helper_mtc0_ebase \
helper_mttc0_ebase \
helper_mftc0_configx \
helper_mtc0_config0 \
helper_mtc0_config2 \
helper_mtc0_config3 \
helper_mtc0_config4 \
helper_mtc0_config5 \
helper_mtc0_lladdr \
helper_mtc0_maar \
helper_mthc0_maar \
helper_mtc0_maari \
helper_mtc0_watchlo \
helper_mtc0_watchhi \
helper_mthc0_watchhi \
helper_mtc0_xcontext \
helper_mtc0_framemask \
helper_mtc0_debug \
helper_mttc0_debug \
helper_mtc0_performance0 \
helper_mtc0_errctl \
helper_mtc0_taglo \
helper_mtc0_datalo \
helper_mtc0_taghi \
helper_mtc0_datahi \
helper_mftgpr \
helper_mftlo \
helper_mfthi \
helper_mftacx \
helper_mftdsp \
helper_mttgpr \
helper_mttlo \
helper_mtthi \
helper_mttacx \
helper_mttdsp \
helper_dmt \
helper_emt \
helper_dvpe \
helper_evpe \
helper_dvp \
helper_evp \
cpu_mips_get_random \
cpu_mips_init \
helper_absq_s_ph \
helper_absq_s_qb \
helper_absq_s_w \
helper_absq_s_ob \
helper_absq_s_qh \
helper_absq_s_pw \
helper_addqh_ph \
helper_addqh_r_ph \
helper_addqh_r_w \
helper_addqh_w \
helper_adduh_qb \
helper_adduh_r_qb \
helper_subqh_ph \
helper_subqh_r_ph \
helper_subqh_r_w \
helper_subqh_w \
helper_addq_ph \
helper_addq_s_ph \
helper_addq_s_w \
helper_addu_ph \
helper_addu_qb \
helper_addu_s_ph \
helper_addu_s_qb \
helper_subq_ph \
helper_subq_s_ph \
helper_subq_s_w \
helper_subu_ph \
helper_subu_qb \
helper_subu_s_ph \
helper_subu_s_qb \
helper_adduh_ob \
helper_adduh_r_ob \
helper_subuh_ob \
helper_subuh_r_ob \
helper_addq_pw \
helper_addq_qh \
helper_addq_s_pw \
helper_addq_s_qh \
helper_addu_ob \
helper_addu_qh \
helper_addu_s_ob \
helper_addu_s_qh \
helper_subq_pw \
helper_subq_qh \
helper_subq_s_pw \
helper_subq_s_qh \
helper_subu_ob \
helper_subu_qh \
helper_subu_s_ob \
helper_subu_s_qh \
helper_subuh_qb \
helper_subuh_r_qb \
helper_addsc \
helper_addwc \
helper_modsub \
helper_raddu_w_qb \
helper_raddu_l_ob \
helper_precr_qb_ph \
helper_precrq_qb_ph \
helper_precr_sra_ph_w \
helper_precr_sra_r_ph_w \
helper_precrq_ph_w \
helper_precrq_rs_ph_w \
helper_precr_ob_qh \
helper_precr_sra_qh_pw \
helper_precr_sra_r_qh_pw \
helper_precrq_ob_qh \
helper_precrq_qh_pw \
helper_precrq_rs_qh_pw \
helper_precrq_pw_l \
helper_precrqu_s_qb_ph \
helper_precrqu_s_ob_qh \
helper_preceq_pw_qhl \
helper_preceq_pw_qhr \
helper_preceq_pw_qhla \
helper_preceq_pw_qhra \
helper_precequ_ph_qbl \
helper_precequ_ph_qbr \
helper_precequ_ph_qbla \
helper_precequ_ph_qbra \
helper_precequ_qh_obl \
helper_precequ_qh_obr \
helper_precequ_qh_obla \
helper_precequ_qh_obra \
helper_preceu_ph_qbl \
helper_preceu_ph_qbr \
helper_preceu_ph_qbla \
helper_preceu_ph_qbra \
helper_preceu_qh_obl \
helper_preceu_qh_obr \
helper_preceu_qh_obla \
helper_preceu_qh_obra \
helper_shll_qb \
helper_shrl_qb \
helper_shra_qb \
helper_shra_r_qb \
helper_shll_ob \
helper_shrl_ob \
helper_shra_ob \
helper_shra_r_ob \
helper_shll_ph \
helper_shll_s_ph \
helper_shll_qh \
helper_shll_s_qh \
helper_shrl_qh \
helper_shra_qh \
helper_shra_r_qh \
helper_shll_s_w \
helper_shra_r_w \
helper_shll_pw \
helper_shll_s_pw \
helper_shra_pw \
helper_shra_r_pw \
helper_shrl_ph \
helper_shra_ph \
helper_shra_r_ph \
helper_muleu_s_ph_qbl \
helper_muleu_s_ph_qbr \
helper_mulq_rs_ph \
helper_mul_ph \
helper_mul_s_ph \
helper_mulq_s_ph \
helper_muleq_s_w_phl \
helper_muleq_s_w_phr \
helper_mulsaq_s_w_ph \
helper_mulsa_w_ph \
helper_muleu_s_qh_obl \
helper_muleu_s_qh_obr \
helper_mulq_rs_qh \
helper_muleq_s_pw_qhl \
helper_muleq_s_pw_qhr \
helper_mulsaq_s_w_qh \
helper_dpau_h_qbl \
helper_dpau_h_qbr \
helper_dpsu_h_qbl \
helper_dpsu_h_qbr \
helper_dpau_h_obl \
helper_dpau_h_obr \
helper_dpsu_h_obl \
helper_dpsu_h_obr \
helper_dpa_w_ph \
helper_dpax_w_ph \
helper_dps_w_ph \
helper_dpsx_w_ph \
helper_dpaq_s_w_ph \
helper_dpaqx_s_w_ph \
helper_dpsq_s_w_ph \
helper_dpsqx_s_w_ph \
helper_dpaqx_sa_w_ph \
helper_dpsqx_sa_w_ph \
helper_dpa_w_qh \
helper_dpaq_s_w_qh \
helper_dps_w_qh \
helper_dpsq_s_w_qh \
helper_dpaq_sa_l_w \
helper_dpsq_sa_l_w \
helper_dpaq_sa_l_pw \
helper_dpsq_sa_l_pw \
helper_mulsaq_s_l_pw \
helper_maq_s_w_phl \
helper_maq_s_w_phr \
helper_maq_sa_w_phl \
helper_maq_sa_w_phr \
helper_mulq_s_w \
helper_mulq_rs_w \
helper_maq_s_w_qhll \
helper_maq_s_w_qhlr \
helper_maq_s_w_qhrl \
helper_maq_s_w_qhrr \
helper_maq_sa_w_qhll \
helper_maq_sa_w_qhlr \
helper_maq_sa_w_qhrl \
helper_maq_sa_w_qhrr \
helper_maq_s_l_pwl \
helper_maq_s_l_pwr \
helper_dmadd \
helper_dmaddu \
helper_dmsub \
helper_dmsubu \
helper_bitrev \
helper_insv \
helper_dinsv \
helper_cmpgu_eq_qb \
helper_cmpgu_lt_qb \
helper_cmpgu_le_qb \
helper_cmpgu_eq_ob \
helper_cmpgu_lt_ob \
helper_cmpgu_le_ob \
helper_cmpu_eq_qb \
helper_cmpu_lt_qb \
helper_cmpu_le_qb \
helper_cmp_eq_ph \
helper_cmp_lt_ph \
helper_cmp_le_ph \
helper_cmpu_eq_ob \
helper_cmpu_lt_ob \
helper_cmpu_le_ob \
helper_cmp_eq_qh \
helper_cmp_lt_qh \
helper_cmp_le_qh \
helper_cmp_eq_pw \
helper_cmp_lt_pw \
helper_cmp_le_pw \
helper_cmpgdu_eq_ob \
helper_cmpgdu_lt_ob \
helper_cmpgdu_le_ob \
helper_pick_qb \
helper_pick_ph \
helper_pick_ob \
helper_pick_qh \
helper_pick_pw \
helper_packrl_ph \
helper_packrl_pw \
helper_extr_w \
helper_extr_r_w \
helper_extr_rs_w \
helper_dextr_w \
helper_dextr_r_w \
helper_dextr_rs_w \
helper_dextr_l \
helper_dextr_r_l \
helper_dextr_rs_l \
helper_extr_s_h \
helper_dextr_s_h \
helper_extp \
helper_extpdp \
helper_dextp \
helper_dextpdp \
helper_shilo \
helper_dshilo \
helper_mthlip \
helper_dmthlip \
cpu_wrdsp \
helper_wrdsp \
cpu_rddsp \
helper_rddsp \
helper_cfc1 \
helper_ctc1 \
ieee_ex_to_mips \
helper_float_sqrt_d \
helper_float_sqrt_s \
helper_float_cvtd_s \
helper_float_cvtd_w \
helper_float_cvtd_l \
helper_float_cvt_l_d \
helper_float_cvt_l_s \
helper_float_cvtps_pw \
helper_float_cvtpw_ps \
helper_float_cvts_d \
helper_float_cvts_w \
helper_float_cvts_l \
helper_float_cvts_pl \
helper_float_cvts_pu \
helper_float_cvt_w_s \
helper_float_cvt_w_d \
helper_float_round_l_d \
helper_float_round_l_s \
helper_float_round_w_d \
helper_float_round_w_s \
helper_float_trunc_l_d \
helper_float_trunc_l_s \
helper_float_trunc_w_d \
helper_float_trunc_w_s \
helper_float_ceil_l_d \
helper_float_ceil_l_s \
helper_float_ceil_w_d \
helper_float_ceil_w_s \
helper_float_floor_l_d \
helper_float_floor_l_s \
helper_float_floor_w_d \
helper_float_floor_w_s \
helper_float_cvt_2008_l_d \
helper_float_cvt_2008_l_s \
helper_float_cvt_2008_w_d \
helper_float_cvt_2008_w_s \
helper_float_round_2008_l_d \
helper_float_round_2008_l_s \
helper_float_round_2008_w_d \
helper_float_round_2008_w_s \
helper_float_trunc_2008_l_d \
helper_float_trunc_2008_l_s \
helper_float_trunc_2008_w_d \
helper_float_trunc_2008_w_s \
helper_float_ceil_2008_l_d \
helper_float_ceil_2008_l_s \
helper_float_ceil_2008_w_d \
helper_float_ceil_2008_w_s \
helper_float_floor_2008_l_d \
helper_float_floor_2008_l_s \
helper_float_floor_2008_w_d \
helper_float_floor_2008_w_s \
helper_float_abs_d \
helper_float_abs_s \
helper_float_abs_ps \
helper_float_chs_d \
helper_float_chs_s \
helper_float_chs_ps \
helper_float_recip_d \
helper_float_recip_s \
helper_float_rsqrt_d \
helper_float_rsqrt_s \
helper_float_recip1_d \
helper_float_recip1_s \
helper_float_recip1_ps \
helper_float_rsqrt1_d \
helper_float_rsqrt1_s \
helper_float_rsqrt1_ps \
helper_float_rint_s \
helper_float_rint_d \
float_class_s \
helper_float_class_s \
float_class_d \
helper_float_class_d \
helper_float_add_d \
helper_float_add_s \
helper_float_add_ps \
helper_float_sub_d \
helper_float_sub_s \
helper_float_sub_ps \
helper_float_mul_d \
helper_float_mul_s \
helper_float_mul_ps \
helper_float_div_d \
helper_float_div_s \
helper_float_div_ps \
helper_float_recip2_d \
helper_float_recip2_s \
helper_float_recip2_ps \
helper_float_rsqrt2_d \
helper_float_rsqrt2_s \
helper_float_rsqrt2_ps \
helper_float_addr_ps \
helper_float_mulr_ps \
helper_float_max_s \
helper_float_max_d \
helper_float_maxa_s \
helper_float_maxa_d \
helper_float_min_s \
helper_float_min_d \
helper_float_mina_s \
helper_float_mina_d \
helper_float_madd_d \
helper_float_madd_s \
helper_float_madd_ps \
helper_float_msub_d \
helper_float_msub_s \
helper_float_msub_ps \
helper_float_nmadd_d \
helper_float_nmadd_s \
helper_float_nmadd_ps \
helper_float_nmsub_d \
helper_float_nmsub_s \
helper_float_nmsub_ps \
helper_float_maddf_s \
helper_float_maddf_d \
helper_float_msubf_s \
helper_float_msubf_d \
helper_cmp_d_f \
helper_cmpabs_d_f \
helper_cmp_d_un \
helper_cmpabs_d_un \
helper_cmp_d_eq \
helper_cmpabs_d_eq \
helper_cmp_d_ueq \
helper_cmpabs_d_ueq \
helper_cmp_d_olt \
helper_cmpabs_d_olt \
helper_cmp_d_ult \
helper_cmpabs_d_ult \
helper_cmp_d_ole \
helper_cmpabs_d_ole \
helper_cmp_d_ule \
helper_cmpabs_d_ule \
helper_cmp_d_sf \
helper_cmpabs_d_sf \
helper_cmp_d_ngle \
helper_cmpabs_d_ngle \
helper_cmp_d_seq \
helper_cmpabs_d_seq \
helper_cmp_d_ngl \
helper_cmpabs_d_ngl \
helper_cmp_d_lt \
helper_cmpabs_d_lt \
helper_cmp_d_nge \
helper_cmpabs_d_nge \
helper_cmp_d_le \
helper_cmpabs_d_le \
helper_cmp_d_ngt \
helper_cmpabs_d_ngt \
helper_cmp_s_f \
helper_cmpabs_s_f \
helper_cmp_s_un \
helper_cmpabs_s_un \
helper_cmp_s_eq \
helper_cmpabs_s_eq \
helper_cmp_s_ueq \
helper_cmpabs_s_ueq \
helper_cmp_s_olt \
helper_cmpabs_s_olt \
helper_cmp_s_ult \
helper_cmpabs_s_ult \
helper_cmp_s_ole \
helper_cmpabs_s_ole \
helper_cmp_s_ule \
helper_cmpabs_s_ule \
helper_cmp_s_sf \
helper_cmpabs_s_sf \
helper_cmp_s_ngle \
helper_cmpabs_s_ngle \
helper_cmp_s_seq \
helper_cmpabs_s_seq \
helper_cmp_s_ngl \
helper_cmpabs_s_ngl \
helper_cmp_s_lt \
helper_cmpabs_s_lt \
helper_cmp_s_nge \
helper_cmpabs_s_nge \
helper_cmp_s_le \
helper_cmpabs_s_le \
helper_cmp_s_ngt \
helper_cmpabs_s_ngt \
helper_cmp_ps_f \
helper_cmpabs_ps_f \
helper_cmp_ps_un \
helper_cmpabs_ps_un \
helper_cmp_ps_eq \
helper_cmpabs_ps_eq \
helper_cmp_ps_ueq \
helper_cmpabs_ps_ueq \
helper_cmp_ps_olt \
helper_cmpabs_ps_olt \
helper_cmp_ps_ult \
helper_cmpabs_ps_ult \
helper_cmp_ps_ole \
helper_cmpabs_ps_ole \
helper_cmp_ps_ule \
helper_cmpabs_ps_ule \
helper_cmp_ps_sf \
helper_cmpabs_ps_sf \
helper_cmp_ps_ngle \
helper_cmpabs_ps_ngle \
helper_cmp_ps_seq \
helper_cmpabs_ps_seq \
helper_cmp_ps_ngl \
helper_cmpabs_ps_ngl \
helper_cmp_ps_lt \
helper_cmpabs_ps_lt \
helper_cmp_ps_nge \
helper_cmpabs_ps_nge \
helper_cmp_ps_le \
helper_cmpabs_ps_le \
helper_cmp_ps_ngt \
helper_cmpabs_ps_ngt \
helper_r6_cmp_d_af \
helper_r6_cmp_d_un \
helper_r6_cmp_d_eq \
helper_r6_cmp_d_ueq \
helper_r6_cmp_d_lt \
helper_r6_cmp_d_ult \
helper_r6_cmp_d_le \
helper_r6_cmp_d_ule \
helper_r6_cmp_d_saf \
helper_r6_cmp_d_sun \
helper_r6_cmp_d_seq \
helper_r6_cmp_d_sueq \
helper_r6_cmp_d_slt \
helper_r6_cmp_d_sult \
helper_r6_cmp_d_sle \
helper_r6_cmp_d_sule \
helper_r6_cmp_d_or \
helper_r6_cmp_d_une \
helper_r6_cmp_d_ne \
helper_r6_cmp_d_sor \
helper_r6_cmp_d_sune \
helper_r6_cmp_d_sne \
helper_r6_cmp_s_af \
helper_r6_cmp_s_un \
helper_r6_cmp_s_eq \
helper_r6_cmp_s_ueq \
helper_r6_cmp_s_lt \
helper_r6_cmp_s_ult \
helper_r6_cmp_s_le \
helper_r6_cmp_s_ule \
helper_r6_cmp_s_saf \
helper_r6_cmp_s_sun \
helper_r6_cmp_s_seq \
helper_r6_cmp_s_sueq \
helper_r6_cmp_s_slt \
helper_r6_cmp_s_sult \
helper_r6_cmp_s_sle \
helper_r6_cmp_s_sule \
helper_r6_cmp_s_or \
helper_r6_cmp_s_une \
helper_r6_cmp_s_ne \
helper_r6_cmp_s_sor \
helper_r6_cmp_s_sune \
helper_r6_cmp_s_sne \
no_mmu_map_address \
fixed_mmu_map_address \
r4k_map_address \
cpu_mips_tlb_flush \
sync_c0_status \
cpu_mips_store_status \
cpu_mips_store_cause \
mips_cpu_get_phys_page_debug \
mips_cpu_tlb_fill \
cpu_mips_translate_address \
exception_resume_pc \
mips_cpu_do_interrupt \
mips_cpu_exec_interrupt \
r4k_invalidate_tlb \
do_raise_exception_err \
helper_paddsb \
helper_paddusb \
helper_paddsh \
helper_paddush \
helper_paddb \
helper_paddh \
helper_paddw \
helper_psubsb \
helper_psubusb \
helper_psubsh \
helper_psubush \
helper_psubb \
helper_psubh \
helper_psubw \
helper_pshufh \
helper_packsswh \
helper_packsshb \
helper_packushb \
helper_punpcklwd \
helper_punpckhwd \
helper_punpcklhw \
helper_punpckhhw \
helper_punpcklbh \
helper_punpckhbh \
helper_pavgh \
helper_pavgb \
helper_pmaxsh \
helper_pminsh \
helper_pmaxub \
helper_pminub \
helper_pcmpeqw \
helper_pcmpgtw \
helper_pcmpeqh \
helper_pcmpgth \
helper_pcmpeqb \
helper_pcmpgtb \
helper_psllw \
helper_psrlw \
helper_psraw \
helper_psllh \
helper_psrlh \
helper_psrah \
helper_pmullh \
helper_pmulhh \
helper_pmulhuh \
helper_pmaddhw \
helper_pasubub \
helper_biadd \
helper_pmovmskb \
helper_msa_nloc_b \
helper_msa_nloc_h \
helper_msa_nloc_w \
helper_msa_nloc_d \
helper_msa_nlzc_b \
helper_msa_nlzc_h \
helper_msa_nlzc_w \
helper_msa_nlzc_d \
helper_msa_pcnt_b \
helper_msa_pcnt_h \
helper_msa_pcnt_w \
helper_msa_pcnt_d \
helper_msa_binsl_b \
helper_msa_binsl_h \
helper_msa_binsl_w \
helper_msa_binsl_d \
helper_msa_binsr_b \
helper_msa_binsr_h \
helper_msa_binsr_w \
helper_msa_binsr_d \
helper_msa_bmnz_v \
helper_msa_bmz_v \
helper_msa_bsel_v \
helper_msa_bclr_b \
helper_msa_bclr_h \
helper_msa_bclr_w \
helper_msa_bclr_d \
helper_msa_bneg_b \
helper_msa_bneg_h \
helper_msa_bneg_w \
helper_msa_bneg_d \
helper_msa_bset_b \
helper_msa_bset_h \
helper_msa_bset_w \
helper_msa_bset_d \
helper_msa_add_a_b \
helper_msa_add_a_h \
helper_msa_add_a_w \
helper_msa_add_a_d \
helper_msa_adds_a_b \
helper_msa_adds_a_h \
helper_msa_adds_a_w \
helper_msa_adds_a_d \
helper_msa_adds_s_b \
helper_msa_adds_s_h \
helper_msa_adds_s_w \
helper_msa_adds_s_d \
helper_msa_adds_u_b \
helper_msa_adds_u_h \
helper_msa_adds_u_w \
helper_msa_adds_u_d \
helper_msa_addv_b \
helper_msa_addv_h \
helper_msa_addv_w \
helper_msa_addv_d \
helper_msa_hadd_s_h \
helper_msa_hadd_s_w \
helper_msa_hadd_s_d \
helper_msa_hadd_u_h \
helper_msa_hadd_u_w \
helper_msa_hadd_u_d \
helper_msa_ave_s_b \
helper_msa_ave_s_h \
helper_msa_ave_s_w \
helper_msa_ave_s_d \
helper_msa_ave_u_b \
helper_msa_ave_u_h \
helper_msa_ave_u_w \
helper_msa_ave_u_d \
helper_msa_aver_s_b \
helper_msa_aver_s_h \
helper_msa_aver_s_w \
helper_msa_aver_s_d \
helper_msa_aver_u_b \
helper_msa_aver_u_h \
helper_msa_aver_u_w \
helper_msa_aver_u_d \
helper_msa_ceq_b \
helper_msa_ceq_h \
helper_msa_ceq_w \
helper_msa_ceq_d \
helper_msa_cle_s_b \
helper_msa_cle_s_h \
helper_msa_cle_s_w \
helper_msa_cle_s_d \
helper_msa_cle_u_b \
helper_msa_cle_u_h \
helper_msa_cle_u_w \
helper_msa_cle_u_d \
helper_msa_clt_s_b \
helper_msa_clt_s_h \
helper_msa_clt_s_w \
helper_msa_clt_s_d \
helper_msa_clt_u_b \
helper_msa_clt_u_h \
helper_msa_clt_u_w \
helper_msa_clt_u_d \
helper_msa_div_s_b \
helper_msa_div_s_h \
helper_msa_div_s_w \
helper_msa_div_s_d \
helper_msa_div_u_b \
helper_msa_div_u_h \
helper_msa_div_u_w \
helper_msa_div_u_d \
helper_msa_max_a_b \
helper_msa_max_a_h \
helper_msa_max_a_w \
helper_msa_max_a_d \
helper_msa_max_s_b \
helper_msa_max_s_h \
helper_msa_max_s_w \
helper_msa_max_s_d \
helper_msa_max_u_b \
helper_msa_max_u_h \
helper_msa_max_u_w \
helper_msa_max_u_d \
helper_msa_min_a_b \
helper_msa_min_a_h \
helper_msa_min_a_w \
helper_msa_min_a_d \
helper_msa_min_s_b \
helper_msa_min_s_h \
helper_msa_min_s_w \
helper_msa_min_s_d \
helper_msa_min_u_b \
helper_msa_min_u_h \
helper_msa_min_u_w \
helper_msa_min_u_d \
helper_msa_mod_s_b \
helper_msa_mod_s_h \
helper_msa_mod_s_w \
helper_msa_mod_s_d \
helper_msa_mod_u_b \
helper_msa_mod_u_h \
helper_msa_mod_u_w \
helper_msa_mod_u_d \
helper_msa_asub_s_b \
helper_msa_asub_s_h \
helper_msa_asub_s_w \
helper_msa_asub_s_d \
helper_msa_asub_u_b \
helper_msa_asub_u_h \
helper_msa_asub_u_w \
helper_msa_asub_u_d \
helper_msa_hsub_s_h \
helper_msa_hsub_s_w \
helper_msa_hsub_s_d \
helper_msa_hsub_u_h \
helper_msa_hsub_u_w \
helper_msa_hsub_u_d \
helper_msa_ilvev_b \
helper_msa_ilvev_h \
helper_msa_ilvev_w \
helper_msa_ilvev_d \
helper_msa_ilvod_b \
helper_msa_ilvod_h \
helper_msa_ilvod_w \
helper_msa_ilvod_d \
helper_msa_ilvl_b \
helper_msa_ilvl_h \
helper_msa_ilvl_w \
helper_msa_ilvl_d \
helper_msa_ilvr_b \
helper_msa_ilvr_h \
helper_msa_ilvr_w \
helper_msa_ilvr_d \
helper_msa_and_v \
helper_msa_nor_v \
helper_msa_or_v \
helper_msa_xor_v \
helper_msa_move_v \
helper_msa_pckev_b \
helper_msa_pckev_h \
helper_msa_pckev_w \
helper_msa_pckev_d \
helper_msa_pckod_b \
helper_msa_pckod_h \
helper_msa_pckod_w \
helper_msa_pckod_d \
helper_msa_sll_b \
helper_msa_sll_h \
helper_msa_sll_w \
helper_msa_sll_d \
helper_msa_sra_b \
helper_msa_sra_h \
helper_msa_sra_w \
helper_msa_sra_d \
helper_msa_srar_b \
helper_msa_srar_h \
helper_msa_srar_w \
helper_msa_srar_d \
helper_msa_srl_b \
helper_msa_srl_h \
helper_msa_srl_w \
helper_msa_srl_d \
helper_msa_srlr_b \
helper_msa_srlr_h \
helper_msa_srlr_w \
helper_msa_srlr_d \
helper_msa_andi_b \
helper_msa_ori_b \
helper_msa_nori_b \
helper_msa_xori_b \
helper_msa_bmnzi_b \
helper_msa_bmzi_b \
helper_msa_bseli_b \
helper_msa_shf_df \
helper_msa_addvi_df \
helper_msa_subvi_df \
helper_msa_ceqi_df \
helper_msa_clei_s_df \
helper_msa_clei_u_df \
helper_msa_clti_s_df \
helper_msa_clti_u_df \
helper_msa_maxi_s_df \
helper_msa_maxi_u_df \
helper_msa_mini_s_df \
helper_msa_mini_u_df \
helper_msa_ldi_df \
helper_msa_slli_df \
helper_msa_srai_df \
helper_msa_srli_df \
helper_msa_bclri_df \
helper_msa_bseti_df \
helper_msa_bnegi_df \
helper_msa_sat_s_df \
helper_msa_sat_u_df \
helper_msa_srari_df \
helper_msa_srlri_df \
helper_msa_binsli_df \
helper_msa_binsri_df \
helper_msa_subv_df \
helper_msa_subs_s_df \
helper_msa_subs_u_df \
helper_msa_subsus_u_df \
helper_msa_subsuu_s_df \
helper_msa_mulv_df \
helper_msa_dotp_s_df \
helper_msa_dotp_u_df \
helper_msa_mul_q_df \
helper_msa_mulr_q_df \
helper_msa_sld_df \
helper_msa_maddv_df \
helper_msa_msubv_df \
helper_msa_dpadd_s_df \
helper_msa_dpadd_u_df \
helper_msa_dpsub_s_df \
helper_msa_dpsub_u_df \
helper_msa_binsl_df \
helper_msa_binsr_df \
helper_msa_madd_q_df \
helper_msa_msub_q_df \
helper_msa_maddr_q_df \
helper_msa_msubr_q_df \
helper_msa_splat_df \
helper_msa_vshf_df \
helper_msa_sldi_df \
helper_msa_splati_df \
helper_msa_copy_s_b \
helper_msa_copy_s_h \
helper_msa_copy_s_w \
helper_msa_copy_s_d \
helper_msa_copy_u_b \
helper_msa_copy_u_h \
helper_msa_copy_u_w \
helper_msa_insert_b \
helper_msa_insert_h \
helper_msa_insert_w \
helper_msa_insert_d \
helper_msa_insve_df \
helper_msa_ctcmsa \
helper_msa_cfcmsa \
helper_msa_fill_df \
helper_msa_fcaf_df \
helper_msa_fcun_df \
helper_msa_fceq_df \
helper_msa_fcueq_df \
helper_msa_fclt_df \
helper_msa_fcult_df \
helper_msa_fcle_df \
helper_msa_fcule_df \
helper_msa_fsaf_df \
helper_msa_fsun_df \
helper_msa_fseq_df \
helper_msa_fsueq_df \
helper_msa_fslt_df \
helper_msa_fsult_df \
helper_msa_fsle_df \
helper_msa_fsule_df \
helper_msa_fcor_df \
helper_msa_fcune_df \
helper_msa_fcne_df \
helper_msa_fsor_df \
helper_msa_fsune_df \
helper_msa_fsne_df \
helper_msa_fadd_df \
helper_msa_fsub_df \
helper_msa_fmul_df \
helper_msa_fdiv_df \
helper_msa_fmadd_df \
helper_msa_fmsub_df \
helper_msa_fexp2_df \
helper_msa_fexdo_df \
helper_msa_ftq_df \
helper_msa_fmin_df \
helper_msa_fmin_a_df \
helper_msa_fmax_df \
helper_msa_fmax_a_df \
helper_msa_fclass_df \
helper_msa_ftrunc_s_df \
helper_msa_ftrunc_u_df \
helper_msa_fsqrt_df \
helper_msa_frsqrt_df \
helper_msa_frcp_df \
helper_msa_frint_df \
helper_msa_flog2_df \
helper_msa_fexupl_df \
helper_msa_fexupr_df \
helper_msa_ffql_df \
helper_msa_ffqr_df \
helper_msa_ftint_s_df \
helper_msa_ftint_u_df \
helper_msa_ffint_s_df \
helper_msa_ffint_u_df \
helper_raise_exception_err \
helper_raise_exception \
helper_raise_exception_debug \
helper_muls \
helper_mulsu \
helper_macc \
helper_macchi \
helper_maccu \
helper_macchiu \
helper_msac \
helper_msachi \
helper_msacu \
helper_msachiu \
helper_mulhi \
helper_mulhiu \
helper_mulshi \
helper_mulshiu \
helper_dbitswap \
helper_bitswap \
helper_rotx \
helper_ll \
helper_lld \
helper_swl \
helper_swr \
helper_sdl \
helper_sdr \
helper_lwm \
helper_swm \
helper_ldm \
helper_sdm \
helper_fork \
helper_yield \
r4k_helper_tlbinv \
r4k_helper_tlbinvf \
r4k_helper_tlbwi \
r4k_helper_tlbwr \
r4k_helper_tlbp \
r4k_helper_tlbr \
helper_tlbwi \
helper_tlbwr \
helper_tlbp \
helper_tlbr \
helper_tlbinv \
helper_tlbinvf \
helper_ginvt \
helper_di \
helper_ei \
helper_eret \
helper_eretnc \
helper_deret \
helper_rdhwr_cpunum \
helper_rdhwr_synci_step \
helper_rdhwr_cc \
helper_rdhwr_ccres \
helper_rdhwr_performance \
helper_rdhwr_xnp \
helper_pmon \
helper_wait \
mips_cpu_do_unaligned_access \
mips_cpu_do_transaction_failed \
helper_msa_ld_b \
helper_msa_ld_h \
helper_msa_ld_w \
helper_msa_ld_d \
helper_msa_st_b \
helper_msa_st_h \
helper_msa_st_w \
helper_msa_st_d \
helper_cache \
gen_intermediate_code \
mips_tcg_init \
cpu_mips_realize_env \
cpu_state_reset \
restore_state_to_opc \
ieee_rm \
mips_defs \
mips_defs_number \
gen_helper_float_class_s \
gen_helper_float_class_d \
"

mipsel_SYMBOLS=${mips_SYMBOLS}

mips64_SYMBOLS=${mips_SYMBOLS}

mips64el_SYMBOLS=${mips_SYMBOLS}

sparc_SYMBOLS="
helper_compute_psr \
helper_compute_C_icc \
cpu_sparc_set_id \
cpu_sparc_init \
helper_check_ieee_exceptions \
helper_fadds \
helper_faddd \
helper_faddq \
helper_fsubs \
helper_fsubd \
helper_fsubq \
helper_fmuls \
helper_fmuld \
helper_fmulq \
helper_fdivs \
helper_fdivd \
helper_fdivq \
helper_fsmuld \
helper_fsmulq \
helper_fdmulq \
helper_fnegs \
helper_fnegd \
helper_fnegq \
helper_fitos \
helper_fitod \
helper_fitoq \
helper_fxtos \
helper_fxtod \
helper_fxtoq \
helper_fdtos \
helper_fstod \
helper_fqtos \
helper_fstoq \
helper_fqtod \
helper_fdtoq \
helper_fstoi \
helper_fdtoi \
helper_fqtoi \
helper_fstox \
helper_fdtox \
helper_fqtox \
helper_fabss \
helper_fabsd \
helper_fabsq \
helper_fsqrts \
helper_fsqrtd \
helper_fsqrtq \
helper_fcmps \
helper_fcmpd \
helper_fcmpes \
helper_fcmped \
helper_fcmpq \
helper_fcmpeq \
helper_fcmps_fcc1 \
helper_fcmpd_fcc1 \
helper_fcmpq_fcc1 \
helper_fcmps_fcc2 \
helper_fcmpd_fcc2 \
helper_fcmpq_fcc2 \
helper_fcmps_fcc3 \
helper_fcmpd_fcc3 \
helper_fcmpq_fcc3 \
helper_fcmpes_fcc1 \
helper_fcmped_fcc1 \
helper_fcmpeq_fcc1 \
helper_fcmpes_fcc2 \
helper_fcmped_fcc2 \
helper_fcmpeq_fcc2 \
helper_fcmpes_fcc3 \
helper_fcmped_fcc3 \
helper_fcmpeq_fcc3 \
helper_ldfsr \
helper_ldxfsr \
cpu_raise_exception_ra \
helper_raise_exception \
helper_debug \
helper_tick_set_count \
helper_tick_get_count \
helper_tick_set_limit \
helper_udiv \
helper_udiv_cc \
helper_sdiv \
helper_sdiv_cc \
helper_sdivx \
helper_udivx \
helper_taddcctv \
helper_tsubcctv \
helper_power_down \
sparc_cpu_do_interrupt \
leon3_irq_manager \
sparc_cpu_do_interrupt \
cpu_tsptr \
helper_set_softint \
helper_clear_softint \
helper_write_softint \
helper_check_align \
helper_ld_asi \
helper_st_asi \
sparc_cpu_do_transaction_failed \
sparc_cpu_do_unaligned_access \
sparc_cpu_tlb_fill \
mmu_probe \
sparc_cpu_memory_rw_debug \
cpu_get_phys_page_nofault \
sparc_cpu_get_phys_page_debug \
gen_intermediate_code \
sparc_tcg_init \
restore_state_to_opc \
cpu_set_cwp \
cpu_get_psr \
cpu_put_psr_raw \
cpu_put_psr \
cpu_cwp_inc \
cpu_cwp_dec \
helper_rett \
helper_save \
helper_restore \
helper_flushw \
helper_saved \
helper_restored \
helper_wrpsr \
helper_rdpsr \
cpu_get_ccr \
cpu_put_ccr \
cpu_get_cwp64 \
cpu_put_cwp64 \
helper_rdccr \
helper_wrccr \
helper_rdcwp \
helper_wrcwp \
cpu_gl_switch_gregs \
helper_wrgl \
cpu_change_pstate \
helper_wrpstate \
helper_wrpil \
helper_done \
helper_retry \
"

sparc64_SYMBOLS=${sparc_SYMBOLS}

m68k_SYMBOLS="
cpu_m68k_init \
helper_reds32 \
helper_redf32 \
helper_exts32 \
helper_extf32 \
helper_extf64 \
helper_redf64 \
helper_firound \
cpu_m68k_set_fpcr \
helper_fitrunc \
helper_set_fpcr \
helper_fsround \
helper_fdround \
helper_fsqrt \
helper_fssqrt \
helper_fdsqrt \
helper_fabs \
helper_fsabs \
helper_fdabs \
helper_fneg \
helper_fsneg \
helper_fdneg \
helper_fadd \
helper_fsadd \
helper_fdadd \
helper_fsub \
helper_fssub \
helper_fdsub \
helper_fmul \
helper_fsmul \
helper_fdmul \
helper_fsglmul \
helper_fdiv \
helper_fsdiv \
helper_fddiv \
helper_fsgldiv \
helper_fcmp \
helper_ftst \
helper_fconst \
helper_fmovemx_st_predec \
helper_fmovemx_st_postinc \
helper_fmovemx_ld_postinc \
helper_fmovemd_st_predec \
helper_fmovemd_st_postinc \
helper_fmovemd_ld_postinc \
helper_fmod \
helper_frem \
helper_fgetexp \
helper_fgetman \
helper_fscale \
helper_flognp1 \
helper_flogn \
helper_flog10 \
helper_flog2 \
helper_fetox \
helper_ftwotox \
helper_ftentox \
helper_ftan \
helper_fsin \
helper_fcos \
helper_fsincos \
helper_fatan \
helper_fasin \
helper_facos \
helper_fatanh \
helper_ftanh \
helper_fsinh \
helper_fcosh \
helper_cf_movec_to \
helper_m68k_movec_to \
helper_m68k_movec_from \
helper_set_macsr \
m68k_switch_sp \
m68k_cpu_get_phys_page_debug \
m68k_set_irq_level \
m68k_cpu_tlb_fill \
helper_bitrev \
helper_ff1 \
helper_sats \
cpu_m68k_get_sr \
cpu_m68k_set_sr \
helper_set_sr \
helper_mac_move \
helper_macmuls \
helper_macmulu \
helper_macmulf \
helper_macsats \
helper_macsatu \
helper_macsatf \
helper_mac_set_flags \
cpu_m68k_get_ccr \
helper_get_ccr \
cpu_m68k_set_ccr \
helper_set_ccr \
helper_flush_flags \
helper_get_macf \
helper_get_macs \
helper_get_macu \
helper_get_mac_extf \
helper_get_mac_exti \
helper_set_mac_extf \
helper_set_mac_exts \
helper_set_mac_extu \
helper_ptest \
helper_pflush \
helper_reset \
m68k_cpu_do_interrupt \
m68k_cpu_transaction_failed \
m68k_cpu_exec_interrupt \
helper_raise_exception \
helper_divuw \
helper_divsw \
helper_divul \
helper_divsl \
helper_divull \
helper_divsll \
helper_cas2w \
helper_cas2l \
helper_cas2l_parallel \
helper_bfexts_mem \
helper_bfextu_mem \
helper_bfins_mem \
helper_bfchg_mem \
helper_bfclr_mem \
helper_bfset_mem \
helper_bfffo_reg \
helper_bfffo_mem \
helper_chk \
helper_chk2 \
floatx80_mod \
floatx80_getman \
floatx80_getexp \
floatx80_scale \
floatx80_move \
floatx80_lognp1 \
floatx80_logn \
floatx80_log10 \
floatx80_log2 \
floatx80_etox \
floatx80_twotox \
floatx80_tentox \
floatx80_tan \
floatx80_sin \
floatx80_cos \
floatx80_atan \
floatx80_asin \
floatx80_acos \
floatx80_atanh \
floatx80_etoxm1 \
floatx80_tanh \
floatx80_sinh \
floatx80_cosh \
m68k_tcg_init \
register_m68k_insns \
gen_intermediate_code \
restore_state_to_opc \
"

ppc_SYMBOLS="
ppc_cpu_unrealize \
ppc_cpu_instance_finalize \
ppc_cpu_do_interrupt \
ppc_cpu_do_system_reset \
ppc_cpu_do_fwnmi_machine_check \
ppc_cpu_exec_interrupt \
raise_exception_err_ra \
raise_exception_err \
raise_exception \
raise_exception_ra \
helper_raise_exception_err \
helper_store_msr \
helper_rfi \
helper_40x_rfci \
helper_rfdi \
helper_rfci \
helper_rfmci \
helper_tw \
helper_rfsvc \
helper_msgclr \
helper_msgsnd \
helper_book3s_msgclr \
ppc_cpu_do_unaligned_access \
helper_divweu \
helper_divwe \
helper_sraw \
helper_popcntb \
helper_div \
helper_divo \
helper_divs \
helper_divso \
helper_602_mfrom \
helper_mtvscr \
helper_vaddcuw \
helper_vprtybw \
helper_vprtybd \
helper_vprtybq \
helper_vmuluwm \
helper_vaddfp \
helper_vsubfp \
helper_vminfp \
helper_vmaxfp \
helper_vmaddfp \
helper_vnmsubfp \
helper_vaddsbs \
helper_vsubsbs \
helper_vsubshs \
helper_vaddsws \
helper_vsubsws \
helper_vaddubs \
helper_vsububs \
helper_vadduhs \
helper_vsubuhs \
helper_vadduws \
helper_vsubuws \
helper_vavgsb \
helper_vavgub \
helper_vavgsh \
helper_vavguh \
helper_vavgsw \
helper_vabsdub \
helper_vabsduh \
helper_vabsduw \
helper_vcfux \
helper_vcfsx \
helper_vcmpequb \
helper_vcmpequb_dot \
helper_vcmpequw \
helper_vcmpequw_dot \
helper_vcmpequd \
helper_vcmpequd_dot \
helper_vcmpgtub \
helper_vcmpgtub_dot \
helper_vcmpgtuh \
helper_vcmpgtuh_dot \
helper_vcmpgtuw \
helper_vcmpgtuw_dot \
helper_vcmpgtud \
helper_vcmpgtud_dot \
helper_vcmpgtud \
helper_vcmpgtud_dot \
helper_vcmpgtsb \
helper_vcmpgtsb_dot \
helper_vcmpgtsh \
helper_vcmpgtsh_dot \
helper_vcmpgtsw \
helper_vcmpgtsw_dot \
helper_vcmpgtsd \
helper_vcmpgtsd_dot \
helper_vcmpnezb \
helper_vcmpnezb_dot \
helper_vcmpnezb \
helper_vcmpnezb_dot \
helper_vcmpnezw \
helper_vcmpnezw_dot \
helper_vcmpneb \
helper_vcmpneb_dot \
helper_vcmpneb \
helper_vcmpneb_dot \
helper_vcmpneh \
helper_vcmpneh_dot \
helper_vcmpnew \
helper_vcmpnew_dot \
helper_vcmpeqfp \
helper_vcmpeqfp_dot \
helper_vcmpgefp \
helper_vcmpgefp_dot \
helper_vcmpgtfp \
helper_vcmpgtfp_dot \
helper_vcmpbfp \
helper_vcmpbfp_dot \
helper_vcmpbfp \
helper_vcmpbfp_dot \
helper_vctuxs \
helper_vctsxs \
helper_vclzlsbb \
helper_vctzlsbb \
helper_vmhaddshs \
helper_vmhraddshs \
helper_vmladduhm \
helper_vmhraddshs \
helper_vmladduhm \
helper_vmrglb \
helper_vmrghb \
helper_vmrglh \
helper_vmrghh \
helper_vmrglw \
helper_vmrghw \
helper_vmsummbm \
helper_vmsumshs \
helper_vmsumubm \
helper_vmsumuhm \
helper_vmulesb \
helper_vmulosb \
helper_vmulesh \
helper_vmulesw \
helper_vmuleub \
helper_vmuloub \
helper_vmuleuh \
helper_vmulouh \
helper_vmuleuw \
helper_vmulouw \
helper_vperm \
helper_vpermr \
helper_vbpermd \
helper_vpmsumb \
helper_vpmsumh \
helper_vpmsumw \
helper_vpmsumd \
helper_vpkpx \
helper_vpkshss \
helper_vpkshus \
helper_vpkswss \
helper_vpkswus \
helper_vpksdss \
helper_vpksdus \
helper_vpkuhus \
helper_vpkuwus \
helper_vpkudus \
helper_vpkuhum \
helper_vpkuwum \
helper_vpkudum \
helper_vrefp \
helper_vrfin \
helper_vrfim \
helper_vrfip \
helper_vrfiz \
helper_vrlb \
helper_vrlh \
helper_vrlw \
helper_vrld \
helper_vrsqrtefp \
helper_vrldmi \
helper_vrlwmi \
helper_vrldnm \
helper_vrlwnm \
helper_vsel \
helper_vexptefp \
helper_vlogefp \
helper_vextublx \
helper_vextuhlx \
helper_vextuwlx \
helper_vextubrx \
helper_vextuhrx \
helper_vextuwrx \
helper_vslv \
helper_vsrv \
helper_vsldoi \
helper_vslo \
helper_vinsertb \
helper_vinserth \
helper_vinsertw \
helper_vinsertd \
helper_vextractub \
helper_vextractuh \
helper_vextractuw \
helper_vextractd \
helper_xxextractuw \
helper_xxinsertw \
helper_vextsb2w \
helper_vextsb2d \
helper_vextsh2w \
helper_vextsh2d \
helper_vnegw \
helper_vnegd \
helper_vsro \
helper_vsubcuw \
helper_vsumsws \
helper_vsum2sws \
helper_vsum4sbs \
helper_vsum4shs \
helper_vsum4ubs \
helper_vupklpx \
helper_vupkhpx \
helper_vupkhsb \
helper_vupkhsh \
helper_vupkhsw \
helper_vupklsb \
helper_vupklsh \
helper_vupklsw \
helper_vclzb \
helper_vclzh \
helper_vctzb \
helper_vctzh \
helper_vctzw \
helper_vctzd \
helper_vpopcntb \
helper_vpopcnth \
helper_vpopcntw \
helper_vpopcntd \
helper_vadduqm \
helper_vaddeuqm \
helper_vaddcuq \
helper_vaddecuq \
helper_vsubuqm \
helper_vsubeuqm \
helper_vsubcuq \
helper_vsubecuq \
helper_bcdadd \
helper_bcdsub \
helper_bcdcfn \
helper_bcdctn \
helper_bcdcfz \
helper_bcdctz \
helper_bcdcfsq \
helper_bcdctsq \
helper_bcdcpsgn \
helper_bcdsetsgn \
helper_bcds \
helper_bcdus \
helper_bcdsr \
helper_bcdtrunc \
helper_bcdutrunc \
helper_vsbox \
helper_vcipher \
helper_vcipherlast \
helper_vncipher \
helper_vncipherlast \
helper_vshasigmaw \
helper_vshasigmad \
helper_vpermxor \
helper_brinc \
helper_cntlsw32 \
helper_cntlzw32 \
helper_dlmzb \
helper_lmw \
helper_lsw \
helper_lswx \
helper_stsw \
helper_dcbz \
helper_dcbzep \
helper_icbi \
helper_icbiep \
helper_lscbx \
helper_lvebx \
helper_lvehx \
helper_lvewx \
helper_stvebx \
helper_stvehx \
helper_stvewx \
helper_tbegin \
helper_load_dump_spr \
helper_store_dump_spr \
helper_hfscr_facility_check \
helper_fscr_facility_check \
helper_msr_facility_check \
helper_store_sdr1 \
helper_store_pidr \
helper_store_lpidr \
helper_store_hid0_601 \
helper_store_403_pbr \
helper_store_40x_dbcr0 \
helper_store_40x_sler \
helper_clcs \
ppc_store_msr \
helper_fixup_thrm \
store_40x_sler \
dump_mmu \
ppc_cpu_get_phys_page_debug \
helper_store_ibatu \
helper_store_ibatl \
helper_store_dbatu \
helper_store_dbatl \
helper_store_601_batu \
helper_store_601_batl \
ppc_tlb_invalidate_all \
ppc_tlb_invalidate_one \
ppc_store_sdr1 \
helper_load_sr \
helper_store_sr \
helper_tlbia \
helper_tlbie \
helper_tlbiva \
helper_6xx_tlbd \
helper_6xx_tlbi \
helper_74xx_tlbd \
helper_74xx_tlbi \
helper_rac \
helper_4xx_tlbre_hi \
helper_4xx_tlbre_lo \
helper_4xx_tlbwe_hi \
helper_4xx_tlbwe_lo \
helper_4xx_tlbsx \
helper_440_tlbwe \
helper_440_tlbre \
helper_440_tlbsx \
helper_booke_setpid \
helper_booke_set_eplc \
helper_booke_set_epsc \
helper_booke206_tlbwe \
helper_booke206_tlbre \
helper_booke206_tlbsx \
helper_booke206_tlbivax \
helper_booke206_tlbilx0 \
helper_booke206_tlbilx1 \
helper_booke206_tlbilx3 \
helper_booke206_tlbflush \
helper_check_tlb_flush_local \
helper_check_tlb_flush_global \
ppc_cpu_tlb_fill \
helper_load_tbl \
helper_load_tbu \
helper_load_atbl \
helper_load_atbu \
helper_load_vtb \
helper_load_601_rtcl \
helper_load_601_rtcu \
helper_store_tbl \
helper_store_tbu \
helper_store_atbl \
helper_store_atbu \
helper_store_601_rtcl \
helper_store_601_rtcu \
helper_load_decr \
helper_store_decr \
helper_load_hdecr \
helper_store_hdecr \
helper_store_vtb \
helper_store_tbu40 \
helper_load_40x_pit \
helper_store_40x_pit \
helper_store_booke_tcr \
helper_store_booke_tsr \
helper_load_dcr \
helper_store_dcr \
helper_raise_exception \
helper_book3s_msgsnd \
helper_cmpb \
helper_mfvscr \
helper_vaddshs \
helper_vavguw \
helper_vcmpequh \
helper_vcmpequh_dot \
helper_vcmpnezh \
helper_vcmpnezh_dot \
helper_vmsumshm \
helper_vmsumuhs \
helper_vmulosh \
helper_vmulosw \
helper_vbpermq \
helper_vextsw2d \
helper_stmw \
ppc_translate_init \
cpu_ppc_init \
gen_intermediate_code \
restore_state_to_opc \
ppc_set_irq \
ppc6xx_irq_init \
ppc40x_core_reset \
ppc40x_chip_reset \
ppc40x_system_reset \
store_40x_dbcr0 \
ppc40x_irq_init \
ppce500_irq_init \
ppce500_set_mpic_proxy \
cpu_ppc_get_tb \
cpu_ppc_load_tbl \
cpu_ppc_load_tbu \
cpu_ppc_store_tbl \
cpu_ppc_store_tbu \
cpu_ppc_load_atbl \
cpu_ppc_load_atbu \
cpu_ppc_store_atbl \
cpu_ppc_store_atbu \
cpu_ppc_load_vtb \
cpu_ppc_store_vtb \
cpu_ppc_store_tbu40 \
ppc_decr_clear_on_delivery \
cpu_ppc_load_decr \
cpu_ppc_load_hdecr \
cpu_ppc_load_purr \
cpu_ppc_store_decr \
cpu_ppc_store_hdecr \
cpu_ppc_store_purr \
cpu_ppc_tb_init \
cpu_ppc601_load_rtcu \
cpu_ppc601_store_rtcu \
cpu_ppc601_load_rtcl \
cpu_ppc601_store_rtcl \
load_40x_pit \
store_40x_pit \
ppc_40x_timers_init \
ppc_dcr_read \
ppc_dcr_write \
ppc_dcr_register \
ppc_dcr_init \
ppc_cpu_pir \
ppc_irq_reset \
store_booke_tsr \
get_pteg_offset32 \
ppc_booke_timers_init \
ppc_hash32_handle_mmu_fault \
gen_helper_store_booke_tsr \
gen_helper_store_booke_tcr \
store_booke_tcr \
ppc_hash32_get_phys_page_debug \
helper_fadd \
helper_todouble \
helper_tosingle \
helper_compute_fprf_float16 \
helper_compute_fprf_float32 \
helper_compute_fprf_float64 \
helper_compute_fprf_float128 \
helper_fpscr_clrbit \
helper_fpscr_setbit \
helper_store_fpscr \
helper_float_check_status \
helper_reset_fpstatus \
helper_fsub \
helper_fmul \
helper_fdiv \
helper_fctiw \
helper_fctiwz \
helper_fctiwu \
helper_fctiwuz \
helper_fctid \
helper_fctidz \
helper_fctidu \
helper_fctiduz \
helper_fcfid \
helper_fcfids \
helper_fcfidu \
helper_fcfidus \
helper_frin \
helper_friz \
helper_frip \
helper_frim \
helper_fmadd \
helper_fnmadd \
helper_fmsub \
helper_fnmsub \
helper_frsp \
helper_fsqrt \
helper_fre \
helper_fres \
helper_frsqrte \
helper_fsel \
helper_ftdiv \
helper_ftsqrt \
helper_fcmpu \
helper_fcmpo \
helper_efscfsi \
helper_efscfui \
helper_efscfuf \
helper_efscfsf \
helper_efsctsi \
helper_efsctui \
helper_efsctsiz \
helper_efsctuiz \
helper_efsctsf \
helper_efsctuf \
helper_evfscfsi \
helper_evfscfui \
helper_evfscfuf \
helper_evfscfsf \
helper_evfsctsi \
helper_evfsctui \
helper_evfsctsiz \
helper_evfsctuiz \
helper_evfsctsf \
helper_evfsctuf \
helper_efsadd \
helper_efssub \
helper_efsmul \
helper_efsdiv \
helper_evfsadd \
helper_evfssub \
helper_evfsmul \
helper_evfsdiv \
helper_efststlt \
helper_efststgt \
helper_efststeq \
helper_efscmplt \
helper_efscmpgt \
helper_efscmpeq \
helper_evfststlt \
helper_evfststgt \
helper_evfststeq \
helper_evfscmplt \
helper_evfscmpgt \
helper_evfscmpeq \
helper_efdcfsi \
helper_efdcfsid \
helper_efdcfui \
helper_efdcfuid \
helper_efdctsi \
helper_efdctui \
helper_efdctsiz \
helper_efdctsidz \
helper_efdctuiz \
helper_efdctuidz \
helper_efdcfsf \
helper_efdcfuf \
helper_efdctsf \
helper_efdctuf \
helper_efscfd \
helper_efdcfs \
helper_efdadd \
helper_efdsub \
helper_efdmul \
helper_efddiv \
helper_efdtstlt \
helper_efdtstgt \
helper_efdtsteq \
helper_efdcmplt \
helper_efdcmpgt \
helper_efdcmpeq \
helper_xsadddp \
helper_xsaddsp \
helper_xvadddp \
helper_xvaddsp \
helper_xssubdp \
helper_xssubsp \
helper_xvsubdp \
helper_xvsubsp \
helper_xsaddqp \
helper_xsmuldp \
helper_xsmulsp \
helper_xvmuldp \
helper_xvmulsp \
helper_xsmulqp \
helper_xsdivdp \
helper_xsdivsp \
helper_xvdivdp \
helper_xvdivsp \
helper_xsdivqp \
helper_xsredp \
helper_xsresp \
helper_xvredp \
helper_xvresp \
helper_xssqrtdp \
helper_xssqrtsp \
helper_xvsqrtdp \
helper_xvsqrtsp \
helper_xsrsqrtedp \
helper_xsrsqrtesp \
helper_xvrsqrtedp \
helper_xvrsqrtesp \
helper_xstdivdp \
helper_xvtdivdp \
helper_xvtdivsp \
helper_xstsqrtdp \
helper_xvtsqrtdp \
helper_xvtsqrtsp \
helper_xsmadddp \
helper_xsmsubdp \
helper_xsnmadddp \
helper_xsnmsubdp \
helper_xsmaddsp \
helper_xsmsubsp \
helper_xsnmaddsp \
helper_xsnmsubsp \
helper_xvmadddp \
helper_xvmsubdp \
helper_xvnmadddp \
helper_xvnmsubdp \
helper_xvmaddsp \
helper_xvmsubsp \
helper_xvnmaddsp \
helper_xvnmsubsp \
helper_xscmpeqdp \
helper_xscmpgedp \
helper_xscmpgtdp \
helper_xscmpnedp \
helper_xscmpexpdp \
helper_xscmpexpqp \
helper_xscmpodp \
helper_xscmpudp \
helper_xscmpoqp \
helper_xscmpuqp \
helper_xsmaxdp \
helper_xvmaxdp \
helper_xvmaxsp \
helper_xsmindp \
helper_xvmindp \
helper_xvminsp \
helper_xsmaxcdp \
helper_xsmincdp \
helper_xsmaxjdp \
helper_xsminjdp \
helper_xvcmpeqdp \
helper_xvcmpgedp \
helper_xvcmpgtdp \
helper_xvcmpnedp \
helper_xvcmpeqsp \
helper_xvcmpgesp \
helper_xvcmpgtsp \
helper_xvcmpnesp \
helper_xscvdpsp \
helper_xscvspdp \
helper_xvcvdpsp \
helper_xvcvspdp \
helper_xscvdpqp \
helper_xscvdphp \
helper_xscvhpdp \
helper_xvcvsphp \
helper_xvcvhpsp \
helper_xscvqpdp \
helper_xscvdpspn \
helper_xscvspdpn \
helper_xscvdpsxds \
helper_xscvdpsxws \
helper_xscvdpuxds \
helper_xscvdpuxws \
helper_xvcvdpsxds \
helper_xvcvdpsxws \
helper_xvcvdpuxds \
helper_xvcvdpuxws \
helper_xvcvspsxds \
helper_xvcvspsxws \
helper_xvcvspuxds \
helper_xvcvspuxws \
helper_xscvqpsdz \
helper_xscvqpswz \
helper_xscvqpudz \
helper_xscvqpuwz \
helper_xscvsxddp \
helper_xscvuxddp \
helper_xscvsxdsp \
helper_xscvuxdsp \
helper_xvcvsxddp \
helper_xvcvuxddp \
helper_xvcvsxwdp \
helper_xvcvuxwdp \
helper_xvcvsxdsp \
helper_xvcvuxdsp \
helper_xvcvsxwsp \
helper_xvcvuxwsp \
helper_xscvsdqp \
helper_xscvudqp \
helper_xsrdpi \
helper_xsrdpic \
helper_xsrdpim \
helper_xsrdpip \
helper_xsrdpiz \
helper_xvrdpi \
helper_xvrdpic \
helper_xvrdpim \
helper_xvrdpip \
helper_xvrdpiz \
helper_xvrspi \
helper_xvrspic \
helper_xvrspim \
helper_xvrspip \
helper_xvrspiz \
helper_xsrsp \
helper_xxperm \
helper_xxpermr \
helper_xvxsigsp \
helper_xvtstdcdp \
helper_xvtstdcsp \
helper_xststdcdp \
helper_xststdcqp \
helper_xststdcsp \
helper_xsrqpi \
helper_xsrqpxp \
helper_xssqrtqp \
helper_xssubqp \
do_store_fpscr
"

ppc64_SYMBOLS=${ppc_SYMBOLS}

s390x_SYMBOLS="helper_uc_s390x_exit \
tcg_s390_tod_updated \
tcg_s390_program_interrupt \
tcg_s390_data_exception \
"

tricore_SYMBOLS="
helper_fadd \
helper_fsub \
helper_fmul \
helper_fdiv \
helper_fmadd \
helper_fmsub \
helper_pack \
gen_intermediate_code \
restore_state_to_opc \
helper_uc_tricore_exit \
"

ARCHS="x86_64 arm aarch64 riscv32 riscv64 mips mipsel mips64 mips64el sparc sparc64 m68k ppc ppc64 s390x tricore"

for arch in $ARCHS; do

echo "Generating header for $arch"
echo "/* Autogen header for Unicorn Engine - DONOT MODIFY */" > $SOURCE_DIR/qemu/$arch.h
echo "#ifndef UNICORN_AUTOGEN_${arch}_H" >> $SOURCE_DIR/qemu/$arch.h
echo "#define UNICORN_AUTOGEN_${arch}_H" >> $SOURCE_DIR/qemu/$arch.h
echo "#ifndef UNICORN_ARCH_POSTFIX" >> $SOURCE_DIR/qemu/$arch.h
echo "#define UNICORN_ARCH_POSTFIX _$arch" >> $SOURCE_DIR/qemu/$arch.h
echo "#endif" >> $SOURCE_DIR/qemu/$arch.h

for loop in $COMMON_SYMBOLS; do
    echo "#define $loop ${loop}_${arch}" >> $SOURCE_DIR/qemu/$arch.h
done

ARCH_SYMBOLS=$(eval echo '$'"${arch}_SYMBOLS")

#echo ${ARCH_SYMBOLS}

for loop in $ARCH_SYMBOLS; do
    echo "#define $loop ${loop}_${arch}" >> $SOURCE_DIR/qemu/$arch.h
done

echo "#endif" >> $SOURCE_DIR/qemu/$arch.h

done
